Class: Google::Apis::GkehubV1alpha::CloudAuditLoggingFeatureSpec
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::CloudAuditLoggingFeatureSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Cloud Audit Logging: Spec for Audit Logging Allowlisting.
Instance Attribute Summary collapse
-
#allowlisted_service_accounts ⇒ Array<String>
Service account that should be allowlisted to send the audit logs; eg cloudauditlogging@gcp-project.iam.gserviceaccount.com.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAuditLoggingFeatureSpec
constructor
A new instance of CloudAuditLoggingFeatureSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAuditLoggingFeatureSpec
Returns a new instance of CloudAuditLoggingFeatureSpec.
389 390 391 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowlisted_service_accounts ⇒ Array<String>
Service account that should be allowlisted to send the audit logs; eg
cloudauditlogging@gcp-project.iam.gserviceaccount.com. These accounts must
already exist, but do not need to have any permissions granted to them. The
customer's entitlements will be checked prior to allowlisting (i.e. the
customer must be an Anthos customer.)
Corresponds to the JSON property allowlistedServiceAccounts
387 388 389 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 387 def allowlisted_service_accounts @allowlisted_service_accounts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
394 395 396 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 394 def update!(**args) @allowlisted_service_accounts = args[:allowlisted_service_accounts] if args.key?(:allowlisted_service_accounts) end |