Class: Google::Apis::GkehubV1alpha::ClusterUpgradeGkeUpgradeFeatureCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

GKEUpgradeFeatureCondition describes the condition of the feature for GKE clusters at a certain point of time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterUpgradeGkeUpgradeFeatureCondition

Returns a new instance of ClusterUpgradeGkeUpgradeFeatureCondition.



573
574
575
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#reasonString

Reason why the feature is in this status. Corresponds to the JSON property reason

Returns:

  • (String)


556
557
558
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 556

def reason
  @reason
end

#statusString

Status of the condition, one of True, False, Unknown. Corresponds to the JSON property status

Returns:

  • (String)


561
562
563
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 561

def status
  @status
end

#typeString

Type of the condition, for example, "ready". Corresponds to the JSON property type

Returns:

  • (String)


566
567
568
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 566

def type
  @type
end

#update_timeString

Last timestamp the condition was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


571
572
573
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 571

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



578
579
580
581
582
583
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 578

def update!(**args)
  @reason = args[:reason] if args.key?(:reason)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end