Class: Google::Apis::GkehubV1alpha::ClusterUpgradeScopeSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

ClusterUpgrade: The configuration for the scope-level ClusterUpgrade feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterUpgradeScopeSpec

Returns a new instance of ClusterUpgradeScopeSpec.



823
824
825
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 823

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gke_upgrade_overridesArray<Google::Apis::GkehubV1alpha::ClusterUpgradeGkeUpgradeOverride>

Allow users to override some properties of each GKE upgrade. Corresponds to the JSON property gkeUpgradeOverrides



805
806
807
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 805

def gke_upgrade_overrides
  @gke_upgrade_overrides
end

#post_conditionsGoogle::Apis::GkehubV1alpha::ClusterUpgradePostConditions

Post conditional checks after an upgrade has been applied on all eligible clusters. Corresponds to the JSON property postConditions



811
812
813
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 811

def post_conditions
  @post_conditions
end

#upstream_scopesArray<String>

This scope consumes upgrades that have COMPLETE status code in the upstream scopes. See UpgradeStatus.Code for code definitions. The scope name should be in the form: projects/p/locations/global/scopes/s`Wherepis the project,sis a valid Scope in this project.pWILL match the Feature's project. This is defined as repeated for future proof reasons. Initial implementation will enforce at most one upstream scope. Corresponds to the JSON propertyupstreamScopes`

Returns:

  • (Array<String>)


821
822
823
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 821

def upstream_scopes
  @upstream_scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



828
829
830
831
832
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 828

def update!(**args)
  @gke_upgrade_overrides = args[:gke_upgrade_overrides] if args.key?(:gke_upgrade_overrides)
  @post_conditions = args[:post_conditions] if args.key?(:post_conditions)
  @upstream_scopes = args[:upstream_scopes] if args.key?(:upstream_scopes)
end