Class: Google::Apis::GkehubV1alpha::ClusterUpgradeScopeState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

ClusterUpgrade: The state for the scope-level ClusterUpgrade feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterUpgradeScopeState

Returns a new instance of ClusterUpgradeScopeState.



860
861
862
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 860

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#downstream_scopesArray<String>

This scopes whose upstream_scopes contain the current scope. The scope name should be in the form: projects/p/locations/gloobal/scopes/s`Wherep is the project,sis a valid Scope in this project.pWILL match the Feature's project. Corresponds to the JSON propertydownstreamScopes`

Returns:

  • (Array<String>)


845
846
847
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 845

def downstream_scopes
  @downstream_scopes
end

#gke_stateGoogle::Apis::GkehubV1alpha::ClusterUpgradeGkeUpgradeFeatureState

GKEUpgradeFeatureState contains feature states for GKE clusters in the scope. Corresponds to the JSON property gkeState



850
851
852
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 850

def gke_state
  @gke_state
end

#ignoredHash<String,Google::Apis::GkehubV1alpha::ClusterUpgradeIgnoredMembership>

A list of memberships ignored by the feature. For example, manually upgraded clusters can be ignored if they are newer than the default versions of its release channel. The membership resource is in the format: projects/p/ locations/l/membership/m`. Corresponds to the JSON propertyignored`



858
859
860
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 858

def ignored
  @ignored
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



865
866
867
868
869
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 865

def update!(**args)
  @downstream_scopes = args[:downstream_scopes] if args.key?(:downstream_scopes)
  @gke_state = args[:gke_state] if args.key?(:gke_state)
  @ignored = args[:ignored] if args.key?(:ignored)
end