Class: Google::Apis::GkehubV1alpha::CommonFeatureSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

CommonFeatureSpec contains Fleet-wide configuration information

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommonFeatureSpec

Returns a new instance of CommonFeatureSpec.



967
968
969
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 967

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appdevexperienceGoogle::Apis::GkehubV1alpha::AppDevExperienceFeatureSpec

Spec for App Dev Experience Feature. Corresponds to the JSON property appdevexperience



910
911
912
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 910

def appdevexperience
  @appdevexperience
end

#cloudauditloggingGoogle::Apis::GkehubV1alpha::CloudAuditLoggingFeatureSpec

Cloud Audit Logging: Spec for Audit Logging Allowlisting. Corresponds to the JSON property cloudauditlogging



915
916
917
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 915

def cloudauditlogging
  @cloudauditlogging
end

#clusterupgradeGoogle::Apis::GkehubV1alpha::ClusterUpgradeFleetSpec

ClusterUpgrade: The configuration for the fleet-level ClusterUpgrade feature. Corresponds to the JSON property clusterupgrade



921
922
923
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 921

def clusterupgrade
  @clusterupgrade
end

#dataplanev2Google::Apis::GkehubV1alpha::DataplaneV2FeatureSpec

Dataplane V2: Spec Corresponds to the JSON property dataplanev2



926
927
928
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 926

def dataplanev2
  @dataplanev2
end

#fleetobservabilityGoogle::Apis::GkehubV1alpha::FleetObservabilityFeatureSpec

Fleet Observability: The Hub-wide input for the FleetObservability feature. Corresponds to the JSON property fleetobservability



931
932
933
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 931

def fleetobservability
  @fleetobservability
end

#meshGoogle::Apis::GkehubV1alpha::ServiceMeshFeatureSpec

Service Mesh: Spec for the fleet for the servicemesh feature Corresponds to the JSON property mesh



936
937
938
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 936

def mesh
  @mesh
end

#multiclusteringressGoogle::Apis::GkehubV1alpha::MultiClusterIngressFeatureSpec

Multi-cluster Ingress: The configuration for the MultiClusterIngress feature. Corresponds to the JSON property multiclusteringress



942
943
944
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 942

def multiclusteringress
  @multiclusteringress
end

#namespaceactuationGoogle::Apis::GkehubV1alpha::NamespaceActuationFeatureSpec

An empty spec for actuation feature. This is required since Feature proto requires a spec. Corresponds to the JSON property namespaceactuation



948
949
950
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 948

def namespaceactuation
  @namespaceactuation
end

#rbacrolebindingactuationGoogle::Apis::GkehubV1alpha::RbacRoleBindingActuationFeatureSpec

RBAC RoleBinding Actuation: The Hub-wide input for the RBACRoleBindingActuation feature. Corresponds to the JSON property rbacrolebindingactuation



954
955
956
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 954

def rbacrolebindingactuation
  @rbacrolebindingactuation
end

#workloadcertificateGoogle::Apis::GkehubV1alpha::FeatureSpec

Workload Certificate: The Hub-wide input for the WorkloadCertificate feature. Corresponds to the JSON property workloadcertificate



960
961
962
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 960

def workloadcertificate
  @workloadcertificate
end

#workloadidentityGoogle::Apis::GkehubV1alpha::WorkloadIdentityFeatureSpec

WorkloadIdentity: Global feature specification. Corresponds to the JSON property workloadidentity



965
966
967
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 965

def workloadidentity
  @workloadidentity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



972
973
974
975
976
977
978
979
980
981
982
983
984
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 972

def update!(**args)
  @appdevexperience = args[:appdevexperience] if args.key?(:appdevexperience)
  @cloudauditlogging = args[:cloudauditlogging] if args.key?(:cloudauditlogging)
  @clusterupgrade = args[:clusterupgrade] if args.key?(:clusterupgrade)
  @dataplanev2 = args[:dataplanev2] if args.key?(:dataplanev2)
  @fleetobservability = args[:fleetobservability] if args.key?(:fleetobservability)
  @mesh = args[:mesh] if args.key?(:mesh)
  @multiclusteringress = args[:multiclusteringress] if args.key?(:multiclusteringress)
  @namespaceactuation = args[:namespaceactuation] if args.key?(:namespaceactuation)
  @rbacrolebindingactuation = args[:rbacrolebindingactuation] if args.key?(:rbacrolebindingactuation)
  @workloadcertificate = args[:workloadcertificate] if args.key?(:workloadcertificate)
  @workloadidentity = args[:workloadidentity] if args.key?(:workloadidentity)
end