Class: Google::Apis::GkehubV1alpha::ConfigManagementConfigSyncDeploymentState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

The state of ConfigSync's deployment on a cluster

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementConfigSyncDeploymentState

Returns a new instance of ConfigManagementConfigSyncDeploymentState.



1340
1341
1342
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1340

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admission_webhookString

Deployment state of admission-webhook Corresponds to the JSON property admissionWebhook

Returns:

  • (String)


1298
1299
1300
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1298

def admission_webhook
  @admission_webhook
end

#git_syncString

Deployment state of the git-sync pod Corresponds to the JSON property gitSync

Returns:

  • (String)


1303
1304
1305
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1303

def git_sync
  @git_sync
end

#importerString

Deployment state of the importer pod Corresponds to the JSON property importer

Returns:

  • (String)


1308
1309
1310
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1308

def importer
  @importer
end

#monitorString

Deployment state of the monitor pod Corresponds to the JSON property monitor

Returns:

  • (String)


1313
1314
1315
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1313

def monitor
  @monitor
end

#otel_collectorString

Deployment state of otel-collector Corresponds to the JSON property otelCollector

Returns:

  • (String)


1318
1319
1320
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1318

def otel_collector
  @otel_collector
end

#reconciler_managerString

Deployment state of reconciler-manager pod Corresponds to the JSON property reconcilerManager

Returns:

  • (String)


1323
1324
1325
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1323

def reconciler_manager
  @reconciler_manager
end

#resource_group_controller_managerString

Deployment state of resource-group-controller-manager Corresponds to the JSON property resourceGroupControllerManager

Returns:

  • (String)


1328
1329
1330
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1328

def resource_group_controller_manager
  @resource_group_controller_manager
end

#root_reconcilerString

Deployment state of root-reconciler Corresponds to the JSON property rootReconciler

Returns:

  • (String)


1333
1334
1335
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1333

def root_reconciler
  @root_reconciler
end

#syncerString

Deployment state of the syncer pod Corresponds to the JSON property syncer

Returns:

  • (String)


1338
1339
1340
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1338

def syncer
  @syncer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1345

def update!(**args)
  @admission_webhook = args[:admission_webhook] if args.key?(:admission_webhook)
  @git_sync = args[:git_sync] if args.key?(:git_sync)
  @importer = args[:importer] if args.key?(:importer)
  @monitor = args[:monitor] if args.key?(:monitor)
  @otel_collector = args[:otel_collector] if args.key?(:otel_collector)
  @reconciler_manager = args[:reconciler_manager] if args.key?(:reconciler_manager)
  @resource_group_controller_manager = args[:resource_group_controller_manager] if args.key?(:resource_group_controller_manager)
  @root_reconciler = args[:root_reconciler] if args.key?(:root_reconciler)
  @syncer = args[:syncer] if args.key?(:syncer)
end