Class: Google::Apis::GkehubV1alpha::ConfigManagementConfigSyncState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

State information for ConfigSync

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementConfigSyncState

Returns a new instance of ConfigManagementConfigSyncState.



1428
1429
1430
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_level_stop_syncing_stateString

Output only. Whether syncing resources to the cluster is stopped at the cluster level. Corresponds to the JSON property clusterLevelStopSyncingState

Returns:

  • (String)


1385
1386
1387
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1385

def cluster_level_stop_syncing_state
  @cluster_level_stop_syncing_state
end

#cr_countFixnum

Output only. The number of RootSync and RepoSync CRs in the cluster. Corresponds to the JSON property crCount

Returns:

  • (Fixnum)


1390
1391
1392
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1390

def cr_count
  @cr_count
end

#deployment_stateGoogle::Apis::GkehubV1alpha::ConfigManagementConfigSyncDeploymentState

The state of ConfigSync's deployment on a cluster Corresponds to the JSON property deploymentState



1395
1396
1397
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1395

def deployment_state
  @deployment_state
end

#errorsArray<Google::Apis::GkehubV1alpha::ConfigManagementConfigSyncError>

Output only. Errors pertaining to the installation of Config Sync. Corresponds to the JSON property errors



1400
1401
1402
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1400

def errors
  @errors
end

#reposync_crdString

Output only. The state of the Reposync CRD Corresponds to the JSON property reposyncCrd

Returns:

  • (String)


1405
1406
1407
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1405

def reposync_crd
  @reposync_crd
end

#rootsync_crdString

Output only. The state of the RootSync CRD Corresponds to the JSON property rootsyncCrd

Returns:

  • (String)


1410
1411
1412
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1410

def rootsync_crd
  @rootsync_crd
end

#stateString

Output only. The state of CS This field summarizes the other fields in this message. Corresponds to the JSON property state

Returns:

  • (String)


1416
1417
1418
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1416

def state
  @state
end

#sync_stateGoogle::Apis::GkehubV1alpha::ConfigManagementSyncState

State indicating an ACM's progress syncing configurations to a cluster Corresponds to the JSON property syncState



1421
1422
1423
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1421

def sync_state
  @sync_state
end

#versionGoogle::Apis::GkehubV1alpha::ConfigManagementConfigSyncVersion

Specific versioning information pertaining to ConfigSync's Pods Corresponds to the JSON property version



1426
1427
1428
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1426

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1433

def update!(**args)
  @cluster_level_stop_syncing_state = args[:cluster_level_stop_syncing_state] if args.key?(:cluster_level_stop_syncing_state)
  @cr_count = args[:cr_count] if args.key?(:cr_count)
  @deployment_state = args[:deployment_state] if args.key?(:deployment_state)
  @errors = args[:errors] if args.key?(:errors)
  @reposync_crd = args[:reposync_crd] if args.key?(:reposync_crd)
  @rootsync_crd = args[:rootsync_crd] if args.key?(:rootsync_crd)
  @state = args[:state] if args.key?(:state)
  @sync_state = args[:sync_state] if args.key?(:sync_state)
  @version = args[:version] if args.key?(:version)
end