Class: Google::Apis::GkehubV1alpha::ConfigManagementConfigSyncVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Specific versioning information pertaining to ConfigSync's Pods

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementConfigSyncVersion

Returns a new instance of ConfigManagementConfigSyncVersion.



1481
1482
1483
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1481

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admission_webhookString

Version of the deployed admission-webhook pod Corresponds to the JSON property admissionWebhook

Returns:

  • (String)


1439
1440
1441
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1439

def admission_webhook
  @admission_webhook
end

#git_syncString

Version of the deployed git-sync pod Corresponds to the JSON property gitSync

Returns:

  • (String)


1444
1445
1446
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1444

def git_sync
  @git_sync
end

#importerString

Version of the deployed importer pod Corresponds to the JSON property importer

Returns:

  • (String)


1449
1450
1451
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1449

def importer
  @importer
end

#monitorString

Version of the deployed monitor pod Corresponds to the JSON property monitor

Returns:

  • (String)


1454
1455
1456
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1454

def monitor
  @monitor
end

#otel_collectorString

Version of the deployed otel-collector pod Corresponds to the JSON property otelCollector

Returns:

  • (String)


1459
1460
1461
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1459

def otel_collector
  @otel_collector
end

#reconciler_managerString

Version of the deployed reconciler-manager pod Corresponds to the JSON property reconcilerManager

Returns:

  • (String)


1464
1465
1466
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1464

def reconciler_manager
  @reconciler_manager
end

#resource_group_controller_managerString

Version of the deployed resource-group-controller-manager pod Corresponds to the JSON property resourceGroupControllerManager

Returns:

  • (String)


1469
1470
1471
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1469

def resource_group_controller_manager
  @resource_group_controller_manager
end

#root_reconcilerString

Version of the deployed reconciler container in root-reconciler pod Corresponds to the JSON property rootReconciler

Returns:

  • (String)


1474
1475
1476
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1474

def root_reconciler
  @root_reconciler
end

#syncerString

Version of the deployed syncer pod Corresponds to the JSON property syncer

Returns:

  • (String)


1479
1480
1481
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1479

def syncer
  @syncer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1486

def update!(**args)
  @admission_webhook = args[:admission_webhook] if args.key?(:admission_webhook)
  @git_sync = args[:git_sync] if args.key?(:git_sync)
  @importer = args[:importer] if args.key?(:importer)
  @monitor = args[:monitor] if args.key?(:monitor)
  @otel_collector = args[:otel_collector] if args.key?(:otel_collector)
  @reconciler_manager = args[:reconciler_manager] if args.key?(:reconciler_manager)
  @resource_group_controller_manager = args[:resource_group_controller_manager] if args.key?(:resource_group_controller_manager)
  @root_reconciler = args[:root_reconciler] if args.key?(:root_reconciler)
  @syncer = args[:syncer] if args.key?(:syncer)
end