Class: Google::Apis::GkehubV1alpha::ConfigManagementDeploymentOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Configuration for a deployment override.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementDeploymentOverride

Returns a new instance of ConfigManagementDeploymentOverride.



1583
1584
1585
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containersArray<Google::Apis::GkehubV1alpha::ConfigManagementContainerOverride>

Optional. The containers of the deployment resource to be overridden. Corresponds to the JSON property containers



1571
1572
1573
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1571

def containers
  @containers
end

#deployment_nameString

Required. The name of the deployment resource to be overridden. Corresponds to the JSON property deploymentName

Returns:

  • (String)


1576
1577
1578
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1576

def deployment_name
  @deployment_name
end

#deployment_namespaceString

Required. The namespace of the deployment resource to be overridden. Corresponds to the JSON property deploymentNamespace

Returns:

  • (String)


1581
1582
1583
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1581

def deployment_namespace
  @deployment_namespace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1588
1589
1590
1591
1592
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1588

def update!(**args)
  @containers = args[:containers] if args.key?(:containers)
  @deployment_name = args[:deployment_name] if args.key?(:deployment_name)
  @deployment_namespace = args[:deployment_namespace] if args.key?(:deployment_namespace)
end