Class: Google::Apis::GkehubV1alpha::ConfigManagementErrorResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Model for a config file in the git repo with an associated Sync error

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementErrorResource

Returns a new instance of ConfigManagementErrorResource.



1619
1620
1621
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1619

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_gvkGoogle::Apis::GkehubV1alpha::ConfigManagementGroupVersionKind

A Kubernetes object's GVK Corresponds to the JSON property resourceGvk



1602
1603
1604
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1602

def resource_gvk
  @resource_gvk
end

#resource_nameString

Metadata name of the resource that is causing an error Corresponds to the JSON property resourceName

Returns:

  • (String)


1607
1608
1609
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1607

def resource_name
  @resource_name
end

#resource_namespaceString

Namespace of the resource that is causing an error Corresponds to the JSON property resourceNamespace

Returns:

  • (String)


1612
1613
1614
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1612

def resource_namespace
  @resource_namespace
end

#source_pathString

Path in the git repo of the erroneous config Corresponds to the JSON property sourcePath

Returns:

  • (String)


1617
1618
1619
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1617

def source_path
  @source_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1624
1625
1626
1627
1628
1629
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1624

def update!(**args)
  @resource_gvk = args[:resource_gvk] if args.key?(:resource_gvk)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @resource_namespace = args[:resource_namespace] if args.key?(:resource_namespace)
  @source_path = args[:source_path] if args.key?(:source_path)
end