Class: Google::Apis::GkehubV1alpha::ConfigManagementGitConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Git repo configuration for a single cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementGitConfig

Returns a new instance of ConfigManagementGitConfig.



1685
1686
1687
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1685

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcp_service_account_emailString

Optional. The Google Cloud Service Account Email used for auth when secret_type is gcpserviceaccount. Corresponds to the JSON property gcpServiceAccountEmail

Returns:

  • (String)


1644
1645
1646
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1644

def 
  @gcp_service_account_email
end

#https_proxyString

Optional. URL for the HTTPS proxy to be used when communicating with the Git repo. Only specify when secret_type is cookiefile, token, or none. Corresponds to the JSON property httpsProxy

Returns:

  • (String)


1650
1651
1652
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1650

def https_proxy
  @https_proxy
end

#policy_dirString

Optional. The path within the Git repository that represents the top level of the repo to sync. Default: the root directory of the repository. Corresponds to the JSON property policyDir

Returns:

  • (String)


1656
1657
1658
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1656

def policy_dir
  @policy_dir
end

#secret_typeString

Required. Type of secret configured for access to the Git repo. Must be one of ssh, cookiefile, gcenode, token, gcpserviceaccount, githubapp or none. The validation of this is case-sensitive. Corresponds to the JSON property secretType

Returns:

  • (String)


1663
1664
1665
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1663

def secret_type
  @secret_type
end

#sync_branchString

Optional. The branch of the repository to sync from. Default: master. Corresponds to the JSON property syncBranch

Returns:

  • (String)


1668
1669
1670
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1668

def sync_branch
  @sync_branch
end

#sync_repoString

Required. The URL of the Git repository to use as the source of truth. Corresponds to the JSON property syncRepo

Returns:

  • (String)


1673
1674
1675
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1673

def sync_repo
  @sync_repo
end

#sync_revString

Optional. Git revision (tag or hash) to check out. Default HEAD. Corresponds to the JSON property syncRev

Returns:

  • (String)


1678
1679
1680
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1678

def sync_rev
  @sync_rev
end

#sync_wait_secsFixnum

Optional. Period in seconds between consecutive syncs. Default: 15. Corresponds to the JSON property syncWaitSecs

Returns:

  • (Fixnum)


1683
1684
1685
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1683

def sync_wait_secs
  @sync_wait_secs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1690

def update!(**args)
  @gcp_service_account_email = args[:gcp_service_account_email] if args.key?(:gcp_service_account_email)
  @https_proxy = args[:https_proxy] if args.key?(:https_proxy)
  @policy_dir = args[:policy_dir] if args.key?(:policy_dir)
  @secret_type = args[:secret_type] if args.key?(:secret_type)
  @sync_branch = args[:sync_branch] if args.key?(:sync_branch)
  @sync_repo = args[:sync_repo] if args.key?(:sync_repo)
  @sync_rev = args[:sync_rev] if args.key?(:sync_rev)
  @sync_wait_secs = args[:sync_wait_secs] if args.key?(:sync_wait_secs)
end