Class: Google::Apis::GkehubV1alpha::ConfigManagementPolicyController
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ConfigManagementPolicyController
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Configuration for Policy Controller
Instance Attribute Summary collapse
-
#audit_interval_seconds ⇒ Fixnum
Sets the interval for Policy Controller Audit Scans (in seconds).
-
#enabled ⇒ Boolean
(also: #enabled?)
Enables the installation of Policy Controller.
-
#exemptable_namespaces ⇒ Array<String>
The set of namespaces that are excluded from Policy Controller checks.
-
#log_denies_enabled ⇒ Boolean
(also: #log_denies_enabled?)
Logs all denies and dry run failures.
-
#monitoring ⇒ Google::Apis::GkehubV1alpha::ConfigManagementPolicyControllerMonitoring
PolicyControllerMonitoring specifies the backends Policy Controller should export metrics to.
-
#mutation_enabled ⇒ Boolean
(also: #mutation_enabled?)
Enable or disable mutation in policy controller.
-
#referential_rules_enabled ⇒ Boolean
(also: #referential_rules_enabled?)
Enables the ability to use Constraint Templates that reference to objects other than the object currently being evaluated.
-
#template_library_installed ⇒ Boolean
(also: #template_library_installed?)
Installs the default template library along with Policy Controller.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementPolicyController
constructor
A new instance of ConfigManagementPolicyController.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementPolicyController
Returns a new instance of ConfigManagementPolicyController.
2131 2132 2133 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2131 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audit_interval_seconds ⇒ Fixnum
Sets the interval for Policy Controller Audit Scans (in seconds). When set to
0, this disables audit functionality altogether.
Corresponds to the JSON property auditIntervalSeconds
2078 2079 2080 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2078 def audit_interval_seconds @audit_interval_seconds end |
#enabled ⇒ Boolean Also known as: enabled?
Enables the installation of Policy Controller. If false, the rest of
PolicyController fields take no effect.
Corresponds to the JSON property enabled
2084 2085 2086 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2084 def enabled @enabled end |
#exemptable_namespaces ⇒ Array<String>
The set of namespaces that are excluded from Policy Controller checks.
Namespaces do not need to currently exist on the cluster.
Corresponds to the JSON property exemptableNamespaces
2091 2092 2093 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2091 def exemptable_namespaces @exemptable_namespaces end |
#log_denies_enabled ⇒ Boolean Also known as: log_denies_enabled?
Logs all denies and dry run failures.
Corresponds to the JSON property logDeniesEnabled
2096 2097 2098 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2096 def log_denies_enabled @log_denies_enabled end |
#monitoring ⇒ Google::Apis::GkehubV1alpha::ConfigManagementPolicyControllerMonitoring
PolicyControllerMonitoring specifies the backends Policy Controller should
export metrics to. For example, to specify metrics should be exported to Cloud
Monitoring and Prometheus, specify backends: ["cloudmonitoring", "prometheus"]
Corresponds to the JSON property monitoring
2104 2105 2106 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2104 def monitoring @monitoring end |
#mutation_enabled ⇒ Boolean Also known as: mutation_enabled?
Enable or disable mutation in policy controller. If true, mutation CRDs,
webhook and controller deployment will be deployed to the cluster.
Corresponds to the JSON property mutationEnabled
2110 2111 2112 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2110 def mutation_enabled @mutation_enabled end |
#referential_rules_enabled ⇒ Boolean Also known as: referential_rules_enabled?
Enables the ability to use Constraint Templates that reference to objects
other than the object currently being evaluated.
Corresponds to the JSON property referentialRulesEnabled
2117 2118 2119 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2117 def referential_rules_enabled @referential_rules_enabled end |
#template_library_installed ⇒ Boolean Also known as: template_library_installed?
Installs the default template library along with Policy Controller.
Corresponds to the JSON property templateLibraryInstalled
2123 2124 2125 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2123 def template_library_installed @template_library_installed end |
#update_time ⇒ String
Output only. Last time this membership spec was updated.
Corresponds to the JSON property updateTime
2129 2130 2131 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2129 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2136 def update!(**args) @audit_interval_seconds = args[:audit_interval_seconds] if args.key?(:audit_interval_seconds) @enabled = args[:enabled] if args.key?(:enabled) @exemptable_namespaces = args[:exemptable_namespaces] if args.key?(:exemptable_namespaces) @log_denies_enabled = args[:log_denies_enabled] if args.key?(:log_denies_enabled) @monitoring = args[:monitoring] if args.key?(:monitoring) @mutation_enabled = args[:mutation_enabled] if args.key?(:mutation_enabled) @referential_rules_enabled = args[:referential_rules_enabled] if args.key?(:referential_rules_enabled) @template_library_installed = args[:template_library_installed] if args.key?(:template_library_installed) @update_time = args[:update_time] if args.key?(:update_time) end |