Class: Google::Apis::GkehubV1alpha::ConfigManagementPolicyControllerMigration
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ConfigManagementPolicyControllerMigration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
State for the migration of PolicyController from ACM -> PoCo Hub.
Instance Attribute Summary collapse
-
#copy_time ⇒ String
Last time this membership spec was copied to PoCo feature.
-
#stage ⇒ String
Stage of the migration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementPolicyControllerMigration
constructor
A new instance of ConfigManagementPolicyControllerMigration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementPolicyControllerMigration
Returns a new instance of ConfigManagementPolicyControllerMigration.
2115 2116 2117 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#copy_time ⇒ String
Last time this membership spec was copied to PoCo feature.
Corresponds to the JSON property copyTime
2108 2109 2110 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2108 def copy_time @copy_time end |
#stage ⇒ String
Stage of the migration.
Corresponds to the JSON property stage
2113 2114 2115 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2113 def stage @stage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2120 2121 2122 2123 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2120 def update!(**args) @copy_time = args[:copy_time] if args.key?(:copy_time) @stage = args[:stage] if args.key?(:stage) end |