Class: Google::Apis::GkehubV1alpha::ConfigManagementPolicyControllerState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ConfigManagementPolicyControllerState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
State for PolicyControllerState.
Instance Attribute Summary collapse
-
#deployment_state ⇒ Google::Apis::GkehubV1alpha::ConfigManagementGatekeeperDeploymentState
State of Policy Controller installation.
-
#migration ⇒ Google::Apis::GkehubV1alpha::ConfigManagementPolicyControllerMigration
State for the migration of PolicyController from ACM -> PoCo Hub.
-
#version ⇒ Google::Apis::GkehubV1alpha::ConfigManagementPolicyControllerVersion
The build version of Gatekeeper Policy Controller is using.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementPolicyControllerState
constructor
A new instance of ConfigManagementPolicyControllerState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementPolicyControllerState
Returns a new instance of ConfigManagementPolicyControllerState.
2242 2243 2244 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2242 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment_state ⇒ Google::Apis::GkehubV1alpha::ConfigManagementGatekeeperDeploymentState
State of Policy Controller installation.
Corresponds to the JSON property deploymentState
2230 2231 2232 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2230 def deployment_state @deployment_state end |
#migration ⇒ Google::Apis::GkehubV1alpha::ConfigManagementPolicyControllerMigration
State for the migration of PolicyController from ACM -> PoCo Hub.
Corresponds to the JSON property migration
2235 2236 2237 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2235 def migration @migration end |
#version ⇒ Google::Apis::GkehubV1alpha::ConfigManagementPolicyControllerVersion
The build version of Gatekeeper Policy Controller is using.
Corresponds to the JSON property version
2240 2241 2242 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2240 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2247 2248 2249 2250 2251 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2247 def update!(**args) @deployment_state = args[:deployment_state] if args.key?(:deployment_state) @migration = args[:migration] if args.key?(:migration) @version = args[:version] if args.key?(:version) end |