Class: Google::Apis::GkehubV1alpha::ConnectAgentResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

ConnectAgentResource represents a Kubernetes resource manifest for Connect Agent deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectAgentResource

Returns a new instance of ConnectAgentResource.



2353
2354
2355
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2353

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#manifestString

YAML manifest of the resource. Corresponds to the JSON property manifest

Returns:

  • (String)


2345
2346
2347
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2345

def manifest
  @manifest
end

#typeGoogle::Apis::GkehubV1alpha::TypeMeta

TypeMeta is the type information needed for content unmarshalling of Kubernetes resources in the manifest. Corresponds to the JSON property type



2351
2352
2353
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2351

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2358
2359
2360
2361
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2358

def update!(**args)
  @manifest = args[:manifest] if args.key?(:manifest)
  @type = args[:type] if args.key?(:type)
end