Class: Google::Apis::GkehubV1alpha::DefaultClusterConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

DefaultClusterConfig describes the default cluster configurations to be applied to all clusters born-in-fleet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DefaultClusterConfig

Returns a new instance of DefaultClusterConfig.



2390
2391
2392
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2390

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#binary_authorization_configGoogle::Apis::GkehubV1alpha::BinaryAuthorizationConfig

BinaryAuthorizationConfig defines the fleet level configuration of binary authorization feature. Corresponds to the JSON property binaryAuthorizationConfig



2374
2375
2376
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2374

def binary_authorization_config
  @binary_authorization_config
end

#compliance_posture_configGoogle::Apis::GkehubV1alpha::CompliancePostureConfig

Deprecated: Compliance Posture is no longer supported. For more details, see https://cloud.google.com/kubernetes-engine/docs/deprecations/posture- management-deprecation. CompliancePostureConfig defines the settings needed to enable/disable features for the Compliance Posture. Corresponds to the JSON property compliancePostureConfig



2382
2383
2384
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2382

def compliance_posture_config
  @compliance_posture_config
end

#security_posture_configGoogle::Apis::GkehubV1alpha::SecurityPostureConfig

SecurityPostureConfig defines the flags needed to enable/disable features for the Security Posture API. Corresponds to the JSON property securityPostureConfig



2388
2389
2390
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2388

def security_posture_config
  @security_posture_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2395
2396
2397
2398
2399
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2395

def update!(**args)
  @binary_authorization_config = args[:binary_authorization_config] if args.key?(:binary_authorization_config)
  @compliance_posture_config = args[:compliance_posture_config] if args.key?(:compliance_posture_config)
  @security_posture_config = args[:security_posture_config] if args.key?(:security_posture_config)
end