Class: Google::Apis::GkehubV1alpha::Feature

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Feature represents the settings and status of any Fleet Feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Feature

Returns a new instance of Feature.



2649
2650
2651
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2649

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. When the Feature resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2549
2550
2551
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2549

def create_time
  @create_time
end

#delete_timeString

Output only. When the Feature resource was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


2554
2555
2556
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2554

def delete_time
  @delete_time
end

#fleet_default_member_configGoogle::Apis::GkehubV1alpha::CommonFleetDefaultMemberConfigSpec

CommonFleetDefaultMemberConfigSpec contains default configuration information for memberships of a fleet Corresponds to the JSON property fleetDefaultMemberConfig



2560
2561
2562
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2560

def fleet_default_member_config
  @fleet_default_member_config
end

#labelsHash<String,String>

Labels for this Feature. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2565
2566
2567
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2565

def labels
  @labels
end

#membership_specsHash<String,Google::Apis::GkehubV1alpha::MembershipFeatureSpec>

Optional. Membership-specific configuration for this Feature. If this Feature does not support any per-Membership configuration, this field may be unused. The keys indicate which Membership the configuration is for, in the form: projects/p/locations/l/memberships/m`Wherepis the project,lis a valid location andmis a valid Membership in this project at that location. pWILL match the Feature's project.pwill always be returned as the project number, but the project ID is also accepted during input. If the same Membership is specified in the map twice (using the project ID form, and the project number form), exactly ONE of the entries will be saved, with no guarantees as to which. For this reason, it is recommended the same format be used for all entries when mutating a Feature. Corresponds to the JSON propertymembershipSpecs`



2580
2581
2582
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2580

def membership_specs
  @membership_specs
end

#membership_statesHash<String,Google::Apis::GkehubV1alpha::MembershipFeatureState>

Output only. Membership-specific Feature status. If this Feature does report any per-Membership status, this field may be unused. The keys indicate which Membership the state is for, in the form: projects/p/locations/l/ memberships/m`Wherepis the project number,lis a valid location and mis a valid Membership in this project at that location.pMUST match the Feature's project number. Corresponds to the JSON propertymembershipStates`



2590
2591
2592
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2590

def membership_states
  @membership_states
end

#nameString

Output only. The full, unique name of this Feature resource in the format projects/*/locations/*/features/*. Corresponds to the JSON property name

Returns:

  • (String)


2596
2597
2598
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2596

def name
  @name
end

#resource_stateGoogle::Apis::GkehubV1alpha::FeatureResourceState

FeatureResourceState describes the state of a Feature resource in the GkeHub API. See FeatureState for the "running state" of the Feature in the Fleet and across Memberships. Corresponds to the JSON property resourceState



2603
2604
2605
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2603

def resource_state
  @resource_state
end

#scope_specsHash<String,Google::Apis::GkehubV1alpha::ScopeFeatureSpec>

Optional. Scope-specific configuration for this Feature. If this Feature does not support any per-Scope configuration, this field may be unused. The keys indicate which Scope the configuration is for, in the form: projects/p/ locations/global/scopes/s`Wherepis the project,sis a valid Scope in this project.pWILL match the Feature's project.pwill always be returned as the project number, but the project ID is also accepted during input. If the same Scope is specified in the map twice (using the project ID form, and the project number form), exactly ONE of the entries will be saved, with no guarantees as to which. For this reason, it is recommended the same format be used for all entries when mutating a Feature. Corresponds to the JSON propertyscopeSpecs`



2617
2618
2619
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2617

def scope_specs
  @scope_specs
end

#scope_statesHash<String,Google::Apis::GkehubV1alpha::ScopeFeatureState>

Output only. Scope-specific Feature status. If this Feature does report any per-Scope status, this field may be unused. The keys indicate which Scope the state is for, in the form: projects/p/locations/global/scopes/s`Wherep is the project,sis a valid Scope in this project.pWILL match the Feature's project. Corresponds to the JSON propertyscopeStates`



2626
2627
2628
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2626

def scope_states
  @scope_states
end

#specGoogle::Apis::GkehubV1alpha::CommonFeatureSpec

CommonFeatureSpec contains Fleet-wide configuration information Corresponds to the JSON property spec



2631
2632
2633
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2631

def spec
  @spec
end

#stateGoogle::Apis::GkehubV1alpha::CommonFeatureState

CommonFeatureState contains Fleet-wide Feature status information. Corresponds to the JSON property state



2636
2637
2638
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2636

def state
  @state
end

#unreachableArray<String>

Output only. List of locations that could not be reached while fetching this feature. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2642
2643
2644
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2642

def unreachable
  @unreachable
end

#update_timeString

Output only. When the Feature resource was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2647
2648
2649
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2647

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
2666
2667
2668
2669
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2654

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @fleet_default_member_config = args[:fleet_default_member_config] if args.key?(:fleet_default_member_config)
  @labels = args[:labels] if args.key?(:labels)
  @membership_specs = args[:membership_specs] if args.key?(:membership_specs)
  @membership_states = args[:membership_states] if args.key?(:membership_states)
  @name = args[:name] if args.key?(:name)
  @resource_state = args[:resource_state] if args.key?(:resource_state)
  @scope_specs = args[:scope_specs] if args.key?(:scope_specs)
  @scope_states = args[:scope_states] if args.key?(:scope_states)
  @spec = args[:spec] if args.key?(:spec)
  @state = args[:state] if args.key?(:state)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
  @update_time = args[:update_time] if args.key?(:update_time)
end