Class: Google::Apis::GkehubV1alpha::FleetObservabilityFleetObservabilityBaseFeatureState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::FleetObservabilityFleetObservabilityBaseFeatureState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Base state for fleet observability feature.
Instance Attribute Summary collapse
-
#code ⇒ String
The high-level, machine-readable status of this Feature.
-
#errors ⇒ Array<Google::Apis::GkehubV1alpha::FleetObservabilityFeatureError>
Errors after reconciling the monitoring and logging feature if the code is not OK.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FleetObservabilityFleetObservabilityBaseFeatureState
constructor
A new instance of FleetObservabilityFleetObservabilityBaseFeatureState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FleetObservabilityFleetObservabilityBaseFeatureState
Returns a new instance of FleetObservabilityFleetObservabilityBaseFeatureState.
2931 2932 2933 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2931 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The high-level, machine-readable status of this Feature.
Corresponds to the JSON property code
2923 2924 2925 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2923 def code @code end |
#errors ⇒ Array<Google::Apis::GkehubV1alpha::FleetObservabilityFeatureError>
Errors after reconciling the monitoring and logging feature if the code is not
OK.
Corresponds to the JSON property errors
2929 2930 2931 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2929 def errors @errors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2936 2937 2938 2939 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2936 def update!(**args) @code = args[:code] if args.key?(:code) @errors = args[:errors] if args.key?(:errors) end |