Class: Google::Apis::GkehubV1alpha::GenerateExclusivityManifestResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

The response of the exclusivity artifacts manifests for the client to apply.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateExclusivityManifestResponse

Returns a new instance of GenerateExclusivityManifestResponse.



3046
3047
3048
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3046

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cr_manifestString

The YAML manifest of the membership CR to apply if a new version of the CR is available. Empty if no update needs to be applied. Corresponds to the JSON property crManifest

Returns:

  • (String)


3038
3039
3040
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3038

def cr_manifest
  @cr_manifest
end

#crd_manifestString

The YAML manifest of the membership CRD to apply if a newer version of the CRD is available. Empty if no update needs to be applied. Corresponds to the JSON property crdManifest

Returns:

  • (String)


3044
3045
3046
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3044

def crd_manifest
  @crd_manifest
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3051
3052
3053
3054
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3051

def update!(**args)
  @cr_manifest = args[:cr_manifest] if args.key?(:cr_manifest)
  @crd_manifest = args[:crd_manifest] if args.key?(:crd_manifest)
end