Class: Google::Apis::GkehubV1alpha::IdentityServiceAzureAdConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Configuration for the AzureAD Auth flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceAzureAdConfig

Returns a new instance of IdentityServiceAzureAdConfig.



3265
3266
3267
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

ID for the registered client application that makes authentication requests to the Azure AD identity provider. Corresponds to the JSON property clientId

Returns:

  • (String)


3230
3231
3232
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3230

def client_id
  @client_id
end

#client_secretString

Input only. Unencrypted AzureAD client secret will be passed to the GKE Hub CLH. Corresponds to the JSON property clientSecret

Returns:

  • (String)


3236
3237
3238
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3236

def client_secret
  @client_secret
end

#encrypted_client_secretString

Output only. Encrypted AzureAD client secret. Corresponds to the JSON property encryptedClientSecret NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3242
3243
3244
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3242

def encrypted_client_secret
  @encrypted_client_secret
end

#group_formatString

Optional. Format of the AzureAD groups that the client wants for auth. Corresponds to the JSON property groupFormat

Returns:

  • (String)


3247
3248
3249
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3247

def group_format
  @group_format
end

#kubectl_redirect_uriString

The redirect URL that kubectl uses for authorization. Corresponds to the JSON property kubectlRedirectUri

Returns:

  • (String)


3252
3253
3254
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3252

def kubectl_redirect_uri
  @kubectl_redirect_uri
end

#tenantString

Kind of Azure AD account to be authenticated. Supported values are or for accounts belonging to a specific tenant. Corresponds to the JSON property tenant

Returns:

  • (String)


3258
3259
3260
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3258

def tenant
  @tenant
end

#user_claimString

Optional. Claim in the AzureAD ID Token that holds the user details. Corresponds to the JSON property userClaim

Returns:

  • (String)


3263
3264
3265
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3263

def user_claim
  @user_claim
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3270
3271
3272
3273
3274
3275
3276
3277
3278
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3270

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @encrypted_client_secret = args[:encrypted_client_secret] if args.key?(:encrypted_client_secret)
  @group_format = args[:group_format] if args.key?(:group_format)
  @kubectl_redirect_uri = args[:kubectl_redirect_uri] if args.key?(:kubectl_redirect_uri)
  @tenant = args[:tenant] if args.key?(:tenant)
  @user_claim = args[:user_claim] if args.key?(:user_claim)
end