Class: Google::Apis::GkehubV1alpha::IdentityServiceLdapConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::IdentityServiceLdapConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Configuration for the LDAP Auth flow.
Instance Attribute Summary collapse
-
#group ⇒ Google::Apis::GkehubV1alpha::IdentityServiceGroupConfig
Contains the properties for locating and authenticating groups in the directory.
-
#server ⇒ Google::Apis::GkehubV1alpha::IdentityServiceServerConfig
Server settings for the external LDAP server.
-
#service_account ⇒ Google::Apis::GkehubV1alpha::IdentityServiceServiceAccountConfig
Contains the credentials of the service account which is authorized to perform the LDAP search in the directory.
-
#user ⇒ Google::Apis::GkehubV1alpha::IdentityServiceUserConfig
Defines where users exist in the LDAP directory.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IdentityServiceLdapConfig
constructor
A new instance of IdentityServiceLdapConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IdentityServiceLdapConfig
Returns a new instance of IdentityServiceLdapConfig.
3464 3465 3466 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3464 def initialize(**args) update!(**args) end |
Instance Attribute Details
#group ⇒ Google::Apis::GkehubV1alpha::IdentityServiceGroupConfig
Contains the properties for locating and authenticating groups in the
directory.
Corresponds to the JSON property group
3445 3446 3447 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3445 def group @group end |
#server ⇒ Google::Apis::GkehubV1alpha::IdentityServiceServerConfig
Server settings for the external LDAP server.
Corresponds to the JSON property server
3450 3451 3452 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3450 def server @server end |
#service_account ⇒ Google::Apis::GkehubV1alpha::IdentityServiceServiceAccountConfig
Contains the credentials of the service account which is authorized to perform
the LDAP search in the directory. The credentials can be supplied by the
combination of the DN and password or the client certificate.
Corresponds to the JSON property serviceAccount
3457 3458 3459 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3457 def service_account @service_account end |
#user ⇒ Google::Apis::GkehubV1alpha::IdentityServiceUserConfig
Defines where users exist in the LDAP directory.
Corresponds to the JSON property user
3462 3463 3464 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3462 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3469 3470 3471 3472 3473 3474 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3469 def update!(**args) @group = args[:group] if args.key?(:group) @server = args[:server] if args.key?(:server) @service_account = args[:service_account] if args.key?(:service_account) @user = args[:user] if args.key?(:user) end |