Class: Google::Apis::GkehubV1alpha::IdentityServiceServiceAccountConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Contains the credentials of the service account which is authorized to perform the LDAP search in the directory. The credentials can be supplied by the combination of the DN and password or the client certificate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceServiceAccountConfig

Returns a new instance of IdentityServiceServiceAccountConfig.



3762
3763
3764
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#simple_bind_credentialsGoogle::Apis::GkehubV1alpha::IdentityServiceSimpleBindCredentials

The structure holds the LDAP simple binding credential. Corresponds to the JSON property simpleBindCredentials



3760
3761
3762
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3760

def simple_bind_credentials
  @simple_bind_credentials
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3767
3768
3769
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3767

def update!(**args)
  @simple_bind_credentials = args[:simple_bind_credentials] if args.key?(:simple_bind_credentials)
end