Class: Google::Apis::GkehubV1alpha::KubernetesResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

KubernetesResource contains the YAML manifests and configuration for Membership Kubernetes resources in the cluster. After CreateMembership or UpdateMembership, these resources should be re-applied in the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KubernetesResource

Returns a new instance of KubernetesResource.



3884
3885
3886
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3884

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connect_resourcesArray<Google::Apis::GkehubV1alpha::ResourceManifest>

Output only. The Kubernetes resources for installing the GKE Connect agent This field is only populated in the Membership returned from a successful long- running operation from CreateMembership or UpdateMembership. It is not populated during normal GetMembership or ListMemberships requests. To get the resource manifest after the initial registration, the caller should make a UpdateMembership call with an empty field mask. Corresponds to the JSON property connectResources



3856
3857
3858
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3856

def connect_resources
  @connect_resources
end

#membership_cr_manifestString

Input only. The YAML representation of the Membership CR. This field is ignored for GKE clusters where Hub can read the CR directly. Callers should provide the CR that is currently present in the cluster during CreateMembership or UpdateMembership, or leave this field empty if none exists. The CR manifest is used to validate the cluster has not been registered with another Membership. Corresponds to the JSON property membershipCrManifest

Returns:

  • (String)


3866
3867
3868
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3866

def membership_cr_manifest
  @membership_cr_manifest
end

#membership_resourcesArray<Google::Apis::GkehubV1alpha::ResourceManifest>

Output only. Additional Kubernetes resources that need to be applied to the cluster after Membership creation, and after every update. This field is only populated in the Membership returned from a successful long-running operation from CreateMembership or UpdateMembership. It is not populated during normal GetMembership or ListMemberships requests. To get the resource manifest after the initial registration, the caller should make a UpdateMembership call with an empty field mask. Corresponds to the JSON property membershipResources



3877
3878
3879
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3877

def membership_resources
  @membership_resources
end

#resource_optionsGoogle::Apis::GkehubV1alpha::ResourceOptions

ResourceOptions represent options for Kubernetes resource generation. Corresponds to the JSON property resourceOptions



3882
3883
3884
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3882

def resource_options
  @resource_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3889
3890
3891
3892
3893
3894
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3889

def update!(**args)
  @connect_resources = args[:connect_resources] if args.key?(:connect_resources)
  @membership_cr_manifest = args[:membership_cr_manifest] if args.key?(:membership_cr_manifest)
  @membership_resources = args[:membership_resources] if args.key?(:membership_resources)
  @resource_options = args[:resource_options] if args.key?(:resource_options)
end