Class: Google::Apis::GkehubV1alpha::ListFeaturesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Response message for the GkeHub.ListFeatures method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListFeaturesResponse

Returns a new instance of ListFeaturesResponse.



4046
4047
4048
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4046

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListFeatures method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4039
4040
4041
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4039

def next_page_token
  @next_page_token
end

#resourcesArray<Google::Apis::GkehubV1alpha::Feature>

The list of matching Features Corresponds to the JSON property resources



4044
4045
4046
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4044

def resources
  @resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4051
4052
4053
4054
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4051

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @resources = args[:resources] if args.key?(:resources)
end