Class: Google::Apis::GkehubV1alpha::ListMembershipsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Response message for the GkeHub.ListMemberships method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMembershipsResponse

Returns a new instance of ListMembershipsResponse.



4196
4197
4198
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4196

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListMemberships method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4184
4185
4186
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4184

def next_page_token
  @next_page_token
end

#resourcesArray<Google::Apis::GkehubV1alpha::Membership>

The list of matching Memberships. Corresponds to the JSON property resources



4189
4190
4191
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4189

def resources
  @resources
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4194
4195
4196
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4194

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4201
4202
4203
4204
4205
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4201

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @resources = args[:resources] if args.key?(:resources)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end