Class: Google::Apis::GkehubV1alpha::MembershipBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

MembershipBinding is a subresource of a Membership, representing what Fleet Scopes (or other, future Fleet resources) a Membership is bound to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipBinding

Returns a new instance of MembershipBinding.



4553
4554
4555
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4553

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. When the membership binding was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4513
4514
4515
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4513

def create_time
  @create_time
end

#delete_timeString

Output only. When the membership binding was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


4518
4519
4520
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4518

def delete_time
  @delete_time
end

#labelsHash<String,String>

Optional. Labels for this MembershipBinding. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4523
4524
4525
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4523

def labels
  @labels
end

#nameString

The resource name for the membershipbinding itself projects/project/ locations/location/memberships/membership/bindings/membershipbinding` Corresponds to the JSON propertyname`

Returns:

  • (String)


4529
4530
4531
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4529

def name
  @name
end

#scopeString

A Scope resource name in the format projects/*/locations/*/scopes/*. Corresponds to the JSON property scope

Returns:

  • (String)


4534
4535
4536
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4534

def scope
  @scope
end

#stateGoogle::Apis::GkehubV1alpha::MembershipBindingLifecycleState

MembershipBindingLifecycleState describes the state of a Binding resource. Corresponds to the JSON property state



4539
4540
4541
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4539

def state
  @state
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all membershipbinding resources. If a membershipbinding resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


4546
4547
4548
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4546

def uid
  @uid
end

#update_timeString

Output only. When the membership binding was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4551
4552
4553
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4551

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4558
4559
4560
4561
4562
4563
4564
4565
4566
4567
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4558

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @scope = args[:scope] if args.key?(:scope)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end