Class: Google::Apis::GkehubV1alpha::Namespace

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Namespace represents a namespace across the Fleet

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Namespace

Returns a new instance of Namespace.



5071
5072
5073
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. When the namespace was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5022
5023
5024
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5022

def create_time
  @create_time
end

#delete_timeString

Output only. When the namespace was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


5027
5028
5029
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5027

def delete_time
  @delete_time
end

#labelsHash<String,String>

Optional. Labels for this Namespace. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5032
5033
5034
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5032

def labels
  @labels
end

#nameString

The resource name for the namespace projects/project/locations/location/ namespaces/namespace` Corresponds to the JSON propertyname`

Returns:

  • (String)


5038
5039
5040
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5038

def name
  @name
end

#namespace_labelsHash<String,String>

Optional. Namespace-level cluster namespace labels. These labels are applied to the related namespace of the member clusters bound to the parent Scope. Scope-level labels (namespace_labels in the Fleet Scope resource) take precedence over Namespace-level labels if they share a key. Keys and values must be Kubernetes-conformant. Corresponds to the JSON property namespaceLabels

Returns:

  • (Hash<String,String>)


5047
5048
5049
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5047

def namespace_labels
  @namespace_labels
end

#scopeString

Required. Scope associated with the namespace Corresponds to the JSON property scope

Returns:

  • (String)


5052
5053
5054
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5052

def scope
  @scope
end

#stateGoogle::Apis::GkehubV1alpha::NamespaceLifecycleState

NamespaceLifecycleState describes the state of a Namespace resource. Corresponds to the JSON property state



5057
5058
5059
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5057

def state
  @state
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all namespace resources. If a namespace resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


5064
5065
5066
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5064

def uid
  @uid
end

#update_timeString

Output only. When the namespace was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5069
5070
5071
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5069

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5076

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @namespace_labels = args[:namespace_labels] if args.key?(:namespace_labels)
  @scope = args[:scope] if args.key?(:scope)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end