Class: Google::Apis::GkehubV1alpha::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



5333
5334
5335
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5333

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


5297
5298
5299
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5297

def api_version
  @api_version
end

#cancel_requestedBoolean Also known as: cancel_requested?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property cancelRequested

Returns:

  • (Boolean)


5305
5306
5307
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5305

def cancel_requested
  @cancel_requested
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5311
5312
5313
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5311

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


5316
5317
5318
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5316

def end_time
  @end_time
end

#status_detailString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusDetail

Returns:

  • (String)


5321
5322
5323
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5321

def status_detail
  @status_detail
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


5326
5327
5328
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5326

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


5331
5332
5333
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5331

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5338
5339
5340
5341
5342
5343
5344
5345
5346
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5338

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @cancel_requested = args[:cancel_requested] if args.key?(:cancel_requested)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @status_detail = args[:status_detail] if args.key?(:status_detail)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end