Class: Google::Apis::GkehubV1alpha::OperationalState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Operational state of the Rollout Sequence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationalState

Returns a new instance of OperationalState.



5399
5400
5401
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#reasonsArray<String>

Output only. Reasons for the Rollout Sequence state. Corresponds to the JSON property reasons

Returns:

  • (Array<String>)


5386
5387
5388
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5386

def reasons
  @reasons
end

#stateString

Output only. State of the Rollout Sequence. Corresponds to the JSON property state

Returns:

  • (String)


5391
5392
5393
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5391

def state
  @state
end

#state_change_timeString

Output only. The timestamp at which the operational state was last changed. Used to track how long it has been in the current state. Corresponds to the JSON property stateChangeTime

Returns:

  • (String)


5397
5398
5399
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5397

def state_change_time
  @state_change_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5404
5405
5406
5407
5408
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5404

def update!(**args)
  @reasons = args[:reasons] if args.key?(:reasons)
  @state = args[:state] if args.key?(:state)
  @state_change_time = args[:state_change_time] if args.key?(:state_change_time)
end