Class: Google::Apis::GkehubV1alpha::PolicyControllerMembershipState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Policy Controller: State for a single cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyControllerMembershipState

Returns a new instance of PolicyControllerMembershipState.



5734
5735
5736
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5734

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#component_statesHash<String,Google::Apis::GkehubV1alpha::PolicyControllerOnClusterState>

Currently these include (also serving as map keys): 1. "admission" 2. "audit"

  1. "mutation" Corresponds to the JSON property componentStates


5721
5722
5723
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5721

def component_states
  @component_states
end

#policy_content_stateGoogle::Apis::GkehubV1alpha::PolicyControllerPolicyContentState

The state of the policy controller policy content Corresponds to the JSON property policyContentState



5726
5727
5728
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5726

def policy_content_state
  @policy_content_state
end

#stateString

The overall Policy Controller lifecycle state observed by the Hub Feature controller. Corresponds to the JSON property state

Returns:

  • (String)


5732
5733
5734
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5732

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5739
5740
5741
5742
5743
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5739

def update!(**args)
  @component_states = args[:component_states] if args.key?(:component_states)
  @policy_content_state = args[:policy_content_state] if args.key?(:policy_content_state)
  @state = args[:state] if args.key?(:state)
end