Class: Google::Apis::GkehubV1alpha::PolicyControllerPolicyContentState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

The state of the policy controller policy content

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyControllerPolicyContentState

Returns a new instance of PolicyControllerPolicyContentState.



5727
5728
5729
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5727

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bundle_statesHash<String,Google::Apis::GkehubV1alpha::PolicyControllerOnClusterState>

The state of the any bundles included in the chosen version of the manifest Corresponds to the JSON property bundleStates



5715
5716
5717
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5715

def bundle_states
  @bundle_states
end

#referential_sync_config_stateGoogle::Apis::GkehubV1alpha::PolicyControllerOnClusterState

OnClusterState represents the state of a sub-component of Policy Controller. Corresponds to the JSON property referentialSyncConfigState



5720
5721
5722
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5720

def referential_sync_config_state
  @referential_sync_config_state
end

#template_library_stateGoogle::Apis::GkehubV1alpha::PolicyControllerOnClusterState

OnClusterState represents the state of a sub-component of Policy Controller. Corresponds to the JSON property templateLibraryState



5725
5726
5727
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5725

def template_library_state
  @template_library_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5732
5733
5734
5735
5736
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5732

def update!(**args)
  @bundle_states = args[:bundle_states] if args.key?(:bundle_states)
  @referential_sync_config_state = args[:referential_sync_config_state] if args.key?(:referential_sync_config_state)
  @template_library_state = args[:template_library_state] if args.key?(:template_library_state)
end