Class: Google::Apis::GkehubV1alpha::RbacRoleBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

RBACRoleBinding represents a rbacrolebinding across the Fleet

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RbacRoleBinding

Returns a new instance of RbacRoleBinding.



6064
6065
6066
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. When the rbacrolebinding was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6010
6011
6012
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6010

def create_time
  @create_time
end

#delete_timeString

Output only. When the rbacrolebinding was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


6015
6016
6017
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6015

def delete_time
  @delete_time
end

#groupString

group is the group, as seen by the kubernetes cluster. Corresponds to the JSON property group

Returns:

  • (String)


6020
6021
6022
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6020

def group
  @group
end

#labelsHash<String,String>

Optional. Labels for this RBACRolebinding. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6025
6026
6027
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6025

def labels
  @labels
end

#nameString

The resource name for the rbacrolebinding projects/project/locations/ location/scopes/scope/rbacrolebindings/rbacrolebindingor `projects/` project`/locations/`location`/memberships/`membership`/rbacrolebindings/` rbacrolebinding Corresponds to the JSON property name

Returns:

  • (String)


6033
6034
6035
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6033

def name
  @name
end

#roleGoogle::Apis::GkehubV1alpha::Role

Role is the type for Kubernetes roles Corresponds to the JSON property role



6038
6039
6040
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6038

def role
  @role
end

#stateGoogle::Apis::GkehubV1alpha::RbacRoleBindingLifecycleState

RBACRoleBindingLifecycleState describes the state of a RbacRoleBinding resource. Corresponds to the JSON property state



6044
6045
6046
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6044

def state
  @state
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all rbacrolebinding resources. If a rbacrolebinding resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


6051
6052
6053
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6051

def uid
  @uid
end

#update_timeString

Output only. When the rbacrolebinding was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6056
6057
6058
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6056

def update_time
  @update_time
end

#userString

user is the name of the user as seen by the kubernetes cluster, example "alice" or "alice@domain.tld" Corresponds to the JSON property user

Returns:

  • (String)


6062
6063
6064
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6062

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6069
6070
6071
6072
6073
6074
6075
6076
6077
6078
6079
6080
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6069

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @group = args[:group] if args.key?(:group)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @role = args[:role] if args.key?(:role)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user = args[:user] if args.key?(:user)
end