Class: Google::Apis::GkehubV1alpha::Rollout

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Rollout contains the Rollout metadata and configuration. Next ID: 31

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Rollout

Returns a new instance of Rollout.



6388
6389
6390
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6388

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#complete_timeString

Output only. The timestamp at which the Rollout was completed. Corresponds to the JSON property completeTime

Returns:

  • (String)


6271
6272
6273
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6271

def complete_time
  @complete_time
end

#create_timeString

Output only. The timestamp at which the Rollout was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6276
6277
6278
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6276

def create_time
  @create_time
end

#delete_timeString

Output only. The timestamp at the Rollout was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


6281
6282
6283
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6281

def delete_time
  @delete_time
end

#display_nameString

Optional. Human readable display name of the Rollout. Corresponds to the JSON property displayName

Returns:

  • (String)


6286
6287
6288
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6286

def display_name
  @display_name
end

#etagString

Output only. etag of the Rollout Ex. abc1234 Corresponds to the JSON property etag

Returns:

  • (String)


6291
6292
6293
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6291

def etag
  @etag
end

#ignore_cluster_disruption_budgetsBoolean Also known as: ignore_cluster_disruption_budgets?

Optional. If set to true, the rollout will ignore the disruption budgets of the clusters. Corresponds to the JSON property ignoreClusterDisruptionBudgets

Returns:

  • (Boolean)


6297
6298
6299
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6297

def ignore_cluster_disruption_budgets
  @ignore_cluster_disruption_budgets
end

#ignore_maintenance_policiesBoolean Also known as: ignore_maintenance_policies?

Optional. If set to true, the rollout will ignore any maintenance policies ( Maintenance Windows and Maintenance Exclusions) set on the clusters. Corresponds to the JSON property ignoreMaintenancePolicies

Returns:

  • (Boolean)


6304
6305
6306
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6304

def ignore_maintenance_policies
  @ignore_maintenance_policies
end

#intentString

Output only. The intent of the rollout. Corresponds to the JSON property intent

Returns:

  • (String)


6310
6311
6312
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6310

def intent
  @intent
end

#labelsHash<String,String>

Optional. Labels for this Rollout. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6315
6316
6317
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6315

def labels
  @labels
end

#membership_statesHash<String,Google::Apis::GkehubV1alpha::RolloutMembershipState>

Output only. States of upgrading control plane or node pool targets of a single cluster (GKE Hub membership) that's part of this Rollout. The key is the membership name of the cluster. The value is the state of the cluster. Corresponds to the JSON property membershipStates



6322
6323
6324
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6322

def membership_states
  @membership_states
end

#nameString

Identifier. The full, unique resource name of this Rollout in the format of projects/project/locations/global/rollouts/rollout`. Corresponds to the JSON propertyname`

Returns:

  • (String)


6328
6329
6330
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6328

def name
  @name
end

#rollout_sequenceString

Optional. Immutable. The full, unique resource name of the rollout sequence that initiatied this Rollout. In the format of projects/project/locations/ global/rolloutSequences/rollout_sequence`. Corresponds to the JSON propertyrolloutSequence`

Returns:

  • (String)


6335
6336
6337
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6335

def rollout_sequence
  @rollout_sequence
end

#stage_soak_duration_overridesHash<String,String>

Optional. Overrides the soak durations for specific stages of the rollout. Key is the stage number, value is the desired soak duration. Stages omitted from the map will receive the standard soak duration configured on the sequence for that stage. Corresponds to the JSON property stageSoakDurationOverrides

Returns:

  • (Hash<String,String>)


6343
6344
6345
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6343

def stage_soak_duration_overrides
  @stage_soak_duration_overrides
end

#stagesArray<Google::Apis::GkehubV1alpha::RolloutStage>

Output only. The stages of the Rollout. Corresponds to the JSON property stages



6348
6349
6350
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6348

def stages
  @stages
end

#stateString

Output only. State specifies various states of the Rollout. Corresponds to the JSON property state

Returns:

  • (String)


6353
6354
6355
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6353

def state
  @state
end

#state_reasonString

Output only. A human-readable description explaining the reason for the current state. Corresponds to the JSON property stateReason

Returns:

  • (String)


6359
6360
6361
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6359

def state_reason
  @state_reason
end

#state_reason_typeString

Output only. StateReasonType specifies the reason type of the Rollout state. Corresponds to the JSON property stateReasonType

Returns:

  • (String)


6364
6365
6366
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6364

def state_reason_type
  @state_reason_type
end

#triggerString

Output only. The trigger of the rollout. Corresponds to the JSON property trigger

Returns:

  • (String)


6369
6370
6371
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6369

def trigger
  @trigger
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all Rollout resources. If a Rollout resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


6376
6377
6378
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6376

def uid
  @uid
end

#update_timeString

Output only. The timestamp at which the Rollout was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6381
6382
6383
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6381

def update_time
  @update_time
end

#version_upgradeGoogle::Apis::GkehubV1alpha::VersionUpgrade

Config for version upgrade of clusters. Corresponds to the JSON property versionUpgrade



6386
6387
6388
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6386

def version_upgrade
  @version_upgrade
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6393
6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
6410
6411
6412
6413
6414
6415
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6393

def update!(**args)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @ignore_cluster_disruption_budgets = args[:ignore_cluster_disruption_budgets] if args.key?(:ignore_cluster_disruption_budgets)
  @ignore_maintenance_policies = args[:ignore_maintenance_policies] if args.key?(:ignore_maintenance_policies)
  @intent = args[:intent] if args.key?(:intent)
  @labels = args[:labels] if args.key?(:labels)
  @membership_states = args[:membership_states] if args.key?(:membership_states)
  @name = args[:name] if args.key?(:name)
  @rollout_sequence = args[:rollout_sequence] if args.key?(:rollout_sequence)
  @stage_soak_duration_overrides = args[:stage_soak_duration_overrides] if args.key?(:stage_soak_duration_overrides)
  @stages = args[:stages] if args.key?(:stages)
  @state = args[:state] if args.key?(:state)
  @state_reason = args[:state_reason] if args.key?(:state_reason)
  @state_reason_type = args[:state_reason_type] if args.key?(:state_reason_type)
  @trigger = args[:trigger] if args.key?(:trigger)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version_upgrade = args[:version_upgrade] if args.key?(:version_upgrade)
end