Class: Google::Apis::GkehubV1alpha::RolloutSequenceState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

State and reasons of the Rollout Sequence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutSequenceState

Returns a new instance of RolloutSequenceState.



6425
6426
6427
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_state_change_timeString

Output only. The timestamp at which the LifecycleState was last changed. Used to track how long it has been in the current state. Corresponds to the JSON property lastStateChangeTime

Returns:

  • (String)


6413
6414
6415
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6413

def last_state_change_time
  @last_state_change_time
end

#lifecycle_stateString

Output only. Lifecycle state of the Rollout Sequence. Corresponds to the JSON property lifecycleState

Returns:

  • (String)


6418
6419
6420
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6418

def lifecycle_state
  @lifecycle_state
end

#state_reasonsArray<String>

Output only. StateReason represents the reason for the Rollout Sequence state. Corresponds to the JSON property stateReasons

Returns:

  • (Array<String>)


6423
6424
6425
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6423

def state_reasons
  @state_reasons
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6430
6431
6432
6433
6434
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6430

def update!(**args)
  @last_state_change_time = args[:last_state_change_time] if args.key?(:last_state_change_time)
  @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state)
  @state_reasons = args[:state_reasons] if args.key?(:state_reasons)
end