Class: Google::Apis::GkehubV1alpha::RolloutStage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Stage represents a single stage in the Rollout.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutStage

Returns a new instance of RolloutStage.



6635
6636
6637
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6635

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_selectorGoogle::Apis::GkehubV1alpha::ClusterSelector

Selector for clusters. Corresponds to the JSON property clusterSelector



6602
6603
6604
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6602

def cluster_selector
  @cluster_selector
end

#end_timeString

Optional. Output only. The time at which the stage ended. Corresponds to the JSON property endTime

Returns:

  • (String)


6607
6608
6609
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6607

def end_time
  @end_time
end

#fleet_projectsArray<String>

Output only. The fleet projects from the sequence that was used to create this stage. Expected format: projects/project_number Corresponds to the JSON property fleetProjects

Returns:

  • (Array<String>)


6613
6614
6615
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6613

def fleet_projects
  @fleet_projects
end

#soak_durationString

Optional. Duration to soak after this stage before starting the next stage. Corresponds to the JSON property soakDuration

Returns:

  • (String)


6618
6619
6620
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6618

def soak_duration
  @soak_duration
end

#stage_numberFixnum

Output only. The stage number to which this status applies. Corresponds to the JSON property stageNumber

Returns:

  • (Fixnum)


6623
6624
6625
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6623

def stage_number
  @stage_number
end

#start_timeString

Optional. Output only. The time at which the stage started. Corresponds to the JSON property startTime

Returns:

  • (String)


6628
6629
6630
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6628

def start_time
  @start_time
end

#stateString

Output only. The state of the stage. Corresponds to the JSON property state

Returns:

  • (String)


6633
6634
6635
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6633

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6640
6641
6642
6643
6644
6645
6646
6647
6648
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6640

def update!(**args)
  @cluster_selector = args[:cluster_selector] if args.key?(:cluster_selector)
  @end_time = args[:end_time] if args.key?(:end_time)
  @fleet_projects = args[:fleet_projects] if args.key?(:fleet_projects)
  @soak_duration = args[:soak_duration] if args.key?(:soak_duration)
  @stage_number = args[:stage_number] if args.key?(:stage_number)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
end