Class: Google::Apis::GkehubV1alpha::SecurityPostureConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::SecurityPostureConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
SecurityPostureConfig defines the flags needed to enable/disable features for the Security Posture API.
Instance Attribute Summary collapse
-
#mode ⇒ String
Sets which mode to use for Security Posture features.
-
#vulnerability_mode ⇒ String
Sets which mode to use for vulnerability scanning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPostureConfig
constructor
A new instance of SecurityPostureConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPostureConfig
Returns a new instance of SecurityPostureConfig.
6849 6850 6851 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mode ⇒ String
Sets which mode to use for Security Posture features.
Corresponds to the JSON property mode
6842 6843 6844 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6842 def mode @mode end |
#vulnerability_mode ⇒ String
Sets which mode to use for vulnerability scanning.
Corresponds to the JSON property vulnerabilityMode
6847 6848 6849 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6847 def vulnerability_mode @vulnerability_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6854 6855 6856 6857 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6854 def update!(**args) @mode = args[:mode] if args.key?(:mode) @vulnerability_mode = args[:vulnerability_mode] if args.key?(:vulnerability_mode) end |