Class: Google::Apis::GkehubV1alpha::ServiceMeshAnalysisMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

AnalysisMessage is a single message produced by an analyzer, and it used to communicate to the end user about the state of their Service Mesh configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceMeshAnalysisMessage

Returns a new instance of ServiceMeshAnalysisMessage.



6892
6893
6894
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsHash<String,Object>

A UI can combine these args with a template (based on message_base.type) to produce an internationalized message. Corresponds to the JSON property args

Returns:

  • (Hash<String,Object>)


6870
6871
6872
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6870

def args
  @args
end

#descriptionString

A human readable description of what the error means. It is suitable for non- internationalize display purposes. Corresponds to the JSON property description

Returns:

  • (String)


6876
6877
6878
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6876

def description
  @description
end

#message_baseGoogle::Apis::GkehubV1alpha::ServiceMeshAnalysisMessageBase

AnalysisMessageBase describes some common information that is needed for all messages. Corresponds to the JSON property messageBase



6882
6883
6884
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6882

def message_base
  @message_base
end

#resource_pathsArray<String>

A list of strings specifying the resource identifiers that were the cause of message generation. A "path" here may be: * MEMBERSHIP_ID if the cause is a specific member cluster * MEMBERSHIP_ID/(NAMESPACE\/)?RESOURCETYPE/NAME if the cause is a resource in a cluster Corresponds to the JSON property resourcePaths

Returns:

  • (Array<String>)


6890
6891
6892
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6890

def resource_paths
  @resource_paths
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6897
6898
6899
6900
6901
6902
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6897

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @description = args[:description] if args.key?(:description)
  @message_base = args[:message_base] if args.key?(:message_base)
  @resource_paths = args[:resource_paths] if args.key?(:resource_paths)
end