Class: Google::Apis::GkehubV1alpha::ServiceMeshFeatureCondition
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ServiceMeshFeatureCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Condition being reported.
Instance Attribute Summary collapse
-
#code ⇒ String
Unique identifier of the condition which describes the condition recognizable to the user.
-
#details ⇒ String
A short summary about the issue.
-
#documentation_link ⇒ String
Links contains actionable information.
-
#severity ⇒ String
Severity level of the condition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceMeshFeatureCondition
constructor
A new instance of ServiceMeshFeatureCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceMeshFeatureCondition
Returns a new instance of ServiceMeshFeatureCondition.
6942 6943 6944 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6942 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Unique identifier of the condition which describes the condition recognizable
to the user.
Corresponds to the JSON property code
6925 6926 6927 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6925 def code @code end |
#details ⇒ String
A short summary about the issue.
Corresponds to the JSON property details
6930 6931 6932 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6930 def details @details end |
#documentation_link ⇒ String
Links contains actionable information.
Corresponds to the JSON property documentationLink
6935 6936 6937 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6935 def documentation_link @documentation_link end |
#severity ⇒ String
Severity level of the condition.
Corresponds to the JSON property severity
6940 6941 6942 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6940 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6947 6948 6949 6950 6951 6952 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6947 def update!(**args) @code = args[:code] if args.key?(:code) @details = args[:details] if args.key?(:details) @documentation_link = args[:documentation_link] if args.key?(:documentation_link) @severity = args[:severity] if args.key?(:severity) end |