Class: Google::Apis::GkehubV1alpha::ServiceMeshMembershipSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Service Mesh: Spec for a single Membership for the servicemesh feature

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceMeshMembershipSpec

Returns a new instance of ServiceMeshMembershipSpec.



7105
7106
7107
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_apiString

Optional. Specifies the API that will be used for configuring the mesh workloads. Corresponds to the JSON property configApi

Returns:

  • (String)


7086
7087
7088
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7086

def config_api
  @config_api
end

#control_planeString

Deprecated: use management instead Enables automatic control plane management. Corresponds to the JSON property controlPlane

Returns:

  • (String)


7092
7093
7094
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7092

def control_plane
  @control_plane
end

#default_channelString

Determines which release channel to use for default injection and service mesh APIs. Corresponds to the JSON property defaultChannel

Returns:

  • (String)


7098
7099
7100
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7098

def default_channel
  @default_channel
end

#managementString

Optional. Enables automatic Service Mesh management. Corresponds to the JSON property management

Returns:

  • (String)


7103
7104
7105
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7103

def management
  @management
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7110
7111
7112
7113
7114
7115
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7110

def update!(**args)
  @config_api = args[:config_api] if args.key?(:config_api)
  @control_plane = args[:control_plane] if args.key?(:control_plane)
  @default_channel = args[:default_channel] if args.key?(:default_channel)
  @management = args[:management] if args.key?(:management)
end