Class: Google::Apis::GkehubV1alpha::UpgradeRolloutSequenceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Request message for upgrading a rollout sequence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeRolloutSequenceRequest

Returns a new instance of UpgradeRolloutSequenceRequest.



7506
7507
7508
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7506

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forceBoolean Also known as: force?

Optional. If set to true, any rollout already running on the first stage of the sequence will be cancelled to allow for the creation of the new rollout. Corresponds to the JSON property force

Returns:

  • (Boolean)


7452
7453
7454
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7452

def force
  @force
end

#ignore_cluster_disruption_budgetsBoolean Also known as: ignore_cluster_disruption_budgets?

Optional. If set to true, the rollout will ignore the disruption budgets of the clusters. Corresponds to the JSON property ignoreClusterDisruptionBudgets

Returns:

  • (Boolean)


7459
7460
7461
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7459

def ignore_cluster_disruption_budgets
  @ignore_cluster_disruption_budgets
end

#ignore_maintenance_policiesBoolean Also known as: ignore_maintenance_policies?

Optional. If set to true, the rollout will ignore any maintenance policies ( Maintenance Windows and Maintenance Exclusions) set on the clusters. Corresponds to the JSON property ignoreMaintenancePolicies

Returns:

  • (Boolean)


7466
7467
7468
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7466

def ignore_maintenance_policies
  @ignore_maintenance_policies
end

#patch_onlyBoolean Also known as: patch_only?

Optional. If set to true, the rollout will only upgrade clusters that match the minor version of the version field, but are on an earlier patch version. Corresponds to the JSON property patchOnly

Returns:

  • (Boolean)


7473
7474
7475
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7473

def patch_only
  @patch_only
end

#soak_duration_override_all_stagesString

Optional. Overrides the soak duration for all stages of the rollout. Corresponds to the JSON property soakDurationOverrideAllStages

Returns:

  • (String)


7479
7480
7481
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7479

def soak_duration_override_all_stages
  @soak_duration_override_all_stages
end

#soak_duration_override_per_stageGoogle::Apis::GkehubV1alpha::PerStageSoakDurationOverrides

Configuration for per-stage soak duration overrides. Corresponds to the JSON property soakDurationOverridePerStage



7484
7485
7486
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7484

def soak_duration_override_per_stage
  @soak_duration_override_per_stage
end

#upgrade_typeString

Required. The type of upgrade. Corresponds to the JSON property upgradeType

Returns:

  • (String)


7489
7490
7491
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7489

def upgrade_type
  @upgrade_type
end

#versionString

Required. GKE version to upgrade to. A valid GKE version available on the release channel used by the sequence. Patch versions from less conservative channels are allowed if their minor version is already available in the sequence's channel. This is similar to single-cluster upgrade rules, see https: //cloud.google.com/kubernetes-engine/docs/how-to/upgrading-a-cluster#supported- versions Example: With the following versions available on the RAPID and REGULAR channels: * REGULAR: 1.35.3-gke.123000 * RAPID: 1.36.4-gke.321000, 1. 35.6-gke.045000 Valid versions are 1.35.3-gke.123, 1.35.6-gke.045000 Aliases like latest are supported. For more information on valid upgrade versions and specifying cluster versions, see: https://cloud.google.com/kubernetes- engine/versioning#specifying_cluster_version Corresponds to the JSON property version

Returns:

  • (String)


7504
7505
7506
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7504

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7511
7512
7513
7514
7515
7516
7517
7518
7519
7520
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7511

def update!(**args)
  @force = args[:force] if args.key?(:force)
  @ignore_cluster_disruption_budgets = args[:ignore_cluster_disruption_budgets] if args.key?(:ignore_cluster_disruption_budgets)
  @ignore_maintenance_policies = args[:ignore_maintenance_policies] if args.key?(:ignore_maintenance_policies)
  @patch_only = args[:patch_only] if args.key?(:patch_only)
  @soak_duration_override_all_stages = args[:soak_duration_override_all_stages] if args.key?(:soak_duration_override_all_stages)
  @soak_duration_override_per_stage = args[:soak_duration_override_per_stage] if args.key?(:soak_duration_override_per_stage)
  @upgrade_type = args[:upgrade_type] if args.key?(:upgrade_type)
  @version = args[:version] if args.key?(:version)
end