Class: Google::Apis::GkehubV1alpha::WorkloadIdentityIdentityProviderStateDetail
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::WorkloadIdentityIdentityProviderStateDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
IdentityProviderStateDetail represents the state of an Identity Provider.
Instance Attribute Summary collapse
-
#code ⇒ String
The state of the Identity Provider.
-
#description ⇒ String
A human-readable description of the current state or returned error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityIdentityProviderStateDetail
constructor
A new instance of WorkloadIdentityIdentityProviderStateDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityIdentityProviderStateDetail
Returns a new instance of WorkloadIdentityIdentityProviderStateDetail.
7453 7454 7455 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7453 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The state of the Identity Provider.
Corresponds to the JSON property code
7446 7447 7448 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7446 def code @code end |
#description ⇒ String
A human-readable description of the current state or returned error.
Corresponds to the JSON property description
7451 7452 7453 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7451 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7458 7459 7460 7461 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7458 def update!(**args) @code = args[:code] if args.key?(:code) @description = args[:description] if args.key?(:description) end |