Class: Google::Apis::GkehubV1alpha::WorkloadIdentityMembershipState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

WorkloadIdentity: The membership-specific state for WorkloadIdentity feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityMembershipState

Returns a new instance of WorkloadIdentityMembershipState.



7755
7756
7757
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7755

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Deprecated, this field will be erased after code is changed to use the new field. Corresponds to the JSON property description

Returns:

  • (String)


7748
7749
7750
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7748

def description
  @description
end

#identity_provider_state_detailsHash<String,Google::Apis::GkehubV1alpha::WorkloadIdentityIdentityProviderStateDetail>

The state of the Identity Providers corresponding to the membership. Corresponds to the JSON property identityProviderStateDetails



7753
7754
7755
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7753

def identity_provider_state_details
  @identity_provider_state_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7760
7761
7762
7763
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7760

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @identity_provider_state_details = args[:identity_provider_state_details] if args.key?(:identity_provider_state_details)
end