Class: Google::Apis::GkehubV1alpha::WorkloadIdentityNamespaceStateDetail
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::WorkloadIdentityNamespaceStateDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
NamespaceStateDetail represents the state of a IAM namespace.
Instance Attribute Summary collapse
-
#code ⇒ String
The state of the IAM namespace.
-
#description ⇒ String
A human-readable description of the current state or returned error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityNamespaceStateDetail
constructor
A new instance of WorkloadIdentityNamespaceStateDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityNamespaceStateDetail
Returns a new instance of WorkloadIdentityNamespaceStateDetail.
7447 7448 7449 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7447 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The state of the IAM namespace.
Corresponds to the JSON property code
7440 7441 7442 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7440 def code @code end |
#description ⇒ String
A human-readable description of the current state or returned error.
Corresponds to the JSON property description
7445 7446 7447 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7445 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7452 7453 7454 7455 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7452 def update!(**args) @code = args[:code] if args.key?(:code) @description = args[:description] if args.key?(:description) end |