Class: Google::Apis::GkehubV1alpha::ClusterUpgradeFleetState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

ClusterUpgrade: The state for the fleet-level ClusterUpgrade feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterUpgradeFleetState

Returns a new instance of ClusterUpgradeFleetState.



484
485
486
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#downstream_fleetsArray<String>

This fleets whose upstream_fleets contain the current fleet. The fleet name should be either fleet project number or id. Corresponds to the JSON property downstreamFleets

Returns:

  • (Array<String>)


469
470
471
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 469

def downstream_fleets
  @downstream_fleets
end

#gke_stateGoogle::Apis::GkehubV1alpha::ClusterUpgradeGkeUpgradeFeatureState

GKEUpgradeFeatureState contains feature states for GKE clusters in the scope. Corresponds to the JSON property gkeState



474
475
476
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 474

def gke_state
  @gke_state
end

#ignoredHash<String,Google::Apis::GkehubV1alpha::ClusterUpgradeIgnoredMembership>

A list of memberships ignored by the feature. For example, manually upgraded clusters can be ignored if they are newer than the default versions of its release channel. The membership resource is in the format: projects/p/ locations/l/membership/m`. Corresponds to the JSON propertyignored`



482
483
484
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 482

def ignored
  @ignored
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



489
490
491
492
493
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 489

def update!(**args)
  @downstream_fleets = args[:downstream_fleets] if args.key?(:downstream_fleets)
  @gke_state = args[:gke_state] if args.key?(:gke_state)
  @ignored = args[:ignored] if args.key?(:ignored)
end