Class: Google::Apis::GkehubV1alpha::ConfigManagementConfigSync

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Configuration for Config Sync

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementConfigSync

Returns a new instance of ConfigManagementConfigSync.



1247
1248
1249
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1247

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployment_overridesArray<Google::Apis::GkehubV1alpha::ConfigManagementDeploymentOverride>

Optional. Configuration for deployment overrides. Applies only to Config Sync deployments with containers that are not a root or namespace reconciler: reconciler-manager, otel-collector, resource-group-controller-manager, admission-webhook. To override a root or namespace reconciler, use the rootsync or reposync fields at https://docs.cloud.google.com/kubernetes-engine/ config-sync/docs/reference/rootsync-reposync-fields#override-resources instead. Corresponds to the JSON property deploymentOverrides



1188
1189
1190
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1188

def deployment_overrides
  @deployment_overrides
end

#enabledBoolean Also known as: enabled?

Optional. Enables the installation of Config Sync. If set to true, the Feature will manage Config Sync resources, and apply the other ConfigSync fields if they exist. If set to false, the Feature will ignore all other ConfigSync fields and delete the Config Sync resources. If omitted, ConfigSync is considered enabled if the git or oci field is present. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


1197
1198
1199
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1197

def enabled
  @enabled
end

#gitGoogle::Apis::GkehubV1alpha::ConfigManagementGitConfig

Git repo configuration for a single cluster. Corresponds to the JSON property git



1203
1204
1205
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1203

def git
  @git
end

#metrics_gcp_service_account_emailString

Optional. The Email of the Google Cloud Service Account (GSA) used for exporting Config Sync metrics to Cloud Monitoring and Cloud Monarch when Workload Identity is enabled. The GSA should have the Monitoring Metric Writer (roles/monitoring.metricWriter) IAM role. The Kubernetes ServiceAccount default in the namespace config-management-monitoring should be bound to the GSA. Deprecated: If Workload Identity Federation for GKE is enabled, Google Cloud Service Account is no longer needed for exporting Config Sync metrics: https://cloud.google.com/kubernetes-engine/enterprise/config-sync/ docs/how-to/monitor-config-sync-cloud-monitoring#custom-monitoring. Corresponds to the JSON property metricsGcpServiceAccountEmail

Returns:

  • (String)


1216
1217
1218
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1216

def 
  @metrics_gcp_service_account_email
end

#ociGoogle::Apis::GkehubV1alpha::ConfigManagementOciConfig

OCI repo configuration for a single cluster Corresponds to the JSON property oci



1221
1222
1223
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1221

def oci
  @oci
end

#prevent_driftBoolean Also known as: prevent_drift?

Optional. Set to true to enable the Config Sync admission webhook to prevent drifts. If set to false, disables the Config Sync admission webhook and does not prevent drifts. Defaults to false. See https://docs.cloud.google.com/ kubernetes-engine/config-sync/docs/how-to/prevent-config-drift for details. Corresponds to the JSON property preventDrift

Returns:

  • (Boolean)


1229
1230
1231
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1229

def prevent_drift
  @prevent_drift
end

#source_formatString

Optional. Specifies whether the Config Sync repo is in hierarchical or unstructured mode. Defaults to hierarchical. See https://docs.cloud.google. com/kubernetes-engine/config-sync/docs/concepts/configs#organize-configs for an explanation. Corresponds to the JSON property sourceFormat

Returns:

  • (String)


1238
1239
1240
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1238

def source_format
  @source_format
end

#stop_syncingBoolean Also known as: stop_syncing?

Optional. Set to true to stop syncing configs for a single cluster. Default to false. Corresponds to the JSON property stopSyncing

Returns:

  • (Boolean)


1244
1245
1246
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1244

def stop_syncing
  @stop_syncing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1252

def update!(**args)
  @deployment_overrides = args[:deployment_overrides] if args.key?(:deployment_overrides)
  @enabled = args[:enabled] if args.key?(:enabled)
  @git = args[:git] if args.key?(:git)
  @metrics_gcp_service_account_email = args[:metrics_gcp_service_account_email] if args.key?(:metrics_gcp_service_account_email)
  @oci = args[:oci] if args.key?(:oci)
  @prevent_drift = args[:prevent_drift] if args.key?(:prevent_drift)
  @source_format = args[:source_format] if args.key?(:source_format)
  @stop_syncing = args[:stop_syncing] if args.key?(:stop_syncing)
end