Class: Google::Apis::GkehubV1alpha::ConfigManagementConfigSync
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ConfigManagementConfigSync
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Configuration for Config Sync
Instance Attribute Summary collapse
-
#deployment_overrides ⇒ Array<Google::Apis::GkehubV1alpha::ConfigManagementDeploymentOverride>
Optional.
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#git ⇒ Google::Apis::GkehubV1alpha::ConfigManagementGitConfig
Git repo configuration for a single cluster.
-
#metrics_gcp_service_account_email ⇒ String
Optional.
-
#oci ⇒ Google::Apis::GkehubV1alpha::ConfigManagementOciConfig
OCI repo configuration for a single cluster Corresponds to the JSON property
oci. -
#prevent_drift ⇒ Boolean
(also: #prevent_drift?)
Optional.
-
#source_format ⇒ String
Optional.
-
#stop_syncing ⇒ Boolean
(also: #stop_syncing?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementConfigSync
constructor
A new instance of ConfigManagementConfigSync.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementConfigSync
Returns a new instance of ConfigManagementConfigSync.
1212 1213 1214 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1212 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment_overrides ⇒ Array<Google::Apis::GkehubV1alpha::ConfigManagementDeploymentOverride>
Optional. Configuration for deployment overrides.
Corresponds to the JSON property deploymentOverrides
1156 1157 1158 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1156 def deployment_overrides @deployment_overrides end |
#enabled ⇒ Boolean Also known as: enabled?
Optional. Enables the installation of ConfigSync. If set to true, ConfigSync
resources will be created and the other ConfigSync fields will be applied if
exist. If set to false, all other ConfigSync fields will be ignored,
ConfigSync resources will be deleted. If omitted, ConfigSync resources will be
managed depends on the presence of the git or oci field.
Corresponds to the JSON property enabled
1165 1166 1167 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1165 def enabled @enabled end |
#git ⇒ Google::Apis::GkehubV1alpha::ConfigManagementGitConfig
Git repo configuration for a single cluster.
Corresponds to the JSON property git
1171 1172 1173 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1171 def git @git end |
#metrics_gcp_service_account_email ⇒ String
Optional. The Email of the Google Cloud Service Account (GSA) used for
exporting Config Sync metrics to Cloud Monitoring and Cloud Monarch when
Workload Identity is enabled. The GSA should have the Monitoring Metric Writer
(roles/monitoring.metricWriter) IAM role. The Kubernetes ServiceAccount
default in the namespace config-management-monitoring should be bound to
the GSA. Deprecated: If Workload Identity Federation for GKE is enabled,
Google Cloud Service Account is no longer needed for exporting Config Sync
metrics: https://cloud.google.com/kubernetes-engine/enterprise/config-sync/
docs/how-to/monitor-config-sync-cloud-monitoring#custom-monitoring.
Corresponds to the JSON property metricsGcpServiceAccountEmail
1184 1185 1186 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1184 def metrics_gcp_service_account_email @metrics_gcp_service_account_email end |
#oci ⇒ Google::Apis::GkehubV1alpha::ConfigManagementOciConfig
OCI repo configuration for a single cluster
Corresponds to the JSON property oci
1189 1190 1191 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1189 def oci @oci end |
#prevent_drift ⇒ Boolean Also known as: prevent_drift?
Optional. Set to true to enable the Config Sync admission webhook to prevent
drifts. If set to false, disables the Config Sync admission webhook and does
not prevent drifts.
Corresponds to the JSON property preventDrift
1196 1197 1198 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1196 def prevent_drift @prevent_drift end |
#source_format ⇒ String
Optional. Specifies whether the Config Sync Repo is in "hierarchical" or "
unstructured" mode.
Corresponds to the JSON property sourceFormat
1203 1204 1205 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1203 def source_format @source_format end |
#stop_syncing ⇒ Boolean Also known as: stop_syncing?
Optional. Set to true to stop syncing configs for a single cluster. Default to
false.
Corresponds to the JSON property stopSyncing
1209 1210 1211 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1209 def stop_syncing @stop_syncing end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1217 def update!(**args) @deployment_overrides = args[:deployment_overrides] if args.key?(:deployment_overrides) @enabled = args[:enabled] if args.key?(:enabled) @git = args[:git] if args.key?(:git) @metrics_gcp_service_account_email = args[:metrics_gcp_service_account_email] if args.key?(:metrics_gcp_service_account_email) @oci = args[:oci] if args.key?(:oci) @prevent_drift = args[:prevent_drift] if args.key?(:prevent_drift) @source_format = args[:source_format] if args.key?(:source_format) @stop_syncing = args[:stop_syncing] if args.key?(:stop_syncing) end |