Class: Google::Apis::GkehubV1alpha::ConfigManagementConfigSyncState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ConfigManagementConfigSyncState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
State information for ConfigSync
Instance Attribute Summary collapse
-
#cluster_level_stop_syncing_state ⇒ String
Output only.
-
#cr_count ⇒ Fixnum
Output only.
-
#deployment_state ⇒ Google::Apis::GkehubV1alpha::ConfigManagementConfigSyncDeploymentState
The state of ConfigSync's deployment on a cluster Corresponds to the JSON property
deploymentState. -
#errors ⇒ Array<Google::Apis::GkehubV1alpha::ConfigManagementConfigSyncError>
Output only.
-
#reposync_crd ⇒ String
Output only.
-
#rootsync_crd ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#sync_state ⇒ Google::Apis::GkehubV1alpha::ConfigManagementSyncState
State indicating an ACM's progress syncing configurations to a cluster Corresponds to the JSON property
syncState. -
#version ⇒ Google::Apis::GkehubV1alpha::ConfigManagementConfigSyncVersion
Specific versioning information pertaining to ConfigSync's Pods Corresponds to the JSON property
version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementConfigSyncState
constructor
A new instance of ConfigManagementConfigSyncState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementConfigSyncState
Returns a new instance of ConfigManagementConfigSyncState.
1401 1402 1403 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_level_stop_syncing_state ⇒ String
Output only. Whether syncing resources to the cluster is stopped at the
cluster level.
Corresponds to the JSON property clusterLevelStopSyncingState
1358 1359 1360 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1358 def cluster_level_stop_syncing_state @cluster_level_stop_syncing_state end |
#cr_count ⇒ Fixnum
Output only. The number of RootSync and RepoSync CRs in the cluster.
Corresponds to the JSON property crCount
1363 1364 1365 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1363 def cr_count @cr_count end |
#deployment_state ⇒ Google::Apis::GkehubV1alpha::ConfigManagementConfigSyncDeploymentState
The state of ConfigSync's deployment on a cluster
Corresponds to the JSON property deploymentState
1368 1369 1370 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1368 def deployment_state @deployment_state end |
#errors ⇒ Array<Google::Apis::GkehubV1alpha::ConfigManagementConfigSyncError>
Output only. Errors pertaining to the installation of Config Sync.
Corresponds to the JSON property errors
1373 1374 1375 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1373 def errors @errors end |
#reposync_crd ⇒ String
Output only. The state of the Reposync CRD
Corresponds to the JSON property reposyncCrd
1378 1379 1380 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1378 def reposync_crd @reposync_crd end |
#rootsync_crd ⇒ String
Output only. The state of the RootSync CRD
Corresponds to the JSON property rootsyncCrd
1383 1384 1385 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1383 def rootsync_crd @rootsync_crd end |
#state ⇒ String
Output only. The state of CS This field summarizes the other fields in this
message.
Corresponds to the JSON property state
1389 1390 1391 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1389 def state @state end |
#sync_state ⇒ Google::Apis::GkehubV1alpha::ConfigManagementSyncState
State indicating an ACM's progress syncing configurations to a cluster
Corresponds to the JSON property syncState
1394 1395 1396 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1394 def sync_state @sync_state end |
#version ⇒ Google::Apis::GkehubV1alpha::ConfigManagementConfigSyncVersion
Specific versioning information pertaining to ConfigSync's Pods
Corresponds to the JSON property version
1399 1400 1401 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1399 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1406 def update!(**args) @cluster_level_stop_syncing_state = args[:cluster_level_stop_syncing_state] if args.key?(:cluster_level_stop_syncing_state) @cr_count = args[:cr_count] if args.key?(:cr_count) @deployment_state = args[:deployment_state] if args.key?(:deployment_state) @errors = args[:errors] if args.key?(:errors) @reposync_crd = args[:reposync_crd] if args.key?(:reposync_crd) @rootsync_crd = args[:rootsync_crd] if args.key?(:rootsync_crd) @state = args[:state] if args.key?(:state) @sync_state = args[:sync_state] if args.key?(:sync_state) @version = args[:version] if args.key?(:version) end |