Class: Google::Apis::GkehubV1alpha::ConfigManagementDeploymentOverride
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ConfigManagementDeploymentOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Configuration for a deployment override.
Instance Attribute Summary collapse
-
#containers ⇒ Array<Google::Apis::GkehubV1alpha::ConfigManagementContainerOverride>
Optional.
-
#deployment_name ⇒ String
Required.
-
#deployment_namespace ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementDeploymentOverride
constructor
A new instance of ConfigManagementDeploymentOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementDeploymentOverride
Returns a new instance of ConfigManagementDeploymentOverride.
1513 1514 1515 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1513 def initialize(**args) update!(**args) end |
Instance Attribute Details
#containers ⇒ Array<Google::Apis::GkehubV1alpha::ConfigManagementContainerOverride>
Optional. The containers of the deployment resource to be overridden.
Corresponds to the JSON property containers
1501 1502 1503 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1501 def containers @containers end |
#deployment_name ⇒ String
Required. The name of the deployment resource to be overridden.
Corresponds to the JSON property deploymentName
1506 1507 1508 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1506 def deployment_name @deployment_name end |
#deployment_namespace ⇒ String
Required. The namespace of the deployment resource to be overridden.
Corresponds to the JSON property deploymentNamespace
1511 1512 1513 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1511 def deployment_namespace @deployment_namespace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1518 1519 1520 1521 1522 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1518 def update!(**args) @containers = args[:containers] if args.key?(:containers) @deployment_name = args[:deployment_name] if args.key?(:deployment_name) @deployment_namespace = args[:deployment_namespace] if args.key?(:deployment_namespace) end |