Class: Google::Apis::GkehubV1alpha::ConfigManagementGitConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ConfigManagementGitConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Git repo configuration for a single cluster.
Instance Attribute Summary collapse
-
#gcp_service_account_email ⇒ String
Optional.
-
#https_proxy ⇒ String
Optional.
-
#policy_dir ⇒ String
Optional.
-
#secret_type ⇒ String
Required.
-
#sync_branch ⇒ String
Optional.
-
#sync_repo ⇒ String
Required.
-
#sync_rev ⇒ String
Optional.
-
#sync_wait_secs ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementGitConfig
constructor
A new instance of ConfigManagementGitConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementGitConfig
Returns a new instance of ConfigManagementGitConfig.
1666 1667 1668 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1666 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcp_service_account_email ⇒ String
Optional. The Google Cloud Service Account Email used for auth when
secret_type is gcpserviceaccount.
Corresponds to the JSON property gcpServiceAccountEmail
1625 1626 1627 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1625 def gcp_service_account_email @gcp_service_account_email end |
#https_proxy ⇒ String
Optional. URL for the HTTPS proxy to be used when communicating with the Git
repo. Only specify when secret_type is cookiefile, token, or none.
Corresponds to the JSON property httpsProxy
1631 1632 1633 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1631 def https_proxy @https_proxy end |
#policy_dir ⇒ String
Optional. The path within the Git repository that represents the top level of
the repo to sync. Default: the root directory of the repository.
Corresponds to the JSON property policyDir
1637 1638 1639 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1637 def policy_dir @policy_dir end |
#secret_type ⇒ String
Required. Type of secret configured for access to the Git repo. Must be one of
ssh, cookiefile, gcenode, token, gcpserviceaccount, githubapp or
none. The validation of this is case-sensitive.
Corresponds to the JSON property secretType
1644 1645 1646 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1644 def secret_type @secret_type end |
#sync_branch ⇒ String
Optional. The branch of the repository to sync from. Default: master.
Corresponds to the JSON property syncBranch
1649 1650 1651 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1649 def sync_branch @sync_branch end |
#sync_repo ⇒ String
Required. The URL of the Git repository to use as the source of truth.
Corresponds to the JSON property syncRepo
1654 1655 1656 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1654 def sync_repo @sync_repo end |
#sync_rev ⇒ String
Optional. Git revision (tag or hash) to check out. Default HEAD.
Corresponds to the JSON property syncRev
1659 1660 1661 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1659 def sync_rev @sync_rev end |
#sync_wait_secs ⇒ Fixnum
Optional. Period in seconds between consecutive syncs. Default: 15.
Corresponds to the JSON property syncWaitSecs
1664 1665 1666 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1664 def sync_wait_secs @sync_wait_secs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1671 def update!(**args) @gcp_service_account_email = args[:gcp_service_account_email] if args.key?(:gcp_service_account_email) @https_proxy = args[:https_proxy] if args.key?(:https_proxy) @policy_dir = args[:policy_dir] if args.key?(:policy_dir) @secret_type = args[:secret_type] if args.key?(:secret_type) @sync_branch = args[:sync_branch] if args.key?(:sync_branch) @sync_repo = args[:sync_repo] if args.key?(:sync_repo) @sync_rev = args[:sync_rev] if args.key?(:sync_rev) @sync_wait_secs = args[:sync_wait_secs] if args.key?(:sync_wait_secs) end |