Class: Google::Apis::GkehubV1alpha::ConfigManagementMembershipSpec
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ConfigManagementMembershipSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Anthos Config Management: Configuration for a single cluster. Intended to parallel the ConfigManagement CR.
Instance Attribute Summary collapse
-
#binauthz ⇒ Google::Apis::GkehubV1alpha::ConfigManagementBinauthzConfig
Configuration for Binauthz Corresponds to the JSON property
binauthz. -
#cluster ⇒ String
Optional.
-
#config_sync ⇒ Google::Apis::GkehubV1alpha::ConfigManagementConfigSync
Configuration for Config Sync Corresponds to the JSON property
configSync. -
#hierarchy_controller ⇒ Google::Apis::GkehubV1alpha::ConfigManagementHierarchyControllerConfig
Configuration for Hierarchy Controller Corresponds to the JSON property
hierarchyController. -
#management ⇒ String
Optional.
-
#policy_controller ⇒ Google::Apis::GkehubV1alpha::ConfigManagementPolicyController
Configuration for Policy Controller Corresponds to the JSON property
policyController. -
#version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementMembershipSpec
constructor
A new instance of ConfigManagementMembershipSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementMembershipSpec
Returns a new instance of ConfigManagementMembershipSpec.
1941 1942 1943 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1941 def initialize(**args) update!(**args) end |
Instance Attribute Details
#binauthz ⇒ Google::Apis::GkehubV1alpha::ConfigManagementBinauthzConfig
Configuration for Binauthz
Corresponds to the JSON property binauthz
1896 1897 1898 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1896 def binauthz @binauthz end |
#cluster ⇒ String
Optional. User-specified cluster name used by the Config Sync cluster-name-
selector annotation or ClusterSelector object, for applying configs to only a
subset of clusters. Read more about the cluster-name-selector annotation and
ClusterSelector object at https://docs.cloud.google.com/kubernetes-engine/
config-sync/docs/how-to/cluster-scoped-objects#limiting-configs. Only set this
field if a name different from the cluster's fleet membership name is used by
the Config Sync cluster-name-selector annotation or ClusterSelector.
Corresponds to the JSON property cluster
1907 1908 1909 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1907 def cluster @cluster end |
#config_sync ⇒ Google::Apis::GkehubV1alpha::ConfigManagementConfigSync
Configuration for Config Sync
Corresponds to the JSON property configSync
1912 1913 1914 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1912 def config_sync @config_sync end |
#hierarchy_controller ⇒ Google::Apis::GkehubV1alpha::ConfigManagementHierarchyControllerConfig
Configuration for Hierarchy Controller
Corresponds to the JSON property hierarchyController
1917 1918 1919 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1917 def hierarchy_controller @hierarchy_controller end |
#management ⇒ String
Optional. Deprecated: Automatic Feature management is in Preview and is
unavailable in version 1.21.0 and later, after which Config Sync only supports
manual upgrades. If set to manual upgrades, clear this field instead, which is
behaviorally equivalent but helps prevent compatibility issues with newer
fields.
Corresponds to the JSON property management
1926 1927 1928 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1926 def management @management end |
#policy_controller ⇒ Google::Apis::GkehubV1alpha::ConfigManagementPolicyController
Configuration for Policy Controller
Corresponds to the JSON property policyController
1931 1932 1933 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1931 def policy_controller @policy_controller end |
#version ⇒ String
Optional. Version of Config Sync to install. Defaults to the latest supported
Config Sync version if the config_sync field is enabled. See supported
versions at https://cloud.google.com/kubernetes-engine/config-sync/docs/get-
support-config-sync#version_support_policy.
Corresponds to the JSON property version
1939 1940 1941 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1939 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1946 1947 1948 1949 1950 1951 1952 1953 1954 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1946 def update!(**args) @binauthz = args[:binauthz] if args.key?(:binauthz) @cluster = args[:cluster] if args.key?(:cluster) @config_sync = args[:config_sync] if args.key?(:config_sync) @hierarchy_controller = args[:hierarchy_controller] if args.key?(:hierarchy_controller) @management = args[:management] if args.key?(:management) @policy_controller = args[:policy_controller] if args.key?(:policy_controller) @version = args[:version] if args.key?(:version) end |