Class: Google::Apis::GkehubV1alpha::ConfigManagementMembershipSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Anthos Config Management: Configuration for a single cluster. Intended to parallel the ConfigManagement CR.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementMembershipSpec

Returns a new instance of ConfigManagementMembershipSpec.



1911
1912
1913
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1911

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#binauthzGoogle::Apis::GkehubV1alpha::ConfigManagementBinauthzConfig

Configuration for Binauthz Corresponds to the JSON property binauthz



1869
1870
1871
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1869

def binauthz
  @binauthz
end

#clusterString

Optional. User-specified cluster name used by the Config Sync cluster-name- selector annotation or ClusterSelector object, for applying configs to only a subset of clusters. Read more about the cluster-name-selector annotation and ClusterSelector object at https://docs.cloud.google.com/kubernetes-engine/ config-sync/docs/how-to/cluster-scoped-objects#limiting-configs. Only set this field if a name different from the cluster's fleet membership name is used by the Config Sync cluster-name-selector annotation or ClusterSelector. Corresponds to the JSON property cluster

Returns:

  • (String)


1880
1881
1882
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1880

def cluster
  @cluster
end

#config_syncGoogle::Apis::GkehubV1alpha::ConfigManagementConfigSync

Configuration for Config Sync Corresponds to the JSON property configSync



1885
1886
1887
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1885

def config_sync
  @config_sync
end

#hierarchy_controllerGoogle::Apis::GkehubV1alpha::ConfigManagementHierarchyControllerConfig

Configuration for Hierarchy Controller Corresponds to the JSON property hierarchyController



1890
1891
1892
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1890

def hierarchy_controller
  @hierarchy_controller
end

#managementString

Optional. Deprecated: From version 1.21.0, automatic Feature management is unavailable, and Config Sync only supports manual upgrades. Corresponds to the JSON property management

Returns:

  • (String)


1896
1897
1898
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1896

def management
  @management
end

#policy_controllerGoogle::Apis::GkehubV1alpha::ConfigManagementPolicyController

Configuration for Policy Controller Corresponds to the JSON property policyController



1901
1902
1903
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1901

def policy_controller
  @policy_controller
end

#versionString

Optional. Version of Config Sync to install. Defaults to the latest supported Config Sync version if the config_sync field is enabled. See supported versions at https://cloud.google.com/kubernetes-engine/config-sync/docs/get- support-config-sync#version_support_policy. Corresponds to the JSON property version

Returns:

  • (String)


1909
1910
1911
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1909

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1916
1917
1918
1919
1920
1921
1922
1923
1924
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1916

def update!(**args)
  @binauthz = args[:binauthz] if args.key?(:binauthz)
  @cluster = args[:cluster] if args.key?(:cluster)
  @config_sync = args[:config_sync] if args.key?(:config_sync)
  @hierarchy_controller = args[:hierarchy_controller] if args.key?(:hierarchy_controller)
  @management = args[:management] if args.key?(:management)
  @policy_controller = args[:policy_controller] if args.key?(:policy_controller)
  @version = args[:version] if args.key?(:version)
end