Class: Google::Apis::GkehubV1alpha::ConfigManagementMembershipSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Anthos Config Management: Configuration for a single cluster. Intended to parallel the ConfigManagement CR.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementMembershipSpec

Returns a new instance of ConfigManagementMembershipSpec.



1863
1864
1865
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#binauthzGoogle::Apis::GkehubV1alpha::ConfigManagementBinauthzConfig

Configuration for Binauthz Corresponds to the JSON property binauthz



1826
1827
1828
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1826

def binauthz
  @binauthz
end

#clusterString

Optional. The user-specified cluster name used by Config Sync cluster-name- selector annotation or ClusterSelector, for applying configs to only a subset of clusters. Omit this field if the cluster's fleet membership name is used by Config Sync cluster-name-selector annotation or ClusterSelector. Set this field if a name different from the cluster's fleet membership name is used by Config Sync cluster-name-selector annotation or ClusterSelector. Corresponds to the JSON property cluster

Returns:

  • (String)


1836
1837
1838
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1836

def cluster
  @cluster
end

#config_syncGoogle::Apis::GkehubV1alpha::ConfigManagementConfigSync

Configuration for Config Sync Corresponds to the JSON property configSync



1841
1842
1843
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1841

def config_sync
  @config_sync
end

#hierarchy_controllerGoogle::Apis::GkehubV1alpha::ConfigManagementHierarchyControllerConfig

Configuration for Hierarchy Controller Corresponds to the JSON property hierarchyController



1846
1847
1848
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1846

def hierarchy_controller
  @hierarchy_controller
end

#managementString

Optional. Enables automatic Feature management. Corresponds to the JSON property management

Returns:

  • (String)


1851
1852
1853
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1851

def management
  @management
end

#policy_controllerGoogle::Apis::GkehubV1alpha::ConfigManagementPolicyController

Configuration for Policy Controller Corresponds to the JSON property policyController



1856
1857
1858
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1856

def policy_controller
  @policy_controller
end

#versionString

Optional. Version of ACM installed. Corresponds to the JSON property version

Returns:

  • (String)


1861
1862
1863
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1861

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1868
1869
1870
1871
1872
1873
1874
1875
1876
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1868

def update!(**args)
  @binauthz = args[:binauthz] if args.key?(:binauthz)
  @cluster = args[:cluster] if args.key?(:cluster)
  @config_sync = args[:config_sync] if args.key?(:config_sync)
  @hierarchy_controller = args[:hierarchy_controller] if args.key?(:hierarchy_controller)
  @management = args[:management] if args.key?(:management)
  @policy_controller = args[:policy_controller] if args.key?(:policy_controller)
  @version = args[:version] if args.key?(:version)
end