Class: Google::Apis::GkehubV1alpha::ConfigManagementOciConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

OCI repo configuration for a single cluster

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementOciConfig

Returns a new instance of ConfigManagementOciConfig.



1977
1978
1979
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1977

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcp_service_account_emailString

Optional. The Google Cloud Service Account Email used for auth when secret_type is gcpServiceAccount. Corresponds to the JSON property gcpServiceAccountEmail

Returns:

  • (String)


1951
1952
1953
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1951

def 
  @gcp_service_account_email
end

#policy_dirString

Optional. The absolute path of the directory that contains the local resources. Default: the root directory of the image. Corresponds to the JSON property policyDir

Returns:

  • (String)


1957
1958
1959
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1957

def policy_dir
  @policy_dir
end

#secret_typeString

Required. Type of secret configured for access to the OCI repo. Must be one of gcenode, gcpserviceaccount, k8sserviceaccount or none. The validation of this is case-sensitive. Corresponds to the JSON property secretType

Returns:

  • (String)


1964
1965
1966
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1964

def secret_type
  @secret_type
end

#sync_repoString

Required. The OCI image repository URL for the package to sync from. e.g. LOCATION-docker.pkg.dev/PROJECT_ID/REPOSITORY_NAME/PACKAGE_NAME. Corresponds to the JSON property syncRepo

Returns:

  • (String)


1970
1971
1972
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1970

def sync_repo
  @sync_repo
end

#sync_wait_secsFixnum

Optional. Period in seconds between consecutive syncs. Default: 15. Corresponds to the JSON property syncWaitSecs

Returns:

  • (Fixnum)


1975
1976
1977
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1975

def sync_wait_secs
  @sync_wait_secs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1982
1983
1984
1985
1986
1987
1988
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 1982

def update!(**args)
  @gcp_service_account_email = args[:gcp_service_account_email] if args.key?(:gcp_service_account_email)
  @policy_dir = args[:policy_dir] if args.key?(:policy_dir)
  @secret_type = args[:secret_type] if args.key?(:secret_type)
  @sync_repo = args[:sync_repo] if args.key?(:sync_repo)
  @sync_wait_secs = args[:sync_wait_secs] if args.key?(:sync_wait_secs)
end