Class: Google::Apis::GkehubV1alpha::ConfigManagementSyncState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ConfigManagementSyncState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
State indicating an ACM's progress syncing configurations to a cluster
Instance Attribute Summary collapse
-
#code ⇒ String
Sync status code Corresponds to the JSON property
code. -
#errors ⇒ Array<Google::Apis::GkehubV1alpha::ConfigManagementSyncError>
A list of errors resulting from problematic configs.
-
#import_token ⇒ String
Token indicating the state of the importer.
-
#last_sync ⇒ String
Deprecated: use last_sync_time instead.
-
#last_sync_time ⇒ String
Timestamp type of when ACM last successfully synced the repo Corresponds to the JSON property
lastSyncTime. -
#source_token ⇒ String
Token indicating the state of the repo.
-
#sync_token ⇒ String
Token indicating the state of the syncer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementSyncState
constructor
A new instance of ConfigManagementSyncState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementSyncState
Returns a new instance of ConfigManagementSyncState.
2321 2322 2323 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2321 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Sync status code
Corresponds to the JSON property code
2285 2286 2287 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2285 def code @code end |
#errors ⇒ Array<Google::Apis::GkehubV1alpha::ConfigManagementSyncError>
A list of errors resulting from problematic configs. This list will be
truncated after 100 errors, although it is unlikely for that many errors to
simultaneously exist.
Corresponds to the JSON property errors
2292 2293 2294 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2292 def errors @errors end |
#import_token ⇒ String
Token indicating the state of the importer.
Corresponds to the JSON property importToken
2297 2298 2299 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2297 def import_token @import_token end |
#last_sync ⇒ String
Deprecated: use last_sync_time instead. Timestamp of when ACM last
successfully synced the repo The time format is specified in https://golang.
org/pkg/time/#Time.String
Corresponds to the JSON property lastSync
2304 2305 2306 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2304 def last_sync @last_sync end |
#last_sync_time ⇒ String
Timestamp type of when ACM last successfully synced the repo
Corresponds to the JSON property lastSyncTime
2309 2310 2311 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2309 def last_sync_time @last_sync_time end |
#source_token ⇒ String
Token indicating the state of the repo.
Corresponds to the JSON property sourceToken
2314 2315 2316 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2314 def source_token @source_token end |
#sync_token ⇒ String
Token indicating the state of the syncer.
Corresponds to the JSON property syncToken
2319 2320 2321 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2319 def sync_token @sync_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2326 2327 2328 2329 2330 2331 2332 2333 2334 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2326 def update!(**args) @code = args[:code] if args.key?(:code) @errors = args[:errors] if args.key?(:errors) @import_token = args[:import_token] if args.key?(:import_token) @last_sync = args[:last_sync] if args.key?(:last_sync) @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time) @source_token = args[:source_token] if args.key?(:source_token) @sync_token = args[:sync_token] if args.key?(:sync_token) end |