Class: Google::Apis::GkehubV1alpha::ConfigManagementSyncState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

State indicating an ACM's progress syncing configurations to a cluster

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementSyncState

Returns a new instance of ConfigManagementSyncState.



2302
2303
2304
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2302

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Sync status code Corresponds to the JSON property code

Returns:

  • (String)


2266
2267
2268
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2266

def code
  @code
end

#errorsArray<Google::Apis::GkehubV1alpha::ConfigManagementSyncError>

A list of errors resulting from problematic configs. This list will be truncated after 100 errors, although it is unlikely for that many errors to simultaneously exist. Corresponds to the JSON property errors



2273
2274
2275
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2273

def errors
  @errors
end

#import_tokenString

Token indicating the state of the importer. Corresponds to the JSON property importToken

Returns:

  • (String)


2278
2279
2280
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2278

def import_token
  @import_token
end

#last_syncString

Deprecated: use last_sync_time instead. Timestamp of when ACM last successfully synced the repo The time format is specified in https://golang. org/pkg/time/#Time.String Corresponds to the JSON property lastSync

Returns:

  • (String)


2285
2286
2287
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2285

def last_sync
  @last_sync
end

#last_sync_timeString

Timestamp type of when ACM last successfully synced the repo Corresponds to the JSON property lastSyncTime

Returns:

  • (String)


2290
2291
2292
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2290

def last_sync_time
  @last_sync_time
end

#source_tokenString

Token indicating the state of the repo. Corresponds to the JSON property sourceToken

Returns:

  • (String)


2295
2296
2297
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2295

def source_token
  @source_token
end

#sync_tokenString

Token indicating the state of the syncer. Corresponds to the JSON property syncToken

Returns:

  • (String)


2300
2301
2302
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2300

def sync_token
  @sync_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2307

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @errors = args[:errors] if args.key?(:errors)
  @import_token = args[:import_token] if args.key?(:import_token)
  @last_sync = args[:last_sync] if args.key?(:last_sync)
  @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time)
  @source_token = args[:source_token] if args.key?(:source_token)
  @sync_token = args[:sync_token] if args.key?(:sync_token)
end