Class: Google::Apis::GkehubV1alpha::ConfigManagementSyncState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

State indicating an ACM's progress syncing configurations to a cluster

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementSyncState

Returns a new instance of ConfigManagementSyncState.



2273
2274
2275
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2273

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Sync status code Corresponds to the JSON property code

Returns:

  • (String)


2237
2238
2239
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2237

def code
  @code
end

#errorsArray<Google::Apis::GkehubV1alpha::ConfigManagementSyncError>

A list of errors resulting from problematic configs. This list will be truncated after 100 errors, although it is unlikely for that many errors to simultaneously exist. Corresponds to the JSON property errors



2244
2245
2246
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2244

def errors
  @errors
end

#import_tokenString

Token indicating the state of the importer. Corresponds to the JSON property importToken

Returns:

  • (String)


2249
2250
2251
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2249

def import_token
  @import_token
end

#last_syncString

Deprecated: use last_sync_time instead. Timestamp of when ACM last successfully synced the repo The time format is specified in https://golang. org/pkg/time/#Time.String Corresponds to the JSON property lastSync

Returns:

  • (String)


2256
2257
2258
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2256

def last_sync
  @last_sync
end

#last_sync_timeString

Timestamp type of when ACM last successfully synced the repo Corresponds to the JSON property lastSyncTime

Returns:

  • (String)


2261
2262
2263
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2261

def last_sync_time
  @last_sync_time
end

#source_tokenString

Token indicating the state of the repo. Corresponds to the JSON property sourceToken

Returns:

  • (String)


2266
2267
2268
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2266

def source_token
  @source_token
end

#sync_tokenString

Token indicating the state of the syncer. Corresponds to the JSON property syncToken

Returns:

  • (String)


2271
2272
2273
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2271

def sync_token
  @sync_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2278
2279
2280
2281
2282
2283
2284
2285
2286
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2278

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @errors = args[:errors] if args.key?(:errors)
  @import_token = args[:import_token] if args.key?(:import_token)
  @last_sync = args[:last_sync] if args.key?(:last_sync)
  @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time)
  @source_token = args[:source_token] if args.key?(:source_token)
  @sync_token = args[:sync_token] if args.key?(:sync_token)
end