Class: Google::Apis::GkehubV1alpha::ConnectAgentResource
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ConnectAgentResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
ConnectAgentResource represents a Kubernetes resource manifest for Connect Agent deployment.
Instance Attribute Summary collapse
-
#manifest ⇒ String
YAML manifest of the resource.
-
#type ⇒ Google::Apis::GkehubV1alpha::TypeMeta
TypeMeta is the type information needed for content unmarshalling of Kubernetes resources in the manifest.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConnectAgentResource
constructor
A new instance of ConnectAgentResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConnectAgentResource
Returns a new instance of ConnectAgentResource.
2334 2335 2336 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2334 def initialize(**args) update!(**args) end |
Instance Attribute Details
#manifest ⇒ String
YAML manifest of the resource.
Corresponds to the JSON property manifest
2326 2327 2328 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2326 def manifest @manifest end |
#type ⇒ Google::Apis::GkehubV1alpha::TypeMeta
TypeMeta is the type information needed for content unmarshalling of
Kubernetes resources in the manifest.
Corresponds to the JSON property type
2332 2333 2334 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2332 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2339 2340 2341 2342 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2339 def update!(**args) @manifest = args[:manifest] if args.key?(:manifest) @type = args[:type] if args.key?(:type) end |