Class: Google::Apis::GkehubV1alpha::ExcludedCluster
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ExcludedCluster
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
An excluded cluster from the rollout.
Instance Attribute Summary collapse
-
#membership ⇒ String
Output only.
-
#reason ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExcludedCluster
constructor
A new instance of ExcludedCluster.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExcludedCluster
Returns a new instance of ExcludedCluster.
2423 2424 2425 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2423 def initialize(**args) update!(**args) end |
Instance Attribute Details
#membership ⇒ String
Output only. The name of the fleet Membership resource associated to the
excluded cluster.
Corresponds to the JSON property membership
2416 2417 2418 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2416 def membership @membership end |
#reason ⇒ String
Output only. The reason for excluding the cluster from the rollout.
Corresponds to the JSON property reason
2421 2422 2423 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2421 def reason @reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2428 2429 2430 2431 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2428 def update!(**args) @membership = args[:membership] if args.key?(:membership) @reason = args[:reason] if args.key?(:reason) end |