Class: Google::Apis::GkehubV1alpha::FeatureResourceState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

FeatureResourceState describes the state of a Feature resource in the GkeHub API. See FeatureState for the "running state" of the Feature in the Fleet and across Memberships.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FeatureResourceState

Returns a new instance of FeatureResourceState.



2653
2654
2655
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2653

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

The current state of the Feature resource in the Hub API. Corresponds to the JSON property state

Returns:

  • (String)


2651
2652
2653
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2651

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2658
2659
2660
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2658

def update!(**args)
  @state = args[:state] if args.key?(:state)
end