Class: Google::Apis::GkehubV1alpha::FeatureResourceState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

FeatureResourceState describes the state of a Feature resource in the GkeHub API. See FeatureState for the "running state" of the Feature in the Fleet and across Memberships.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FeatureResourceState

Returns a new instance of FeatureResourceState.



2634
2635
2636
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2634

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

The current state of the Feature resource in the Hub API. Corresponds to the JSON property state

Returns:

  • (String)


2632
2633
2634
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2632

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2639
2640
2641
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2639

def update!(**args)
  @state = args[:state] if args.key?(:state)
end