Class: Google::Apis::GkehubV1alpha::FleetObservabilityFleetObservabilityBaseFeatureState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::FleetObservabilityFleetObservabilityBaseFeatureState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Base state for fleet observability feature.
Instance Attribute Summary collapse
-
#code ⇒ String
The high-level, machine-readable status of this Feature.
-
#errors ⇒ Array<Google::Apis::GkehubV1alpha::FleetObservabilityFeatureError>
Errors after reconciling the monitoring and logging feature if the code is not OK.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FleetObservabilityFleetObservabilityBaseFeatureState
constructor
A new instance of FleetObservabilityFleetObservabilityBaseFeatureState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FleetObservabilityFleetObservabilityBaseFeatureState
Returns a new instance of FleetObservabilityFleetObservabilityBaseFeatureState.
2882 2883 2884 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2882 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The high-level, machine-readable status of this Feature.
Corresponds to the JSON property code
2874 2875 2876 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2874 def code @code end |
#errors ⇒ Array<Google::Apis::GkehubV1alpha::FleetObservabilityFeatureError>
Errors after reconciling the monitoring and logging feature if the code is not
OK.
Corresponds to the JSON property errors
2880 2881 2882 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2880 def errors @errors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2887 2888 2889 2890 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 2887 def update!(**args) @code = args[:code] if args.key?(:code) @errors = args[:errors] if args.key?(:errors) end |