Class: Google::Apis::GkehubV1alpha::GenerateExclusivityManifestResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::GenerateExclusivityManifestResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
The response of the exclusivity artifacts manifests for the client to apply.
Instance Attribute Summary collapse
-
#cr_manifest ⇒ String
The YAML manifest of the membership CR to apply if a new version of the CR is available.
-
#crd_manifest ⇒ String
The YAML manifest of the membership CRD to apply if a newer version of the CRD is available.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateExclusivityManifestResponse
constructor
A new instance of GenerateExclusivityManifestResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateExclusivityManifestResponse
Returns a new instance of GenerateExclusivityManifestResponse.
3068 3069 3070 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3068 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cr_manifest ⇒ String
The YAML manifest of the membership CR to apply if a new version of the CR is
available. Empty if no update needs to be applied.
Corresponds to the JSON property crManifest
3060 3061 3062 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3060 def cr_manifest @cr_manifest end |
#crd_manifest ⇒ String
The YAML manifest of the membership CRD to apply if a newer version of the CRD
is available. Empty if no update needs to be applied.
Corresponds to the JSON property crdManifest
3066 3067 3068 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3066 def crd_manifest @crd_manifest end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3073 3074 3075 3076 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3073 def update!(**args) @cr_manifest = args[:cr_manifest] if args.key?(:cr_manifest) @crd_manifest = args[:crd_manifest] if args.key?(:crd_manifest) end |