Class: Google::Apis::GkehubV1alpha::IdentityServiceGroupConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Contains the properties for locating and authenticating groups in the directory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceGroupConfig

Returns a new instance of IdentityServiceGroupConfig.



3370
3371
3372
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3370

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_dnString

Required. The location of the subtree in the LDAP directory to search for group entries. Corresponds to the JSON property baseDn

Returns:

  • (String)


3353
3354
3355
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3353

def base_dn
  @base_dn
end

#filterString

Optional. Optional filter to be used when searching for groups a user belongs to. This can be used to explicitly match only certain groups in order to reduce the amount of groups returned for each user. This defaults to "( objectClass=Group)". Corresponds to the JSON property filter

Returns:

  • (String)


3361
3362
3363
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3361

def filter
  @filter
end

#id_attributeString

Optional. The identifying name of each group a user belongs to. For example, if this is set to "distinguishedName" then RBACs and other group expectations should be written as full DNs. This defaults to "distinguishedName". Corresponds to the JSON property idAttribute

Returns:

  • (String)


3368
3369
3370
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3368

def id_attribute
  @id_attribute
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3375
3376
3377
3378
3379
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3375

def update!(**args)
  @base_dn = args[:base_dn] if args.key?(:base_dn)
  @filter = args[:filter] if args.key?(:filter)
  @id_attribute = args[:id_attribute] if args.key?(:id_attribute)
end