Class: Google::Apis::GkehubV1alpha::IdentityServiceLdapConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Configuration for the LDAP Auth flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceLdapConfig

Returns a new instance of IdentityServiceLdapConfig.



3447
3448
3449
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupGoogle::Apis::GkehubV1alpha::IdentityServiceGroupConfig

Contains the properties for locating and authenticating groups in the directory. Corresponds to the JSON property group



3428
3429
3430
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3428

def group
  @group
end

#serverGoogle::Apis::GkehubV1alpha::IdentityServiceServerConfig

Server settings for the external LDAP server. Corresponds to the JSON property server



3433
3434
3435
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3433

def server
  @server
end

#service_accountGoogle::Apis::GkehubV1alpha::IdentityServiceServiceAccountConfig

Contains the credentials of the service account which is authorized to perform the LDAP search in the directory. The credentials can be supplied by the combination of the DN and password or the client certificate. Corresponds to the JSON property serviceAccount



3440
3441
3442
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3440

def 
  @service_account
end

#userGoogle::Apis::GkehubV1alpha::IdentityServiceUserConfig

Defines where users exist in the LDAP directory. Corresponds to the JSON property user



3445
3446
3447
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3445

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3452
3453
3454
3455
3456
3457
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3452

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @server = args[:server] if args.key?(:server)
  @service_account = args[:service_account] if args.key?(:service_account)
  @user = args[:user] if args.key?(:user)
end