Class: Google::Apis::GkehubV1alpha::IdentityServiceLdapConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Configuration for the LDAP Auth flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceLdapConfig

Returns a new instance of IdentityServiceLdapConfig.



3434
3435
3436
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3434

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupGoogle::Apis::GkehubV1alpha::IdentityServiceGroupConfig

Contains the properties for locating and authenticating groups in the directory. Corresponds to the JSON property group



3415
3416
3417
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3415

def group
  @group
end

#serverGoogle::Apis::GkehubV1alpha::IdentityServiceServerConfig

Server settings for the external LDAP server. Corresponds to the JSON property server



3420
3421
3422
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3420

def server
  @server
end

#service_accountGoogle::Apis::GkehubV1alpha::IdentityServiceServiceAccountConfig

Contains the credentials of the service account which is authorized to perform the LDAP search in the directory. The credentials can be supplied by the combination of the DN and password or the client certificate. Corresponds to the JSON property serviceAccount



3427
3428
3429
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3427

def 
  @service_account
end

#userGoogle::Apis::GkehubV1alpha::IdentityServiceUserConfig

Defines where users exist in the LDAP directory. Corresponds to the JSON property user



3432
3433
3434
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3432

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3439
3440
3441
3442
3443
3444
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3439

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @server = args[:server] if args.key?(:server)
  @service_account = args[:service_account] if args.key?(:service_account)
  @user = args[:user] if args.key?(:user)
end