Class: Google::Apis::GkehubV1alpha::IdentityServiceLdapConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Configuration for the LDAP Auth flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceLdapConfig

Returns a new instance of IdentityServiceLdapConfig.



3418
3419
3420
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3418

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupGoogle::Apis::GkehubV1alpha::IdentityServiceGroupConfig

Contains the properties for locating and authenticating groups in the directory. Corresponds to the JSON property group



3399
3400
3401
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3399

def group
  @group
end

#serverGoogle::Apis::GkehubV1alpha::IdentityServiceServerConfig

Server settings for the external LDAP server. Corresponds to the JSON property server



3404
3405
3406
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3404

def server
  @server
end

#service_accountGoogle::Apis::GkehubV1alpha::IdentityServiceServiceAccountConfig

Contains the credentials of the service account which is authorized to perform the LDAP search in the directory. The credentials can be supplied by the combination of the DN and password or the client certificate. Corresponds to the JSON property serviceAccount



3411
3412
3413
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3411

def 
  @service_account
end

#userGoogle::Apis::GkehubV1alpha::IdentityServiceUserConfig

Defines where users exist in the LDAP directory. Corresponds to the JSON property user



3416
3417
3418
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3416

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3423
3424
3425
3426
3427
3428
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3423

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @server = args[:server] if args.key?(:server)
  @service_account = args[:service_account] if args.key?(:service_account)
  @user = args[:user] if args.key?(:user)
end