Class: Google::Apis::GkehubV1alpha::IdentityServiceServiceAccountConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Contains the credentials of the service account which is authorized to perform the LDAP search in the directory. The credentials can be supplied by the combination of the DN and password or the client certificate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceServiceAccountConfig

Returns a new instance of IdentityServiceServiceAccountConfig.



3716
3717
3718
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3716

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#simple_bind_credentialsGoogle::Apis::GkehubV1alpha::IdentityServiceSimpleBindCredentials

The structure holds the LDAP simple binding credential. Corresponds to the JSON property simpleBindCredentials



3714
3715
3716
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3714

def simple_bind_credentials
  @simple_bind_credentials
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3721
3722
3723
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3721

def update!(**args)
  @simple_bind_credentials = args[:simple_bind_credentials] if args.key?(:simple_bind_credentials)
end