Class: Google::Apis::GkehubV1alpha::ListAdminClusterMembershipsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ListAdminClusterMembershipsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Response message for the GkeHub.ListAdminClusterMemberships method.
Instance Attribute Summary collapse
-
#admin_cluster_memberships ⇒ Array<Google::Apis::GkehubV1alpha::Membership>
The list of matching Memberships of admin clusters.
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListAdminClusterMembershipsmethod. -
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListAdminClusterMembershipsResponse
constructor
A new instance of ListAdminClusterMembershipsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListAdminClusterMembershipsResponse
Returns a new instance of ListAdminClusterMembershipsResponse.
3986 3987 3988 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3986 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_cluster_memberships ⇒ Array<Google::Apis::GkehubV1alpha::Membership>
The list of matching Memberships of admin clusters.
Corresponds to the JSON property adminClusterMemberships
3972 3973 3974 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3972 def admin_cluster_memberships @admin_cluster_memberships end |
#next_page_token ⇒ String
A token to request the next page of resources from the
ListAdminClusterMemberships method. The value of an empty string means that
there are no more resources to return.
Corresponds to the JSON property nextPageToken
3979 3980 3981 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3979 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
3984 3985 3986 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3984 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3991 3992 3993 3994 3995 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3991 def update!(**args) @admin_cluster_memberships = args[:admin_cluster_memberships] if args.key?(:admin_cluster_memberships) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |