Class: Google::Apis::GkehubV1alpha::ListAdminClusterMembershipsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Response message for the GkeHub.ListAdminClusterMemberships method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAdminClusterMembershipsResponse

Returns a new instance of ListAdminClusterMembershipsResponse.



3983
3984
3985
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3983

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_cluster_membershipsArray<Google::Apis::GkehubV1alpha::Membership>

The list of matching Memberships of admin clusters. Corresponds to the JSON property adminClusterMemberships



3969
3970
3971
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3969

def admin_cluster_memberships
  @admin_cluster_memberships
end

#next_page_tokenString

A token to request the next page of resources from the ListAdminClusterMemberships method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3976
3977
3978
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3976

def next_page_token
  @next_page_token
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3981
3982
3983
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3981

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3988
3989
3990
3991
3992
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3988

def update!(**args)
  @admin_cluster_memberships = args[:admin_cluster_memberships] if args.key?(:admin_cluster_memberships)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end