Class: Google::Apis::GkehubV1alpha::ListAdminClusterMembershipsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ListAdminClusterMembershipsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Response message for the GkeHub.ListAdminClusterMemberships method.
Instance Attribute Summary collapse
-
#admin_cluster_memberships ⇒ Array<Google::Apis::GkehubV1alpha::Membership>
The list of matching Memberships of admin clusters.
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListAdminClusterMembershipsmethod. -
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListAdminClusterMembershipsResponse
constructor
A new instance of ListAdminClusterMembershipsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListAdminClusterMembershipsResponse
Returns a new instance of ListAdminClusterMembershipsResponse.
3956 3957 3958 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3956 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_cluster_memberships ⇒ Array<Google::Apis::GkehubV1alpha::Membership>
The list of matching Memberships of admin clusters.
Corresponds to the JSON property adminClusterMemberships
3942 3943 3944 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3942 def admin_cluster_memberships @admin_cluster_memberships end |
#next_page_token ⇒ String
A token to request the next page of resources from the
ListAdminClusterMemberships method. The value of an empty string means that
there are no more resources to return.
Corresponds to the JSON property nextPageToken
3949 3950 3951 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3949 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
3954 3955 3956 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3954 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3961 3962 3963 3964 3965 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3961 def update!(**args) @admin_cluster_memberships = args[:admin_cluster_memberships] if args.key?(:admin_cluster_memberships) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |