Class: Google::Apis::GkehubV1alpha::ListAdminClusterMembershipsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ListAdminClusterMembershipsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Response message for the GkeHub.ListAdminClusterMemberships method.
Instance Attribute Summary collapse
-
#admin_cluster_memberships ⇒ Array<Google::Apis::GkehubV1alpha::Membership>
The list of matching Memberships of admin clusters.
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListAdminClusterMembershipsmethod. -
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListAdminClusterMembershipsResponse
constructor
A new instance of ListAdminClusterMembershipsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListAdminClusterMembershipsResponse
Returns a new instance of ListAdminClusterMembershipsResponse.
3940 3941 3942 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3940 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_cluster_memberships ⇒ Array<Google::Apis::GkehubV1alpha::Membership>
The list of matching Memberships of admin clusters.
Corresponds to the JSON property adminClusterMemberships
3926 3927 3928 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3926 def admin_cluster_memberships @admin_cluster_memberships end |
#next_page_token ⇒ String
A token to request the next page of resources from the
ListAdminClusterMemberships method. The value of an empty string means that
there are no more resources to return.
Corresponds to the JSON property nextPageToken
3933 3934 3935 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3933 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
3938 3939 3940 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3938 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3945 3946 3947 3948 3949 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3945 def update!(**args) @admin_cluster_memberships = args[:admin_cluster_memberships] if args.key?(:admin_cluster_memberships) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |