Class: Google::Apis::GkehubV1alpha::ListBoundMembershipsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

List of Memberships bound to a Scope.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBoundMembershipsResponse

Returns a new instance of ListBoundMembershipsResponse.



4016
4017
4018
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4016

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#membershipsArray<Google::Apis::GkehubV1alpha::Membership>

The list of Memberships bound to the given Scope. Corresponds to the JSON property memberships



4002
4003
4004
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4002

def memberships
  @memberships
end

#next_page_tokenString

A token to request the next page of resources from the ListBoundMemberships method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4009
4010
4011
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4009

def next_page_token
  @next_page_token
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4014
4015
4016
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4014

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4021
4022
4023
4024
4025
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4021

def update!(**args)
  @memberships = args[:memberships] if args.key?(:memberships)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end