Class: Google::Apis::GkehubV1alpha::ListBoundMembershipsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

List of Memberships bound to a Scope.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBoundMembershipsResponse

Returns a new instance of ListBoundMembershipsResponse.



4002
4003
4004
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#membershipsArray<Google::Apis::GkehubV1alpha::Membership>

The list of Memberships bound to the given Scope. Corresponds to the JSON property memberships



3988
3989
3990
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3988

def memberships
  @memberships
end

#next_page_tokenString

A token to request the next page of resources from the ListBoundMemberships method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3995
3996
3997
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3995

def next_page_token
  @next_page_token
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4000
4001
4002
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4000

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4007
4008
4009
4010
4011
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4007

def update!(**args)
  @memberships = args[:memberships] if args.key?(:memberships)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end