Class: Google::Apis::GkehubV1alpha::ListBoundMembershipsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

List of Memberships bound to a Scope.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBoundMembershipsResponse

Returns a new instance of ListBoundMembershipsResponse.



3989
3990
3991
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3989

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#membershipsArray<Google::Apis::GkehubV1alpha::Membership>

The list of Memberships bound to the given Scope. Corresponds to the JSON property memberships



3975
3976
3977
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3975

def memberships
  @memberships
end

#next_page_tokenString

A token to request the next page of resources from the ListBoundMemberships method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3982
3983
3984
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3982

def next_page_token
  @next_page_token
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3987
3988
3989
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3987

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3994
3995
3996
3997
3998
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3994

def update!(**args)
  @memberships = args[:memberships] if args.key?(:memberships)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end