Class: Google::Apis::GkehubV1alpha::ListBoundMembershipsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

List of Memberships bound to a Scope.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBoundMembershipsResponse

Returns a new instance of ListBoundMembershipsResponse.



3951
3952
3953
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3951

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#membershipsArray<Google::Apis::GkehubV1alpha::Membership>

The list of Memberships bound to the given Scope. Corresponds to the JSON property memberships



3937
3938
3939
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3937

def memberships
  @memberships
end

#next_page_tokenString

A token to request the next page of resources from the ListBoundMemberships method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3944
3945
3946
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3944

def next_page_token
  @next_page_token
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3949
3950
3951
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3949

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3956
3957
3958
3959
3960
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 3956

def update!(**args)
  @memberships = args[:memberships] if args.key?(:memberships)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end