Class: Google::Apis::GkehubV1alpha::ListFeaturesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ListFeaturesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Response message for the GkeHub.ListFeatures method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListFeaturesmethod. -
#resources ⇒ Array<Google::Apis::GkehubV1alpha::Feature>
The list of matching Features Corresponds to the JSON property
resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListFeaturesResponse
constructor
A new instance of ListFeaturesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListFeaturesResponse
Returns a new instance of ListFeaturesResponse.
4016 4017 4018 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4016 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListFeatures method.
The value of an empty string means that there are no more resources to return.
Corresponds to the JSON property nextPageToken
4009 4010 4011 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4009 def next_page_token @next_page_token end |
#resources ⇒ Array<Google::Apis::GkehubV1alpha::Feature>
The list of matching Features
Corresponds to the JSON property resources
4014 4015 4016 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4014 def resources @resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4021 4022 4023 4024 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4021 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resources = args[:resources] if args.key?(:resources) end |