Class: Google::Apis::GkehubV1alpha::ListMembershipBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

List of MembershipBindings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMembershipBindingsResponse

Returns a new instance of ListMembershipBindingsResponse.



4113
4114
4115
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4113

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#membership_bindingsArray<Google::Apis::GkehubV1alpha::MembershipBinding>

The list of membership_bindings Corresponds to the JSON property membershipBindings



4099
4100
4101
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4099

def membership_bindings
  @membership_bindings
end

#next_page_tokenString

A token to request the next page of resources from the ListMembershipBindings method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4106
4107
4108
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4106

def next_page_token
  @next_page_token
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4111
4112
4113
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4111

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4118
4119
4120
4121
4122
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4118

def update!(**args)
  @membership_bindings = args[:membership_bindings] if args.key?(:membership_bindings)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end