Class: Google::Apis::GkehubV1alpha::ListMembershipBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

List of MembershipBindings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMembershipBindingsResponse

Returns a new instance of ListMembershipBindingsResponse.



4062
4063
4064
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#membership_bindingsArray<Google::Apis::GkehubV1alpha::MembershipBinding>

The list of membership_bindings Corresponds to the JSON property membershipBindings



4048
4049
4050
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4048

def membership_bindings
  @membership_bindings
end

#next_page_tokenString

A token to request the next page of resources from the ListMembershipBindings method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4055
4056
4057
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4055

def next_page_token
  @next_page_token
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4060
4061
4062
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4060

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4067
4068
4069
4070
4071
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4067

def update!(**args)
  @membership_bindings = args[:membership_bindings] if args.key?(:membership_bindings)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end