Class: Google::Apis::GkehubV1alpha::ListMembershipRbacRoleBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

List of Membership RBACRoleBindings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMembershipRbacRoleBindingsResponse

Returns a new instance of ListMembershipRbacRoleBindingsResponse.



4146
4147
4148
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4146

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListMembershipRBACRoleBindings method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4134
4135
4136
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4134

def next_page_token
  @next_page_token
end

#rbacrolebindingsArray<Google::Apis::GkehubV1alpha::RbacRoleBinding>

The list of Membership RBACRoleBindings. Corresponds to the JSON property rbacrolebindings



4139
4140
4141
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4139

def rbacrolebindings
  @rbacrolebindings
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4144
4145
4146
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4144

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4151
4152
4153
4154
4155
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4151

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @rbacrolebindings = args[:rbacrolebindings] if args.key?(:rbacrolebindings)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end