Class: Google::Apis::GkehubV1alpha::ListMembershipRbacRoleBindingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ListMembershipRbacRoleBindingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
List of Membership RBACRoleBindings.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipRBACRoleBindingsmethod. -
#rbacrolebindings ⇒ Array<Google::Apis::GkehubV1alpha::RbacRoleBinding>
The list of Membership RBACRoleBindings.
-
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMembershipRbacRoleBindingsResponse
constructor
A new instance of ListMembershipRbacRoleBindingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMembershipRbacRoleBindingsResponse
Returns a new instance of ListMembershipRbacRoleBindingsResponse.
4117 4118 4119 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4117 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipRBACRoleBindings method. The value of an empty string means
that there are no more resources to return.
Corresponds to the JSON property nextPageToken
4105 4106 4107 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4105 def next_page_token @next_page_token end |
#rbacrolebindings ⇒ Array<Google::Apis::GkehubV1alpha::RbacRoleBinding>
The list of Membership RBACRoleBindings.
Corresponds to the JSON property rbacrolebindings
4110 4111 4112 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4110 def rbacrolebindings @rbacrolebindings end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
4115 4116 4117 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4115 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4122 4123 4124 4125 4126 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4122 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rbacrolebindings = args[:rbacrolebindings] if args.key?(:rbacrolebindings) @unreachable = args[:unreachable] if args.key?(:unreachable) end |