Class: Google::Apis::GkehubV1alpha::ListMembershipsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Response message for the GkeHub.ListMemberships method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMembershipsResponse

Returns a new instance of ListMembershipsResponse.



4193
4194
4195
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4193

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListMemberships method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4181
4182
4183
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4181

def next_page_token
  @next_page_token
end

#resourcesArray<Google::Apis::GkehubV1alpha::Membership>

The list of matching Memberships. Corresponds to the JSON property resources



4186
4187
4188
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4186

def resources
  @resources
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4191
4192
4193
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4191

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4198
4199
4200
4201
4202
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4198

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @resources = args[:resources] if args.key?(:resources)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end