Class: Google::Apis::GkehubV1alpha::ListMembershipsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ListMembershipsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Response message for the GkeHub.ListMemberships method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipsmethod. -
#resources ⇒ Array<Google::Apis::GkehubV1alpha::Membership>
The list of matching Memberships.
-
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMembershipsResponse
constructor
A new instance of ListMembershipsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMembershipsResponse
Returns a new instance of ListMembershipsResponse.
4179 4180 4181 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4179 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListMemberships
method. The value of an empty string means that there are no more resources to
return.
Corresponds to the JSON property nextPageToken
4167 4168 4169 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4167 def next_page_token @next_page_token end |
#resources ⇒ Array<Google::Apis::GkehubV1alpha::Membership>
The list of matching Memberships.
Corresponds to the JSON property resources
4172 4173 4174 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4172 def resources @resources end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
4177 4178 4179 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4177 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4184 4185 4186 4187 4188 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4184 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resources = args[:resources] if args.key?(:resources) @unreachable = args[:unreachable] if args.key?(:unreachable) end |