Class: Google::Apis::GkehubV1alpha::ListMembershipsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Response message for the GkeHub.ListMemberships method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMembershipsResponse

Returns a new instance of ListMembershipsResponse.



4128
4129
4130
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListMemberships method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4116
4117
4118
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4116

def next_page_token
  @next_page_token
end

#resourcesArray<Google::Apis::GkehubV1alpha::Membership>

The list of matching Memberships. Corresponds to the JSON property resources



4121
4122
4123
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4121

def resources
  @resources
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4126
4127
4128
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4126

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4133
4134
4135
4136
4137
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4133

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @resources = args[:resources] if args.key?(:resources)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end