Class: Google::Apis::GkehubV1alpha::ListMembershipsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Response message for the GkeHub.ListMemberships method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMembershipsResponse

Returns a new instance of ListMembershipsResponse.



4150
4151
4152
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4150

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListMemberships method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4138
4139
4140
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4138

def next_page_token
  @next_page_token
end

#resourcesArray<Google::Apis::GkehubV1alpha::Membership>

The list of matching Memberships. Corresponds to the JSON property resources



4143
4144
4145
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4143

def resources
  @resources
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4148
4149
4150
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4148

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4155
4156
4157
4158
4159
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4155

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @resources = args[:resources] if args.key?(:resources)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end