Class: Google::Apis::GkehubV1alpha::ListPermittedScopesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ListPermittedScopesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
List of permitted Scopes.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListPermittedScopesmethod. -
#scopes ⇒ Array<Google::Apis::GkehubV1alpha::Scope>
The list of permitted Scopes Corresponds to the JSON property
scopes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPermittedScopesResponse
constructor
A new instance of ListPermittedScopesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPermittedScopesResponse
Returns a new instance of ListPermittedScopesResponse.
4255 4256 4257 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4255 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListPermittedScopes
method. The value of an empty string means that there are no more resources to
return.
Corresponds to the JSON property nextPageToken
4248 4249 4250 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4248 def next_page_token @next_page_token end |
#scopes ⇒ Array<Google::Apis::GkehubV1alpha::Scope>
The list of permitted Scopes
Corresponds to the JSON property scopes
4253 4254 4255 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4253 def scopes @scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4260 4261 4262 4263 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4260 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scopes = args[:scopes] if args.key?(:scopes) end |