Class: Google::Apis::GkehubV1alpha::ListPermittedScopesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

List of permitted Scopes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPermittedScopesResponse

Returns a new instance of ListPermittedScopesResponse.



4190
4191
4192
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListPermittedScopes method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4183
4184
4185
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4183

def next_page_token
  @next_page_token
end

#scopesArray<Google::Apis::GkehubV1alpha::Scope>

The list of permitted Scopes Corresponds to the JSON property scopes



4188
4189
4190
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4188

def scopes
  @scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4195
4196
4197
4198
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4195

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scopes = args[:scopes] if args.key?(:scopes)
end