Class: Google::Apis::GkehubV1alpha::ListScopeNamespacesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ListScopeNamespacesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
List of fleet namespaces.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListNamespacesmethod. -
#scope_namespaces ⇒ Array<Google::Apis::GkehubV1alpha::Namespace>
The list of fleet namespaces Corresponds to the JSON property
scopeNamespaces.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListScopeNamespacesResponse
constructor
A new instance of ListScopeNamespacesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListScopeNamespacesResponse
Returns a new instance of ListScopeNamespacesResponse.
4336 4337 4338 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListNamespaces method.
The value of an empty string means that there are no more resources to return.
Corresponds to the JSON property nextPageToken
4329 4330 4331 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4329 def next_page_token @next_page_token end |
#scope_namespaces ⇒ Array<Google::Apis::GkehubV1alpha::Namespace>
The list of fleet namespaces
Corresponds to the JSON property scopeNamespaces
4334 4335 4336 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4334 def scope_namespaces @scope_namespaces end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4341 4342 4343 4344 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4341 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scope_namespaces = args[:scope_namespaces] if args.key?(:scope_namespaces) end |