Class: Google::Apis::GkehubV1alpha::ListScopeNamespacesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

List of fleet namespaces.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListScopeNamespacesResponse

Returns a new instance of ListScopeNamespacesResponse.



4268
4269
4270
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListNamespaces method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4261
4262
4263
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4261

def next_page_token
  @next_page_token
end

#scope_namespacesArray<Google::Apis::GkehubV1alpha::Namespace>

The list of fleet namespaces Corresponds to the JSON property scopeNamespaces



4266
4267
4268
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4266

def scope_namespaces
  @scope_namespaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4273
4274
4275
4276
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4273

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scope_namespaces = args[:scope_namespaces] if args.key?(:scope_namespaces)
end