Class: Google::Apis::GkehubV1alpha::ListScopeRbacRoleBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

List of Scope RBACRoleBindings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListScopeRbacRoleBindingsResponse

Returns a new instance of ListScopeRbacRoleBindingsResponse.



4295
4296
4297
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListScopeRBACRoleBindings method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4288
4289
4290
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4288

def next_page_token
  @next_page_token
end

#rbacrolebindingsArray<Google::Apis::GkehubV1alpha::RbacRoleBinding>

The list of Scope RBACRoleBindings. Corresponds to the JSON property rbacrolebindings



4293
4294
4295
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4293

def rbacrolebindings
  @rbacrolebindings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4300
4301
4302
4303
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4300

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @rbacrolebindings = args[:rbacrolebindings] if args.key?(:rbacrolebindings)
end