Class: Google::Apis::GkehubV1alpha::ListScopesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ListScopesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
List of Scopes.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListScopesmethod. -
#scopes ⇒ Array<Google::Apis::GkehubV1alpha::Scope>
The list of Scopes Corresponds to the JSON property
scopes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListScopesResponse
constructor
A new instance of ListScopesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListScopesResponse
Returns a new instance of ListScopesResponse.
4389 4390 4391 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListScopes method.
The value of an empty string means that there are no more resources to return.
Corresponds to the JSON property nextPageToken
4382 4383 4384 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4382 def next_page_token @next_page_token end |
#scopes ⇒ Array<Google::Apis::GkehubV1alpha::Scope>
The list of Scopes
Corresponds to the JSON property scopes
4387 4388 4389 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4387 def scopes @scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4394 4395 4396 4397 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4394 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scopes = args[:scopes] if args.key?(:scopes) end |