Class: Google::Apis::GkehubV1alpha::ListScopesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

List of Scopes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListScopesResponse

Returns a new instance of ListScopesResponse.



4359
4360
4361
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4359

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListScopes method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4352
4353
4354
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4352

def next_page_token
  @next_page_token
end

#scopesArray<Google::Apis::GkehubV1alpha::Scope>

The list of Scopes Corresponds to the JSON property scopes



4357
4358
4359
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4357

def scopes
  @scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4364
4365
4366
4367
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4364

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scopes = args[:scopes] if args.key?(:scopes)
end