Class: Google::Apis::GkehubV1alpha::ListScopesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ListScopesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
List of Scopes.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListScopesmethod. -
#scopes ⇒ Array<Google::Apis::GkehubV1alpha::Scope>
The list of Scopes Corresponds to the JSON property
scopes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListScopesResponse
constructor
A new instance of ListScopesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListScopesResponse
Returns a new instance of ListScopesResponse.
4321 4322 4323 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4321 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListScopes method.
The value of an empty string means that there are no more resources to return.
Corresponds to the JSON property nextPageToken
4314 4315 4316 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4314 def next_page_token @next_page_token end |
#scopes ⇒ Array<Google::Apis::GkehubV1alpha::Scope>
The list of Scopes
Corresponds to the JSON property scopes
4319 4320 4321 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4319 def scopes @scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4326 4327 4328 4329 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4326 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scopes = args[:scopes] if args.key?(:scopes) end |