Class: Google::Apis::GkehubV1alpha::MembershipFeatureSpec
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::MembershipFeatureSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
MembershipFeatureSpec contains configuration information for a single Membership.
Instance Attribute Summary collapse
-
#cloudbuild ⇒ Google::Apis::GkehubV1alpha::CloudBuildMembershipSpec
Cloud Build: Configurations for each Cloud Build enabled cluster.
-
#configmanagement ⇒ Google::Apis::GkehubV1alpha::ConfigManagementMembershipSpec
Anthos Config Management: Configuration for a single cluster.
-
#fleetobservability ⇒ Google::Apis::GkehubV1alpha::FleetObservabilityMembershipSpec
FleetObservability: The membership-specific input for FleetObservability feature.
-
#identityservice ⇒ Google::Apis::GkehubV1alpha::IdentityServiceMembershipSpec
Anthos Identity Service: Configuration for a single Membership.
-
#mesh ⇒ Google::Apis::GkehubV1alpha::ServiceMeshMembershipSpec
Service Mesh: Spec for a single Membership for the servicemesh feature Corresponds to the JSON property
mesh. -
#namespaceactuation ⇒ Google::Apis::GkehubV1alpha::NamespaceActuationMembershipSpec
Namespace Actuation: The membership-specific input for NamespaceActuation feature.
-
#origin ⇒ Google::Apis::GkehubV1alpha::Origin
Origin defines where this MembershipFeatureSpec originated from.
-
#policycontroller ⇒ Google::Apis::GkehubV1alpha::PolicyControllerMembershipSpec
Policy Controller: Configuration for a single cluster.
-
#workloadcertificate ⇒ Google::Apis::GkehubV1alpha::MembershipSpec
Workload Certificate: The membership-specific input for WorkloadCertificate feature.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MembershipFeatureSpec
constructor
A new instance of MembershipFeatureSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MembershipFeatureSpec
Returns a new instance of MembershipFeatureSpec.
4711 4712 4713 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloudbuild ⇒ Google::Apis::GkehubV1alpha::CloudBuildMembershipSpec
Cloud Build: Configurations for each Cloud Build enabled cluster.
Corresponds to the JSON property cloudbuild
4664 4665 4666 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4664 def cloudbuild @cloudbuild end |
#configmanagement ⇒ Google::Apis::GkehubV1alpha::ConfigManagementMembershipSpec
Anthos Config Management: Configuration for a single cluster. Intended to
parallel the ConfigManagement CR.
Corresponds to the JSON property configmanagement
4670 4671 4672 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4670 def configmanagement @configmanagement end |
#fleetobservability ⇒ Google::Apis::GkehubV1alpha::FleetObservabilityMembershipSpec
FleetObservability: The membership-specific input for FleetObservability
feature.
Corresponds to the JSON property fleetobservability
4676 4677 4678 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4676 def fleetobservability @fleetobservability end |
#identityservice ⇒ Google::Apis::GkehubV1alpha::IdentityServiceMembershipSpec
Anthos Identity Service: Configuration for a single Membership.
Corresponds to the JSON property identityservice
4681 4682 4683 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4681 def identityservice @identityservice end |
#mesh ⇒ Google::Apis::GkehubV1alpha::ServiceMeshMembershipSpec
Service Mesh: Spec for a single Membership for the servicemesh feature
Corresponds to the JSON property mesh
4686 4687 4688 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4686 def mesh @mesh end |
#namespaceactuation ⇒ Google::Apis::GkehubV1alpha::NamespaceActuationMembershipSpec
Namespace Actuation: The membership-specific input for NamespaceActuation
feature.
Corresponds to the JSON property namespaceactuation
4692 4693 4694 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4692 def namespaceactuation @namespaceactuation end |
#origin ⇒ Google::Apis::GkehubV1alpha::Origin
Origin defines where this MembershipFeatureSpec originated from.
Corresponds to the JSON property origin
4697 4698 4699 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4697 def origin @origin end |
#policycontroller ⇒ Google::Apis::GkehubV1alpha::PolicyControllerMembershipSpec
Policy Controller: Configuration for a single cluster. Intended to
parallel the PolicyController CR.
Corresponds to the JSON property policycontroller
4703 4704 4705 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4703 def policycontroller @policycontroller end |
#workloadcertificate ⇒ Google::Apis::GkehubV1alpha::MembershipSpec
Workload Certificate: The membership-specific input for
WorkloadCertificate feature.
Corresponds to the JSON property workloadcertificate
4709 4710 4711 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4709 def workloadcertificate @workloadcertificate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4716 def update!(**args) @cloudbuild = args[:cloudbuild] if args.key?(:cloudbuild) @configmanagement = args[:configmanagement] if args.key?(:configmanagement) @fleetobservability = args[:fleetobservability] if args.key?(:fleetobservability) @identityservice = args[:identityservice] if args.key?(:identityservice) @mesh = args[:mesh] if args.key?(:mesh) @namespaceactuation = args[:namespaceactuation] if args.key?(:namespaceactuation) @origin = args[:origin] if args.key?(:origin) @policycontroller = args[:policycontroller] if args.key?(:policycontroller) @workloadcertificate = args[:workloadcertificate] if args.key?(:workloadcertificate) end |