Class: Google::Apis::GkehubV1alpha::MembershipFeatureState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

MembershipFeatureState contains Feature status information for a single Membership.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipFeatureState

Returns a new instance of MembershipFeatureState.



4846
4847
4848
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4846

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appdevexperienceGoogle::Apis::GkehubV1alpha::AppDevExperienceFeatureState

State for App Dev Exp Feature. Corresponds to the JSON property appdevexperience



4788
4789
4790
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4788

def appdevexperience
  @appdevexperience
end

#clusterupgradeGoogle::Apis::GkehubV1alpha::ClusterUpgradeMembershipState

Per-membership state for this feature. Corresponds to the JSON property clusterupgrade



4793
4794
4795
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4793

def clusterupgrade
  @clusterupgrade
end

#configmanagementGoogle::Apis::GkehubV1alpha::ConfigManagementMembershipState

Anthos Config Management: State for a single cluster. Corresponds to the JSON property configmanagement



4798
4799
4800
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4798

def configmanagement
  @configmanagement
end

#fleetobservabilityGoogle::Apis::GkehubV1alpha::FleetObservabilityMembershipState

FleetObservability: Membership-specific Feature state for fleetobservability. Corresponds to the JSON property fleetobservability



4804
4805
4806
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4804

def fleetobservability
  @fleetobservability
end

#identityserviceGoogle::Apis::GkehubV1alpha::IdentityServiceMembershipState

Anthos Identity Service: State for a single Membership. Corresponds to the JSON property identityservice



4809
4810
4811
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4809

def identityservice
  @identityservice
end

#meteringGoogle::Apis::GkehubV1alpha::MeteringMembershipState

Metering: Per-Membership Feature State. Corresponds to the JSON property metering



4814
4815
4816
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4814

def metering
  @metering
end

#namespaceactuationGoogle::Apis::GkehubV1alpha::NamespaceActuationMembershipState

Namespace Actuation: An empty state left as an example membership-specific Feature state. Corresponds to the JSON property namespaceactuation



4820
4821
4822
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4820

def namespaceactuation
  @namespaceactuation
end

#policycontrollerGoogle::Apis::GkehubV1alpha::PolicyControllerMembershipState

Policy Controller: State for a single cluster. Corresponds to the JSON property policycontroller



4825
4826
4827
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4825

def policycontroller
  @policycontroller
end

#servicemeshGoogle::Apis::GkehubV1alpha::ServiceMeshMembershipState

Service Mesh: State for a single Membership, as analyzed by the Service Mesh Hub Controller. Corresponds to the JSON property servicemesh



4831
4832
4833
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4831

def servicemesh
  @servicemesh
end

#stateGoogle::Apis::GkehubV1alpha::FeatureState

FeatureState describes the high-level state of a Feature. It may be used to describe a Feature's state at the environ-level, or per-membershop, depending on the context. Corresponds to the JSON property state



4838
4839
4840
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4838

def state
  @state
end

#workloadidentityGoogle::Apis::GkehubV1alpha::WorkloadIdentityMembershipState

WorkloadIdentity: The membership-specific state for WorkloadIdentity feature. Corresponds to the JSON property workloadidentity



4844
4845
4846
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4844

def workloadidentity
  @workloadidentity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4851

def update!(**args)
  @appdevexperience = args[:appdevexperience] if args.key?(:appdevexperience)
  @clusterupgrade = args[:clusterupgrade] if args.key?(:clusterupgrade)
  @configmanagement = args[:configmanagement] if args.key?(:configmanagement)
  @fleetobservability = args[:fleetobservability] if args.key?(:fleetobservability)
  @identityservice = args[:identityservice] if args.key?(:identityservice)
  @metering = args[:metering] if args.key?(:metering)
  @namespaceactuation = args[:namespaceactuation] if args.key?(:namespaceactuation)
  @policycontroller = args[:policycontroller] if args.key?(:policycontroller)
  @servicemesh = args[:servicemesh] if args.key?(:servicemesh)
  @state = args[:state] if args.key?(:state)
  @workloadidentity = args[:workloadidentity] if args.key?(:workloadidentity)
end