Class: Google::Apis::GkehubV1alpha::MembershipFeatureState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

MembershipFeatureState contains Feature status information for a single Membership.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipFeatureState

Returns a new instance of MembershipFeatureState.



4833
4834
4835
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4833

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appdevexperienceGoogle::Apis::GkehubV1alpha::AppDevExperienceFeatureState

State for App Dev Exp Feature. Corresponds to the JSON property appdevexperience



4775
4776
4777
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4775

def appdevexperience
  @appdevexperience
end

#clusterupgradeGoogle::Apis::GkehubV1alpha::ClusterUpgradeMembershipState

Per-membership state for this feature. Corresponds to the JSON property clusterupgrade



4780
4781
4782
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4780

def clusterupgrade
  @clusterupgrade
end

#configmanagementGoogle::Apis::GkehubV1alpha::ConfigManagementMembershipState

Anthos Config Management: State for a single cluster. Corresponds to the JSON property configmanagement



4785
4786
4787
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4785

def configmanagement
  @configmanagement
end

#fleetobservabilityGoogle::Apis::GkehubV1alpha::FleetObservabilityMembershipState

FleetObservability: Membership-specific Feature state for fleetobservability. Corresponds to the JSON property fleetobservability



4791
4792
4793
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4791

def fleetobservability
  @fleetobservability
end

#identityserviceGoogle::Apis::GkehubV1alpha::IdentityServiceMembershipState

Anthos Identity Service: State for a single Membership. Corresponds to the JSON property identityservice



4796
4797
4798
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4796

def identityservice
  @identityservice
end

#meteringGoogle::Apis::GkehubV1alpha::MeteringMembershipState

Metering: Per-Membership Feature State. Corresponds to the JSON property metering



4801
4802
4803
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4801

def metering
  @metering
end

#namespaceactuationGoogle::Apis::GkehubV1alpha::NamespaceActuationMembershipState

Namespace Actuation: An empty state left as an example membership-specific Feature state. Corresponds to the JSON property namespaceactuation



4807
4808
4809
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4807

def namespaceactuation
  @namespaceactuation
end

#policycontrollerGoogle::Apis::GkehubV1alpha::PolicyControllerMembershipState

Policy Controller: State for a single cluster. Corresponds to the JSON property policycontroller



4812
4813
4814
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4812

def policycontroller
  @policycontroller
end

#servicemeshGoogle::Apis::GkehubV1alpha::ServiceMeshMembershipState

Service Mesh: State for a single Membership, as analyzed by the Service Mesh Hub Controller. Corresponds to the JSON property servicemesh



4818
4819
4820
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4818

def servicemesh
  @servicemesh
end

#stateGoogle::Apis::GkehubV1alpha::FeatureState

FeatureState describes the high-level state of a Feature. It may be used to describe a Feature's state at the environ-level, or per-membershop, depending on the context. Corresponds to the JSON property state



4825
4826
4827
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4825

def state
  @state
end

#workloadidentityGoogle::Apis::GkehubV1alpha::WorkloadIdentityMembershipState

WorkloadIdentity: The membership-specific state for WorkloadIdentity feature. Corresponds to the JSON property workloadidentity



4831
4832
4833
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4831

def workloadidentity
  @workloadidentity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 4838

def update!(**args)
  @appdevexperience = args[:appdevexperience] if args.key?(:appdevexperience)
  @clusterupgrade = args[:clusterupgrade] if args.key?(:clusterupgrade)
  @configmanagement = args[:configmanagement] if args.key?(:configmanagement)
  @fleetobservability = args[:fleetobservability] if args.key?(:fleetobservability)
  @identityservice = args[:identityservice] if args.key?(:identityservice)
  @metering = args[:metering] if args.key?(:metering)
  @namespaceactuation = args[:namespaceactuation] if args.key?(:namespaceactuation)
  @policycontroller = args[:policycontroller] if args.key?(:policycontroller)
  @servicemesh = args[:servicemesh] if args.key?(:servicemesh)
  @state = args[:state] if args.key?(:state)
  @workloadidentity = args[:workloadidentity] if args.key?(:workloadidentity)
end