Class: Google::Apis::GkehubV1alpha::NamespaceActuationFeatureSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

An empty spec for actuation feature. This is required since Feature proto requires a spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NamespaceActuationFeatureSpec

Returns a new instance of NamespaceActuationFeatureSpec.



5128
5129
5130
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actuation_modeString

actuation_mode controls the behavior of the controller Corresponds to the JSON property actuationMode

Returns:

  • (String)


5126
5127
5128
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5126

def actuation_mode
  @actuation_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5133
5134
5135
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5133

def update!(**args)
  @actuation_mode = args[:actuation_mode] if args.key?(:actuation_mode)
end