Class: Google::Apis::GkehubV1alpha::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#cancel_requested ⇒ Boolean
(also: #cancel_requested?)
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#status_detail ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
5317 5318 5319 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
5281 5282 5283 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5281 def api_version @api_version end |
#cancel_requested ⇒ Boolean Also known as: cancel_requested?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have successfully been cancelled have google.
longrunning.Operation.error value with a google.rpc.Status.code of 1,
corresponding to Code.CANCELLED.
Corresponds to the JSON property cancelRequested
5289 5290 5291 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5289 def cancel_requested @cancel_requested end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
5295 5296 5297 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5295 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
5300 5301 5302 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5300 def end_time @end_time end |
#status_detail ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusDetail
5305 5306 5307 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5305 def status_detail @status_detail end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
5310 5311 5312 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5310 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
5315 5316 5317 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5315 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5322 5323 5324 5325 5326 5327 5328 5329 5330 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5322 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @cancel_requested = args[:cancel_requested] if args.key?(:cancel_requested) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @status_detail = args[:status_detail] if args.key?(:status_detail) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |