Class: Google::Apis::GkehubV1alpha::OperationalState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Operational state of the Rollout Sequence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationalState

Returns a new instance of OperationalState.



5396
5397
5398
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5396

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#reasonsArray<String>

Output only. Reasons for the Rollout Sequence state. Corresponds to the JSON property reasons

Returns:

  • (Array<String>)


5383
5384
5385
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5383

def reasons
  @reasons
end

#stateString

Output only. State of the Rollout Sequence. Corresponds to the JSON property state

Returns:

  • (String)


5388
5389
5390
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5388

def state
  @state
end

#state_change_timeString

Output only. The timestamp at which the operational state was last changed. Used to track how long it has been in the current state. Corresponds to the JSON property stateChangeTime

Returns:

  • (String)


5394
5395
5396
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5394

def state_change_time
  @state_change_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5401
5402
5403
5404
5405
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5401

def update!(**args)
  @reasons = args[:reasons] if args.key?(:reasons)
  @state = args[:state] if args.key?(:state)
  @state_change_time = args[:state_change_time] if args.key?(:state_change_time)
end