Class: Google::Apis::GkehubV1alpha::OperationalState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::OperationalState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Operational state of the Rollout Sequence.
Instance Attribute Summary collapse
-
#reasons ⇒ Array<String>
Output only.
-
#state ⇒ String
Output only.
-
#state_change_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationalState
constructor
A new instance of OperationalState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationalState
Returns a new instance of OperationalState.
5396 5397 5398 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5396 def initialize(**args) update!(**args) end |
Instance Attribute Details
#reasons ⇒ Array<String>
Output only. Reasons for the Rollout Sequence state.
Corresponds to the JSON property reasons
5383 5384 5385 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5383 def reasons @reasons end |
#state ⇒ String
Output only. State of the Rollout Sequence.
Corresponds to the JSON property state
5388 5389 5390 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5388 def state @state end |
#state_change_time ⇒ String
Output only. The timestamp at which the operational state was last changed.
Used to track how long it has been in the current state.
Corresponds to the JSON property stateChangeTime
5394 5395 5396 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5394 def state_change_time @state_change_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5401 5402 5403 5404 5405 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5401 def update!(**args) @reasons = args[:reasons] if args.key?(:reasons) @state = args[:state] if args.key?(:state) @state_change_time = args[:state_change_time] if args.key?(:state_change_time) end |