Class: Google::Apis::GkehubV1alpha::OperationalState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::OperationalState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Operational state of the Rollout Sequence.
Instance Attribute Summary collapse
-
#reasons ⇒ Array<String>
Output only.
-
#state ⇒ String
Output only.
-
#state_change_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationalState
constructor
A new instance of OperationalState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationalState
Returns a new instance of OperationalState.
5369 5370 5371 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5369 def initialize(**args) update!(**args) end |
Instance Attribute Details
#reasons ⇒ Array<String>
Output only. Reasons for the Rollout Sequence state.
Corresponds to the JSON property reasons
5356 5357 5358 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5356 def reasons @reasons end |
#state ⇒ String
Output only. State of the Rollout Sequence.
Corresponds to the JSON property state
5361 5362 5363 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5361 def state @state end |
#state_change_time ⇒ String
Output only. The timestamp at which the operational state was last changed.
Used to track how long it has been in the current state.
Corresponds to the JSON property stateChangeTime
5367 5368 5369 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5367 def state_change_time @state_change_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5374 5375 5376 5377 5378 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5374 def update!(**args) @reasons = args[:reasons] if args.key?(:reasons) @state = args[:state] if args.key?(:state) @state_change_time = args[:state_change_time] if args.key?(:state_change_time) end |