Class: Google::Apis::GkehubV1alpha::PerStageSoakDurationOverrides
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::PerStageSoakDurationOverrides
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Configuration for per-stage soak duration overrides.
Instance Attribute Summary collapse
-
#stage_overrides ⇒ Hash<String,String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PerStageSoakDurationOverrides
constructor
A new instance of PerStageSoakDurationOverrides.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PerStageSoakDurationOverrides
Returns a new instance of PerStageSoakDurationOverrides.
5455 5456 5457 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5455 def initialize(**args) update!(**args) end |
Instance Attribute Details
#stage_overrides ⇒ Hash<String,String>
Required. A mapping of stage numbers to their respective desired soak
durations. Key is the stage number, value is the desired soak duration. Stages
omitted from the map will receive the standard soak duration configured on the
sequence for that stage.
Corresponds to the JSON property stageOverrides
5453 5454 5455 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5453 def stage_overrides @stage_overrides end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5460 5461 5462 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5460 def update!(**args) @stage_overrides = args[:stage_overrides] if args.key?(:stage_overrides) end |