Class: Google::Apis::GkehubV1alpha::RbacRoleBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

RBACRoleBinding represents a rbacrolebinding across the Fleet

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RbacRoleBinding

Returns a new instance of RbacRoleBinding.



6042
6043
6044
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6042

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. When the rbacrolebinding was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5988
5989
5990
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5988

def create_time
  @create_time
end

#delete_timeString

Output only. When the rbacrolebinding was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


5993
5994
5995
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5993

def delete_time
  @delete_time
end

#groupString

group is the group, as seen by the kubernetes cluster. Corresponds to the JSON property group

Returns:

  • (String)


5998
5999
6000
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5998

def group
  @group
end

#labelsHash<String,String>

Optional. Labels for this RBACRolebinding. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6003
6004
6005
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6003

def labels
  @labels
end

#nameString

The resource name for the rbacrolebinding projects/project/locations/ location/scopes/scope/rbacrolebindings/rbacrolebindingor `projects/` project`/locations/`location`/memberships/`membership`/rbacrolebindings/` rbacrolebinding Corresponds to the JSON property name

Returns:

  • (String)


6011
6012
6013
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6011

def name
  @name
end

#roleGoogle::Apis::GkehubV1alpha::Role

Role is the type for Kubernetes roles Corresponds to the JSON property role



6016
6017
6018
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6016

def role
  @role
end

#stateGoogle::Apis::GkehubV1alpha::RbacRoleBindingLifecycleState

RBACRoleBindingLifecycleState describes the state of a RbacRoleBinding resource. Corresponds to the JSON property state



6022
6023
6024
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6022

def state
  @state
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all rbacrolebinding resources. If a rbacrolebinding resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


6029
6030
6031
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6029

def uid
  @uid
end

#update_timeString

Output only. When the rbacrolebinding was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6034
6035
6036
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6034

def update_time
  @update_time
end

#userString

user is the name of the user as seen by the kubernetes cluster, example "alice" or "alice@domain.tld" Corresponds to the JSON property user

Returns:

  • (String)


6040
6041
6042
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6040

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6047
6048
6049
6050
6051
6052
6053
6054
6055
6056
6057
6058
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6047

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @group = args[:group] if args.key?(:group)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @role = args[:role] if args.key?(:role)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user = args[:user] if args.key?(:user)
end