Class: Google::Apis::GkehubV1alpha::RbacRoleBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

RBACRoleBinding represents a rbacrolebinding across the Fleet

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RbacRoleBinding

Returns a new instance of RbacRoleBinding.



5999
6000
6001
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5999

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. When the rbacrolebinding was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5945
5946
5947
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5945

def create_time
  @create_time
end

#delete_timeString

Output only. When the rbacrolebinding was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


5950
5951
5952
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5950

def delete_time
  @delete_time
end

#groupString

group is the group, as seen by the kubernetes cluster. Corresponds to the JSON property group

Returns:

  • (String)


5955
5956
5957
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5955

def group
  @group
end

#labelsHash<String,String>

Optional. Labels for this RBACRolebinding. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5960
5961
5962
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5960

def labels
  @labels
end

#nameString

The resource name for the rbacrolebinding projects/project/locations/ location/scopes/scope/rbacrolebindings/rbacrolebindingor `projects/` project`/locations/`location`/memberships/`membership`/rbacrolebindings/` rbacrolebinding Corresponds to the JSON property name

Returns:

  • (String)


5968
5969
5970
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5968

def name
  @name
end

#roleGoogle::Apis::GkehubV1alpha::Role

Role is the type for Kubernetes roles Corresponds to the JSON property role



5973
5974
5975
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5973

def role
  @role
end

#stateGoogle::Apis::GkehubV1alpha::RbacRoleBindingLifecycleState

RBACRoleBindingLifecycleState describes the state of a RbacRoleBinding resource. Corresponds to the JSON property state



5979
5980
5981
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5979

def state
  @state
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all rbacrolebinding resources. If a rbacrolebinding resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


5986
5987
5988
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5986

def uid
  @uid
end

#update_timeString

Output only. When the rbacrolebinding was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5991
5992
5993
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5991

def update_time
  @update_time
end

#userString

user is the name of the user as seen by the kubernetes cluster, example "alice" or "alice@domain.tld" Corresponds to the JSON property user

Returns:

  • (String)


5997
5998
5999
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5997

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6004

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @group = args[:group] if args.key?(:group)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @role = args[:role] if args.key?(:role)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user = args[:user] if args.key?(:user)
end