Class: Google::Apis::GkehubV1alpha::RbacRoleBinding
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::RbacRoleBinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
RBACRoleBinding represents a rbacrolebinding across the Fleet
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#group ⇒ String
group is the group, as seen by the kubernetes cluster.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
The resource name for the rbacrolebinding
projects/project/locations/location/scopes/scope/rbacrolebindings/rbacrolebindingor `projects/` project`/locations/`location`/memberships/`membership`/rbacrolebindings/` rbacrolebindingCorresponds to the JSON propertyname. -
#role ⇒ Google::Apis::GkehubV1alpha::Role
Role is the type for Kubernetes roles Corresponds to the JSON property
role. -
#state ⇒ Google::Apis::GkehubV1alpha::RbacRoleBindingLifecycleState
RBACRoleBindingLifecycleState describes the state of a RbacRoleBinding resource.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#user ⇒ String
user is the name of the user as seen by the kubernetes cluster, example "alice" or "alice@domain.tld" Corresponds to the JSON property
user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RbacRoleBinding
constructor
A new instance of RbacRoleBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RbacRoleBinding
Returns a new instance of RbacRoleBinding.
5951 5952 5953 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5951 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. When the rbacrolebinding was created.
Corresponds to the JSON property createTime
5897 5898 5899 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5897 def create_time @create_time end |
#delete_time ⇒ String
Output only. When the rbacrolebinding was deleted.
Corresponds to the JSON property deleteTime
5902 5903 5904 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5902 def delete_time @delete_time end |
#group ⇒ String
group is the group, as seen by the kubernetes cluster.
Corresponds to the JSON property group
5907 5908 5909 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5907 def group @group end |
#labels ⇒ Hash<String,String>
Optional. Labels for this RBACRolebinding.
Corresponds to the JSON property labels
5912 5913 5914 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5912 def labels @labels end |
#name ⇒ String
The resource name for the rbacrolebinding projects/project/locations/
location/scopes/scope/rbacrolebindings/rbacrolebindingor `projects/`
project`/locations/`location`/memberships/`membership`/rbacrolebindings/`
rbacrolebinding
Corresponds to the JSON property name
5920 5921 5922 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5920 def name @name end |
#role ⇒ Google::Apis::GkehubV1alpha::Role
Role is the type for Kubernetes roles
Corresponds to the JSON property role
5925 5926 5927 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5925 def role @role end |
#state ⇒ Google::Apis::GkehubV1alpha::RbacRoleBindingLifecycleState
RBACRoleBindingLifecycleState describes the state of a RbacRoleBinding
resource.
Corresponds to the JSON property state
5931 5932 5933 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5931 def state @state end |
#uid ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all rbacrolebinding resources. If a rbacrolebinding resource is deleted and
another resource with the same name is created, it gets a different uid.
Corresponds to the JSON property uid
5938 5939 5940 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5938 def uid @uid end |
#update_time ⇒ String
Output only. When the rbacrolebinding was last updated.
Corresponds to the JSON property updateTime
5943 5944 5945 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5943 def update_time @update_time end |
#user ⇒ String
user is the name of the user as seen by the kubernetes cluster, example "alice"
or "alice@domain.tld"
Corresponds to the JSON property user
5949 5950 5951 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5949 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5956 5957 5958 5959 5960 5961 5962 5963 5964 5965 5966 5967 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5956 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @group = args[:group] if args.key?(:group) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @role = args[:role] if args.key?(:role) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @user = args[:user] if args.key?(:user) end |