Class: Google::Apis::GkehubV1alpha::RbacRoleBindingActuationFeatureSpec
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::RbacRoleBindingActuationFeatureSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
RBAC RoleBinding Actuation: The Hub-wide input for the RBACRoleBindingActuation feature.
Instance Attribute Summary collapse
-
#allowed_custom_roles ⇒ Array<String>
The list of allowed custom roles (ClusterRoles).
Instance Method Summary collapse
-
#initialize(**args) ⇒ RbacRoleBindingActuationFeatureSpec
constructor
A new instance of RbacRoleBindingActuationFeatureSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RbacRoleBindingActuationFeatureSpec
Returns a new instance of RbacRoleBindingActuationFeatureSpec.
5982 5983 5984 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5982 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_custom_roles ⇒ Array<String>
The list of allowed custom roles (ClusterRoles). If a ClusterRole is not part
of this list, it cannot be used in a Scope RBACRoleBinding. If a ClusterRole
in this list is in use, it cannot be removed from the list.
Corresponds to the JSON property allowedCustomRoles
5980 5981 5982 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5980 def allowed_custom_roles @allowed_custom_roles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5987 5988 5989 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 5987 def update!(**args) @allowed_custom_roles = args[:allowed_custom_roles] if args.key?(:allowed_custom_roles) end |