Class: Google::Apis::GkehubV1alpha::ResourceOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

ResourceOptions represent options for Kubernetes resource generation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceOptions

Returns a new instance of ResourceOptions.



6087
6088
6089
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connect_versionString

Optional. The Connect agent version to use for connect_resources. Defaults to the latest GKE Connect version. The version must be a currently supported version, obsolete versions will be rejected. Corresponds to the JSON property connectVersion

Returns:

  • (String)


6064
6065
6066
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6064

def connect_version
  @connect_version
end

#k8s_git_versionString

Optional. Git version of the Kubernetes cluster. This is only used to gate the Connect Agent migration to svc.id.goog on GDC-SO 1.33.100 patch and above. Corresponds to the JSON property k8sGitVersion

Returns:

  • (String)


6070
6071
6072
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6070

def k8s_git_version
  @k8s_git_version
end

#k8s_versionString

Optional. Major and minor version of the Kubernetes cluster. This is only used to determine which version to use for the CustomResourceDefinition resources, apiextensions/v1beta1 orapiextensions/v1. Corresponds to the JSON property k8sVersion

Returns:

  • (String)


6077
6078
6079
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6077

def k8s_version
  @k8s_version
end

#v1beta1_crdBoolean Also known as: v1beta1_crd?

Optional. Use apiextensions/v1beta1 instead of apiextensions/v1 for CustomResourceDefinition resources. This option should be set for clusters with Kubernetes apiserver versions <1.16. Corresponds to the JSON property v1beta1Crd

Returns:

  • (Boolean)


6084
6085
6086
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6084

def v1beta1_crd
  @v1beta1_crd
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6092
6093
6094
6095
6096
6097
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6092

def update!(**args)
  @connect_version = args[:connect_version] if args.key?(:connect_version)
  @k8s_git_version = args[:k8s_git_version] if args.key?(:k8s_git_version)
  @k8s_version = args[:k8s_version] if args.key?(:k8s_version)
  @v1beta1_crd = args[:v1beta1_crd] if args.key?(:v1beta1_crd)
end