Class: Google::Apis::GkehubV1alpha::Rollout

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Rollout contains the Rollout metadata and configuration. Next ID: 28

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Rollout

Returns a new instance of Rollout.



6344
6345
6346
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#complete_timeString

Output only. The timestamp at which the Rollout was completed. Corresponds to the JSON property completeTime

Returns:

  • (String)


6249
6250
6251
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6249

def complete_time
  @complete_time
end

#create_timeString

Output only. The timestamp at which the Rollout was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6254
6255
6256
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6254

def create_time
  @create_time
end

#delete_timeString

Output only. The timestamp at the Rollout was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


6259
6260
6261
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6259

def delete_time
  @delete_time
end

#display_nameString

Optional. Human readable display name of the Rollout. Corresponds to the JSON property displayName

Returns:

  • (String)


6264
6265
6266
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6264

def display_name
  @display_name
end

#etagString

Output only. etag of the Rollout Ex. abc1234 Corresponds to the JSON property etag

Returns:

  • (String)


6269
6270
6271
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6269

def etag
  @etag
end

#intentString

Output only. The intent of the rollout. Corresponds to the JSON property intent

Returns:

  • (String)


6274
6275
6276
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6274

def intent
  @intent
end

#labelsHash<String,String>

Optional. Labels for this Rollout. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6279
6280
6281
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6279

def labels
  @labels
end

#membership_statesHash<String,Google::Apis::GkehubV1alpha::RolloutMembershipState>

Output only. States of upgrading control plane or node pool targets of a single cluster (GKE Hub membership) that's part of this Rollout. The key is the membership name of the cluster. The value is the state of the cluster. Corresponds to the JSON property membershipStates



6286
6287
6288
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6286

def membership_states
  @membership_states
end

#nameString

Identifier. The full, unique resource name of this Rollout in the format of projects/project/locations/global/rollouts/rollout`. Corresponds to the JSON propertyname`

Returns:

  • (String)


6292
6293
6294
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6292

def name
  @name
end

#rollout_sequenceString

Optional. Immutable. The full, unique resource name of the rollout sequence that initiatied this Rollout. In the format of projects/project/locations/ global/rolloutSequences/rollout_sequence`. Corresponds to the JSON propertyrolloutSequence`

Returns:

  • (String)


6299
6300
6301
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6299

def rollout_sequence
  @rollout_sequence
end

#stagesArray<Google::Apis::GkehubV1alpha::RolloutStage>

Output only. The stages of the Rollout. Corresponds to the JSON property stages



6304
6305
6306
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6304

def stages
  @stages
end

#stateString

Output only. State specifies various states of the Rollout. Corresponds to the JSON property state

Returns:

  • (String)


6309
6310
6311
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6309

def state
  @state
end

#state_reasonString

Output only. A human-readable description explaining the reason for the current state. Corresponds to the JSON property stateReason

Returns:

  • (String)


6315
6316
6317
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6315

def state_reason
  @state_reason
end

#state_reason_typeString

Output only. StateReasonType specifies the reason type of the Rollout state. Corresponds to the JSON property stateReasonType

Returns:

  • (String)


6320
6321
6322
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6320

def state_reason_type
  @state_reason_type
end

#triggerString

Output only. The trigger of the rollout. Corresponds to the JSON property trigger

Returns:

  • (String)


6325
6326
6327
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6325

def trigger
  @trigger
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all Rollout resources. If a Rollout resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


6332
6333
6334
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6332

def uid
  @uid
end

#update_timeString

Output only. The timestamp at which the Rollout was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6337
6338
6339
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6337

def update_time
  @update_time
end

#version_upgradeGoogle::Apis::GkehubV1alpha::VersionUpgrade

Config for version upgrade of clusters. Corresponds to the JSON property versionUpgrade



6342
6343
6344
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6342

def version_upgrade
  @version_upgrade
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6349
6350
6351
6352
6353
6354
6355
6356
6357
6358
6359
6360
6361
6362
6363
6364
6365
6366
6367
6368
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6349

def update!(**args)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @intent = args[:intent] if args.key?(:intent)
  @labels = args[:labels] if args.key?(:labels)
  @membership_states = args[:membership_states] if args.key?(:membership_states)
  @name = args[:name] if args.key?(:name)
  @rollout_sequence = args[:rollout_sequence] if args.key?(:rollout_sequence)
  @stages = args[:stages] if args.key?(:stages)
  @state = args[:state] if args.key?(:state)
  @state_reason = args[:state_reason] if args.key?(:state_reason)
  @state_reason_type = args[:state_reason_type] if args.key?(:state_reason_type)
  @trigger = args[:trigger] if args.key?(:trigger)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version_upgrade = args[:version_upgrade] if args.key?(:version_upgrade)
end