Class: Google::Apis::GkehubV1alpha::Rollout
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::Rollout
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Rollout contains the Rollout metadata and configuration. Next ID: 28
Instance Attribute Summary collapse
-
#complete_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#intent ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#membership_states ⇒ Hash<String,Google::Apis::GkehubV1alpha::RolloutMembershipState>
Output only.
-
#name ⇒ String
Identifier.
-
#rollout_sequence ⇒ String
Optional.
-
#stages ⇒ Array<Google::Apis::GkehubV1alpha::RolloutStage>
Output only.
-
#state ⇒ String
Output only.
-
#state_reason ⇒ String
Output only.
-
#state_reason_type ⇒ String
Output only.
-
#trigger ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#version_upgrade ⇒ Google::Apis::GkehubV1alpha::VersionUpgrade
Config for version upgrade of clusters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Rollout
constructor
A new instance of Rollout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Rollout
Returns a new instance of Rollout.
6344 6345 6346 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6344 def initialize(**args) update!(**args) end |
Instance Attribute Details
#complete_time ⇒ String
Output only. The timestamp at which the Rollout was completed.
Corresponds to the JSON property completeTime
6249 6250 6251 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6249 def complete_time @complete_time end |
#create_time ⇒ String
Output only. The timestamp at which the Rollout was created.
Corresponds to the JSON property createTime
6254 6255 6256 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6254 def create_time @create_time end |
#delete_time ⇒ String
Output only. The timestamp at the Rollout was deleted.
Corresponds to the JSON property deleteTime
6259 6260 6261 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6259 def delete_time @delete_time end |
#display_name ⇒ String
Optional. Human readable display name of the Rollout.
Corresponds to the JSON property displayName
6264 6265 6266 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6264 def display_name @display_name end |
#etag ⇒ String
Output only. etag of the Rollout Ex. abc1234
Corresponds to the JSON property etag
6269 6270 6271 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6269 def etag @etag end |
#intent ⇒ String
Output only. The intent of the rollout.
Corresponds to the JSON property intent
6274 6275 6276 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6274 def intent @intent end |
#labels ⇒ Hash<String,String>
Optional. Labels for this Rollout.
Corresponds to the JSON property labels
6279 6280 6281 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6279 def labels @labels end |
#membership_states ⇒ Hash<String,Google::Apis::GkehubV1alpha::RolloutMembershipState>
Output only. States of upgrading control plane or node pool targets of a
single cluster (GKE Hub membership) that's part of this Rollout. The key is
the membership name of the cluster. The value is the state of the cluster.
Corresponds to the JSON property membershipStates
6286 6287 6288 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6286 def membership_states @membership_states end |
#name ⇒ String
Identifier. The full, unique resource name of this Rollout in the format of
projects/project/locations/global/rollouts/rollout`.
Corresponds to the JSON propertyname`
6292 6293 6294 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6292 def name @name end |
#rollout_sequence ⇒ String
Optional. Immutable. The full, unique resource name of the rollout sequence
that initiatied this Rollout. In the format of projects/project/locations/
global/rolloutSequences/rollout_sequence`.
Corresponds to the JSON propertyrolloutSequence`
6299 6300 6301 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6299 def rollout_sequence @rollout_sequence end |
#stages ⇒ Array<Google::Apis::GkehubV1alpha::RolloutStage>
Output only. The stages of the Rollout.
Corresponds to the JSON property stages
6304 6305 6306 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6304 def stages @stages end |
#state ⇒ String
Output only. State specifies various states of the Rollout.
Corresponds to the JSON property state
6309 6310 6311 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6309 def state @state end |
#state_reason ⇒ String
Output only. A human-readable description explaining the reason for the
current state.
Corresponds to the JSON property stateReason
6315 6316 6317 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6315 def state_reason @state_reason end |
#state_reason_type ⇒ String
Output only. StateReasonType specifies the reason type of the Rollout state.
Corresponds to the JSON property stateReasonType
6320 6321 6322 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6320 def state_reason_type @state_reason_type end |
#trigger ⇒ String
Output only. The trigger of the rollout.
Corresponds to the JSON property trigger
6325 6326 6327 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6325 def trigger @trigger end |
#uid ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all Rollout resources. If a Rollout resource is deleted and another resource
with the same name is created, it gets a different uid.
Corresponds to the JSON property uid
6332 6333 6334 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6332 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp at which the Rollout was last updated.
Corresponds to the JSON property updateTime
6337 6338 6339 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6337 def update_time @update_time end |
#version_upgrade ⇒ Google::Apis::GkehubV1alpha::VersionUpgrade
Config for version upgrade of clusters.
Corresponds to the JSON property versionUpgrade
6342 6343 6344 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6342 def version_upgrade @version_upgrade end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6349 def update!(**args) @complete_time = args[:complete_time] if args.key?(:complete_time) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @intent = args[:intent] if args.key?(:intent) @labels = args[:labels] if args.key?(:labels) @membership_states = args[:membership_states] if args.key?(:membership_states) @name = args[:name] if args.key?(:name) @rollout_sequence = args[:rollout_sequence] if args.key?(:rollout_sequence) @stages = args[:stages] if args.key?(:stages) @state = args[:state] if args.key?(:state) @state_reason = args[:state_reason] if args.key?(:state_reason) @state_reason_type = args[:state_reason_type] if args.key?(:state_reason_type) @trigger = args[:trigger] if args.key?(:trigger) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @version_upgrade = args[:version_upgrade] if args.key?(:version_upgrade) end |