Class: Google::Apis::GkehubV1alpha::Rollout
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::Rollout
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Rollout contains the Rollout metadata and configuration. Next ID: 28
Instance Attribute Summary collapse
-
#complete_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#membership_states ⇒ Hash<String,Google::Apis::GkehubV1alpha::RolloutMembershipState>
Output only.
-
#name ⇒ String
Identifier.
-
#rollout_sequence ⇒ String
Optional.
-
#stages ⇒ Array<Google::Apis::GkehubV1alpha::RolloutStage>
Output only.
-
#state ⇒ String
Output only.
-
#state_reason ⇒ String
Output only.
-
#state_reason_type ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#version_upgrade ⇒ Google::Apis::GkehubV1alpha::VersionUpgrade
Config for version upgrade of clusters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Rollout
constructor
A new instance of Rollout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Rollout
Returns a new instance of Rollout.
6317 6318 6319 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#complete_time ⇒ String
Output only. The timestamp at which the Rollout was completed.
Corresponds to the JSON property completeTime
6232 6233 6234 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6232 def complete_time @complete_time end |
#create_time ⇒ String
Output only. The timestamp at which the Rollout was created.
Corresponds to the JSON property createTime
6237 6238 6239 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6237 def create_time @create_time end |
#delete_time ⇒ String
Output only. The timestamp at the Rollout was deleted.
Corresponds to the JSON property deleteTime
6242 6243 6244 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6242 def delete_time @delete_time end |
#display_name ⇒ String
Optional. Human readable display name of the Rollout.
Corresponds to the JSON property displayName
6247 6248 6249 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6247 def display_name @display_name end |
#etag ⇒ String
Output only. etag of the Rollout Ex. abc1234
Corresponds to the JSON property etag
6252 6253 6254 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6252 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels for this Rollout.
Corresponds to the JSON property labels
6257 6258 6259 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6257 def labels @labels end |
#membership_states ⇒ Hash<String,Google::Apis::GkehubV1alpha::RolloutMembershipState>
Output only. States of upgrading control plane or node pool targets of a
single cluster (GKE Hub membership) that's part of this Rollout. The key is
the membership name of the cluster. The value is the state of the cluster.
Corresponds to the JSON property membershipStates
6264 6265 6266 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6264 def membership_states @membership_states end |
#name ⇒ String
Identifier. The full, unique resource name of this Rollout in the format of
projects/project/locations/global/rollouts/rollout`.
Corresponds to the JSON propertyname`
6270 6271 6272 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6270 def name @name end |
#rollout_sequence ⇒ String
Optional. Immutable. The full, unique resource name of the rollout sequence
that initiatied this Rollout. In the format of projects/project/locations/
global/rolloutSequences/rollout_sequence`.
Corresponds to the JSON propertyrolloutSequence`
6277 6278 6279 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6277 def rollout_sequence @rollout_sequence end |
#stages ⇒ Array<Google::Apis::GkehubV1alpha::RolloutStage>
Output only. The stages of the Rollout.
Corresponds to the JSON property stages
6282 6283 6284 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6282 def stages @stages end |
#state ⇒ String
Output only. State specifies various states of the Rollout.
Corresponds to the JSON property state
6287 6288 6289 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6287 def state @state end |
#state_reason ⇒ String
Output only. A human-readable description explaining the reason for the
current state.
Corresponds to the JSON property stateReason
6293 6294 6295 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6293 def state_reason @state_reason end |
#state_reason_type ⇒ String
Output only. StateReasonType specifies the reason type of the Rollout state.
Corresponds to the JSON property stateReasonType
6298 6299 6300 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6298 def state_reason_type @state_reason_type end |
#uid ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all Rollout resources. If a Rollout resource is deleted and another resource
with the same name is created, it gets a different uid.
Corresponds to the JSON property uid
6305 6306 6307 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6305 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp at which the Rollout was last updated.
Corresponds to the JSON property updateTime
6310 6311 6312 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6310 def update_time @update_time end |
#version_upgrade ⇒ Google::Apis::GkehubV1alpha::VersionUpgrade
Config for version upgrade of clusters.
Corresponds to the JSON property versionUpgrade
6315 6316 6317 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6315 def version_upgrade @version_upgrade end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6322 def update!(**args) @complete_time = args[:complete_time] if args.key?(:complete_time) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @membership_states = args[:membership_states] if args.key?(:membership_states) @name = args[:name] if args.key?(:name) @rollout_sequence = args[:rollout_sequence] if args.key?(:rollout_sequence) @stages = args[:stages] if args.key?(:stages) @state = args[:state] if args.key?(:state) @state_reason = args[:state_reason] if args.key?(:state_reason) @state_reason_type = args[:state_reason_type] if args.key?(:state_reason_type) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @version_upgrade = args[:version_upgrade] if args.key?(:version_upgrade) end |