Class: Google::Apis::GkehubV1alpha::Rollout

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Rollout contains the Rollout metadata and configuration. Next ID: 28

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Rollout

Returns a new instance of Rollout.



6265
6266
6267
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#complete_timeString

Output only. The timestamp at which the Rollout was completed. Corresponds to the JSON property completeTime

Returns:

  • (String)


6180
6181
6182
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6180

def complete_time
  @complete_time
end

#create_timeString

Output only. The timestamp at which the Rollout was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6185
6186
6187
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6185

def create_time
  @create_time
end

#delete_timeString

Output only. The timestamp at the Rollout was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


6190
6191
6192
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6190

def delete_time
  @delete_time
end

#display_nameString

Optional. Human readable display name of the Rollout. Corresponds to the JSON property displayName

Returns:

  • (String)


6195
6196
6197
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6195

def display_name
  @display_name
end

#etagString

Output only. etag of the Rollout Ex. abc1234 Corresponds to the JSON property etag

Returns:

  • (String)


6200
6201
6202
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6200

def etag
  @etag
end

#labelsHash<String,String>

Optional. Labels for this Rollout. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6205
6206
6207
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6205

def labels
  @labels
end

#membership_statesHash<String,Google::Apis::GkehubV1alpha::RolloutMembershipState>

Output only. States of upgrading control plane or node pool targets of a single cluster (GKE Hub membership) that's part of this Rollout. The key is the membership name of the cluster. The value is the state of the cluster. Corresponds to the JSON property membershipStates



6212
6213
6214
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6212

def membership_states
  @membership_states
end

#nameString

Identifier. The full, unique resource name of this Rollout in the format of projects/project/locations/global/rollouts/rollout`. Corresponds to the JSON propertyname`

Returns:

  • (String)


6218
6219
6220
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6218

def name
  @name
end

#rollout_sequenceString

Optional. Immutable. The full, unique resource name of the rollout sequence that initiatied this Rollout. In the format of projects/project/locations/ global/rolloutSequences/rollout_sequence`. Corresponds to the JSON propertyrolloutSequence`

Returns:

  • (String)


6225
6226
6227
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6225

def rollout_sequence
  @rollout_sequence
end

#stagesArray<Google::Apis::GkehubV1alpha::RolloutStage>

Output only. The stages of the Rollout. Corresponds to the JSON property stages



6230
6231
6232
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6230

def stages
  @stages
end

#stateString

Output only. State specifies various states of the Rollout. Corresponds to the JSON property state

Returns:

  • (String)


6235
6236
6237
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6235

def state
  @state
end

#state_reasonString

Output only. A human-readable description explaining the reason for the current state. Corresponds to the JSON property stateReason

Returns:

  • (String)


6241
6242
6243
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6241

def state_reason
  @state_reason
end

#state_reason_typeString

Output only. StateReasonType specifies the reason type of the Rollout state. Corresponds to the JSON property stateReasonType

Returns:

  • (String)


6246
6247
6248
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6246

def state_reason_type
  @state_reason_type
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all Rollout resources. If a Rollout resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


6253
6254
6255
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6253

def uid
  @uid
end

#update_timeString

Output only. The timestamp at which the Rollout was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6258
6259
6260
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6258

def update_time
  @update_time
end

#version_upgradeGoogle::Apis::GkehubV1alpha::VersionUpgrade

Config for version upgrade of clusters. Corresponds to the JSON property versionUpgrade



6263
6264
6265
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6263

def version_upgrade
  @version_upgrade
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6270
6271
6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
6287
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6270

def update!(**args)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @membership_states = args[:membership_states] if args.key?(:membership_states)
  @name = args[:name] if args.key?(:name)
  @rollout_sequence = args[:rollout_sequence] if args.key?(:rollout_sequence)
  @stages = args[:stages] if args.key?(:stages)
  @state = args[:state] if args.key?(:state)
  @state_reason = args[:state_reason] if args.key?(:state_reason)
  @state_reason_type = args[:state_reason_type] if args.key?(:state_reason_type)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version_upgrade = args[:version_upgrade] if args.key?(:version_upgrade)
end