Class: Google::Apis::GkehubV1alpha::Rollout
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::Rollout
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Rollout contains the Rollout metadata and configuration.
Instance Attribute Summary collapse
-
#complete_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#excluded_clusters ⇒ Array<Google::Apis::GkehubV1alpha::ExcludedCluster>
Optional.
-
#feature ⇒ Google::Apis::GkehubV1alpha::FeatureUpdate
Feature config to use for Rollout.
-
#labels ⇒ Hash<String,String>
Optional.
-
#membership_states ⇒ Hash<String,Google::Apis::GkehubV1alpha::RolloutMembershipState>
Output only.
-
#name ⇒ String
Identifier.
-
#rollout_sequence ⇒ String
Optional.
-
#schedule ⇒ Google::Apis::GkehubV1alpha::Schedule
Schedule represents the schedule of the Rollout.
-
#stages ⇒ Array<Google::Apis::GkehubV1alpha::RolloutStage>
Output only.
-
#state ⇒ String
Output only.
-
#state_reason ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#version_upgrade ⇒ Google::Apis::GkehubV1alpha::VersionUpgrade
Config for version upgrade of clusters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Rollout
constructor
A new instance of Rollout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Rollout
Returns a new instance of Rollout.
6228 6229 6230 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6228 def initialize(**args) update!(**args) end |
Instance Attribute Details
#complete_time ⇒ String
Output only. The timestamp at which the Rollout was completed.
Corresponds to the JSON property completeTime
6132 6133 6134 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6132 def complete_time @complete_time end |
#create_time ⇒ String
Output only. The timestamp at which the Rollout was created.
Corresponds to the JSON property createTime
6137 6138 6139 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6137 def create_time @create_time end |
#delete_time ⇒ String
Output only. The timestamp at the Rollout was deleted.
Corresponds to the JSON property deleteTime
6142 6143 6144 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6142 def delete_time @delete_time end |
#display_name ⇒ String
Optional. Human readable display name of the Rollout.
Corresponds to the JSON property displayName
6147 6148 6149 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6147 def display_name @display_name end |
#etag ⇒ String
Output only. etag of the Rollout Ex. abc1234
Corresponds to the JSON property etag
6152 6153 6154 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6152 def etag @etag end |
#excluded_clusters ⇒ Array<Google::Apis::GkehubV1alpha::ExcludedCluster>
Optional. Output only. The excluded clusters from the rollout.
Corresponds to the JSON property excludedClusters
6157 6158 6159 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6157 def excluded_clusters @excluded_clusters end |
#feature ⇒ Google::Apis::GkehubV1alpha::FeatureUpdate
Feature config to use for Rollout.
Corresponds to the JSON property feature
6162 6163 6164 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6162 def feature @feature end |
#labels ⇒ Hash<String,String>
Optional. Labels for this Rollout.
Corresponds to the JSON property labels
6167 6168 6169 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6167 def labels @labels end |
#membership_states ⇒ Hash<String,Google::Apis::GkehubV1alpha::RolloutMembershipState>
Output only. States of upgrading control plane or node pool targets of a
single cluster (GKE Hub membership) that's part of this Rollout. The key is
the membership name of the cluster. The value is the state of the cluster.
Corresponds to the JSON property membershipStates
6174 6175 6176 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6174 def membership_states @membership_states end |
#name ⇒ String
Identifier. The full, unique resource name of this Rollout in the format of
projects/project/locations/global/rollouts/rollout`.
Corresponds to the JSON propertyname`
6180 6181 6182 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6180 def name @name end |
#rollout_sequence ⇒ String
Optional. Immutable. The full, unique resource name of the rollout sequence
that initiatied this Rollout. In the format of projects/project/locations/
global/rolloutSequences/rollout_sequence`. Empty for user initiated rollouts.
Corresponds to the JSON propertyrolloutSequence`
6187 6188 6189 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6187 def rollout_sequence @rollout_sequence end |
#schedule ⇒ Google::Apis::GkehubV1alpha::Schedule
Schedule represents the schedule of the Rollout.
Corresponds to the JSON property schedule
6192 6193 6194 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6192 def schedule @schedule end |
#stages ⇒ Array<Google::Apis::GkehubV1alpha::RolloutStage>
Output only. The stages of the Rollout. Note: this is only populated for
google-initiated rollouts.
Corresponds to the JSON property stages
6198 6199 6200 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6198 def stages @stages end |
#state ⇒ String
Output only. State specifies various states of the Rollout.
Corresponds to the JSON property state
6203 6204 6205 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6203 def state @state end |
#state_reason ⇒ String
Output only. A human-readable description explaining the reason for the
current state.
Corresponds to the JSON property stateReason
6209 6210 6211 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6209 def state_reason @state_reason end |
#uid ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all Rollout resources. If a Rollout resource is deleted and another resource
with the same name is created, it gets a different uid.
Corresponds to the JSON property uid
6216 6217 6218 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6216 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp at which the Rollout was last updated.
Corresponds to the JSON property updateTime
6221 6222 6223 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6221 def update_time @update_time end |
#version_upgrade ⇒ Google::Apis::GkehubV1alpha::VersionUpgrade
Config for version upgrade of clusters.
Corresponds to the JSON property versionUpgrade
6226 6227 6228 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6226 def version_upgrade @version_upgrade end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6233 6234 6235 6236 6237 6238 6239 6240 6241 6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 6252 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6233 def update!(**args) @complete_time = args[:complete_time] if args.key?(:complete_time) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @excluded_clusters = args[:excluded_clusters] if args.key?(:excluded_clusters) @feature = args[:feature] if args.key?(:feature) @labels = args[:labels] if args.key?(:labels) @membership_states = args[:membership_states] if args.key?(:membership_states) @name = args[:name] if args.key?(:name) @rollout_sequence = args[:rollout_sequence] if args.key?(:rollout_sequence) @schedule = args[:schedule] if args.key?(:schedule) @stages = args[:stages] if args.key?(:stages) @state = args[:state] if args.key?(:state) @state_reason = args[:state_reason] if args.key?(:state_reason) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @version_upgrade = args[:version_upgrade] if args.key?(:version_upgrade) end |