Class: Google::Apis::GkehubV1alpha::RolloutMembershipState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::RolloutMembershipState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Metadata about single cluster (GKE Hub membership) that's part of this Rollout.
Instance Attribute Summary collapse
-
#last_update_time ⇒ String
Optional.
-
#stage_assignment ⇒ Fixnum
Output only.
-
#targets ⇒ Array<Google::Apis::GkehubV1alpha::RolloutTarget>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutMembershipState
constructor
A new instance of RolloutMembershipState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutMembershipState
Returns a new instance of RolloutMembershipState.
6409 6410 6411 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_update_time ⇒ String
Optional. Output only. The time this status and any related Rollout-specific
details for the membership were updated.
Corresponds to the JSON property lastUpdateTime
6395 6396 6397 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6395 def last_update_time @last_update_time end |
#stage_assignment ⇒ Fixnum
Output only. The stage assignment of this cluster in this rollout.
Corresponds to the JSON property stageAssignment
6400 6401 6402 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6400 def stage_assignment @stage_assignment end |
#targets ⇒ Array<Google::Apis::GkehubV1alpha::RolloutTarget>
Output only. The targets of the rollout - clusters or node pools that are
being upgraded. All targets belongs to the same cluster, identified by the
membership name (key of membership_states map).
Corresponds to the JSON property targets
6407 6408 6409 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6407 def targets @targets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6414 6415 6416 6417 6418 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6414 def update!(**args) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) @stage_assignment = args[:stage_assignment] if args.key?(:stage_assignment) @targets = args[:targets] if args.key?(:targets) end |