Class: Google::Apis::GkehubV1alpha::RolloutMembershipState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Metadata about single cluster (GKE Hub membership) that's part of this Rollout.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutMembershipState

Returns a new instance of RolloutMembershipState.



6236
6237
6238
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6236

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_update_timeString

Optional. Output only. The time this status and any related Rollout-specific details for the membership were updated. Corresponds to the JSON property lastUpdateTime

Returns:

  • (String)


6222
6223
6224
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6222

def last_update_time
  @last_update_time
end

#stage_assignmentFixnum

Output only. The stage assignment of this cluster in this rollout. Corresponds to the JSON property stageAssignment

Returns:

  • (Fixnum)


6227
6228
6229
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6227

def stage_assignment
  @stage_assignment
end

#targetsArray<Google::Apis::GkehubV1alpha::RolloutTarget>

Output only. The targets of the rollout - clusters or node pools that are being upgraded. All targets belongs to the same cluster, identified by the membership name (key of membership_states map). Corresponds to the JSON property targets



6234
6235
6236
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6234

def targets
  @targets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6241
6242
6243
6244
6245
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6241

def update!(**args)
  @last_update_time = args[:last_update_time] if args.key?(:last_update_time)
  @stage_assignment = args[:stage_assignment] if args.key?(:stage_assignment)
  @targets = args[:targets] if args.key?(:targets)
end