Class: Google::Apis::GkehubV1alpha::RolloutSequence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

RolloutSequence defines the desired order of upgrades. Next ID: 20

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutSequence

Returns a new instance of RolloutSequence.



6518
6519
6520
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6518

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_upgrade_configGoogle::Apis::GkehubV1alpha::AutoUpgradeConfig

Configuration for automatic upgrades. Corresponds to the JSON property autoUpgradeConfig



6428
6429
6430
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6428

def auto_upgrade_config
  @auto_upgrade_config
end

#computed_release_channelString

Output only. The computed release channel used for the Rollout Sequence. Corresponds to the JSON property computedReleaseChannel

Returns:

  • (String)


6433
6434
6435
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6433

def computed_release_channel
  @computed_release_channel
end

#create_timeString

Output only. The timestamp at which the Rollout Sequence was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6438
6439
6440
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6438

def create_time
  @create_time
end

#delete_timeString

Output only. The timestamp at the Rollout Sequence was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


6443
6444
6445
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6443

def delete_time
  @delete_time
end

#display_nameString

Optional. Human readable display name of the Rollout Sequence. Corresponds to the JSON property displayName

Returns:

  • (String)


6448
6449
6450
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6448

def display_name
  @display_name
end

#effective_auto_upgrade_configGoogle::Apis::GkehubV1alpha::AutoUpgradeConfig

Configuration for automatic upgrades. Corresponds to the JSON property effectiveAutoUpgradeConfig



6453
6454
6455
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6453

def effective_auto_upgrade_config
  @effective_auto_upgrade_config
end

#etagString

Output only. etag of the Rollout Sequence Ex. abc1234 Corresponds to the JSON property etag

Returns:

  • (String)


6458
6459
6460
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6458

def etag
  @etag
end

#ignored_clusters_selectorGoogle::Apis::GkehubV1alpha::ClusterSelector

Selector for clusters. Corresponds to the JSON property ignoredClustersSelector



6463
6464
6465
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6463

def ignored_clusters_selector
  @ignored_clusters_selector
end

#labelsHash<String,String>

Optional. Labels for this Rollout Sequence. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6468
6469
6470
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6468

def labels
  @labels
end

#last_qualified_control_plane_versionString

Output only. The last qualified control plane version. Corresponds to the JSON property lastQualifiedControlPlaneVersion

Returns:

  • (String)


6473
6474
6475
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6473

def last_qualified_control_plane_version
  @last_qualified_control_plane_version
end

#last_qualified_node_versionString

Output only. The last qualified node version. Corresponds to the JSON property lastQualifiedNodeVersion

Returns:

  • (String)


6478
6479
6480
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6478

def last_qualified_node_version
  @last_qualified_node_version
end

#nameString

Identifier. Name of the rollout sequence in the format of: projects/ PROJECT_ID/locations/global/rolloutSequences/NAME Corresponds to the JSON property name

Returns:

  • (String)


6484
6485
6486
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6484

def name
  @name
end

#operational_stateGoogle::Apis::GkehubV1alpha::OperationalState

Operational state of the Rollout Sequence. Corresponds to the JSON property operationalState



6489
6490
6491
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6489

def operational_state
  @operational_state
end

#stagesArray<Google::Apis::GkehubV1alpha::Stage>

Required. Ordered list of stages that constitutes this Rollout. Corresponds to the JSON property stages



6494
6495
6496
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6494

def stages
  @stages
end

#target_control_plane_versionString

Output only. The target control plane version of the Rollout Sequence. Corresponds to the JSON property targetControlPlaneVersion

Returns:

  • (String)


6499
6500
6501
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6499

def target_control_plane_version
  @target_control_plane_version
end

#target_node_versionString

Output only. The target node version of the Rollout Sequence. Corresponds to the JSON property targetNodeVersion

Returns:

  • (String)


6504
6505
6506
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6504

def target_node_version
  @target_node_version
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all Rollout Sequence resources. If a Rollout Sequence resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


6511
6512
6513
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6511

def uid
  @uid
end

#update_timeString

Output only. The timestamp at which the Rollout Sequence was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6516
6517
6518
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6516

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6523
6524
6525
6526
6527
6528
6529
6530
6531
6532
6533
6534
6535
6536
6537
6538
6539
6540
6541
6542
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6523

def update!(**args)
  @auto_upgrade_config = args[:auto_upgrade_config] if args.key?(:auto_upgrade_config)
  @computed_release_channel = args[:computed_release_channel] if args.key?(:computed_release_channel)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @effective_auto_upgrade_config = args[:effective_auto_upgrade_config] if args.key?(:effective_auto_upgrade_config)
  @etag = args[:etag] if args.key?(:etag)
  @ignored_clusters_selector = args[:ignored_clusters_selector] if args.key?(:ignored_clusters_selector)
  @labels = args[:labels] if args.key?(:labels)
  @last_qualified_control_plane_version = args[:last_qualified_control_plane_version] if args.key?(:last_qualified_control_plane_version)
  @last_qualified_node_version = args[:last_qualified_node_version] if args.key?(:last_qualified_node_version)
  @name = args[:name] if args.key?(:name)
  @operational_state = args[:operational_state] if args.key?(:operational_state)
  @stages = args[:stages] if args.key?(:stages)
  @target_control_plane_version = args[:target_control_plane_version] if args.key?(:target_control_plane_version)
  @target_node_version = args[:target_node_version] if args.key?(:target_node_version)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end