Class: Google::Apis::GkehubV1alpha::RolloutSequence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

RolloutSequence defines the desired order of upgrades. Next ID: 20

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutSequence

Returns a new instance of RolloutSequence.



6415
6416
6417
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6415

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_upgrade_configGoogle::Apis::GkehubV1alpha::AutoUpgradeConfig

Configuration for automatic upgrades. Corresponds to the JSON property autoUpgradeConfig



6350
6351
6352
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6350

def auto_upgrade_config
  @auto_upgrade_config
end

#create_timeString

Output only. The timestamp at which the Rollout Sequence was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6355
6356
6357
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6355

def create_time
  @create_time
end

#delete_timeString

Output only. The timestamp at the Rollout Sequence was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


6360
6361
6362
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6360

def delete_time
  @delete_time
end

#display_nameString

Optional. Human readable display name of the Rollout Sequence. Corresponds to the JSON property displayName

Returns:

  • (String)


6365
6366
6367
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6365

def display_name
  @display_name
end

#effective_auto_upgrade_configGoogle::Apis::GkehubV1alpha::AutoUpgradeConfig

Configuration for automatic upgrades. Corresponds to the JSON property effectiveAutoUpgradeConfig



6370
6371
6372
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6370

def effective_auto_upgrade_config
  @effective_auto_upgrade_config
end

#etagString

Output only. etag of the Rollout Sequence Ex. abc1234 Corresponds to the JSON property etag

Returns:

  • (String)


6375
6376
6377
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6375

def etag
  @etag
end

#ignored_clusters_selectorGoogle::Apis::GkehubV1alpha::ClusterSelector

Selector for clusters. Corresponds to the JSON property ignoredClustersSelector



6380
6381
6382
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6380

def ignored_clusters_selector
  @ignored_clusters_selector
end

#labelsHash<String,String>

Optional. Labels for this Rollout Sequence. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6385
6386
6387
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6385

def labels
  @labels
end

#nameString

Identifier. Name of the rollout sequence in the format of: projects/ PROJECT_ID/locations/global/rolloutSequences/NAME Corresponds to the JSON property name

Returns:

  • (String)


6391
6392
6393
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6391

def name
  @name
end

#operational_stateGoogle::Apis::GkehubV1alpha::OperationalState

Operational state of the Rollout Sequence. Corresponds to the JSON property operationalState



6396
6397
6398
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6396

def operational_state
  @operational_state
end

#stagesArray<Google::Apis::GkehubV1alpha::Stage>

Required. Ordered list of stages that constitutes this Rollout. Corresponds to the JSON property stages



6401
6402
6403
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6401

def stages
  @stages
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all Rollout Sequence resources. If a Rollout Sequence resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


6408
6409
6410
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6408

def uid
  @uid
end

#update_timeString

Output only. The timestamp at which the Rollout Sequence was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6413
6414
6415
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6413

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
6434
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6420

def update!(**args)
  @auto_upgrade_config = args[:auto_upgrade_config] if args.key?(:auto_upgrade_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @effective_auto_upgrade_config = args[:effective_auto_upgrade_config] if args.key?(:effective_auto_upgrade_config)
  @etag = args[:etag] if args.key?(:etag)
  @ignored_clusters_selector = args[:ignored_clusters_selector] if args.key?(:ignored_clusters_selector)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @operational_state = args[:operational_state] if args.key?(:operational_state)
  @stages = args[:stages] if args.key?(:stages)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end