Class: Google::Apis::GkehubV1alpha::RolloutSequence
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::RolloutSequence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
RolloutSequence defines the desired order of upgrades.
Instance Attribute Summary collapse
-
#auto_upgrade_config ⇒ Google::Apis::GkehubV1alpha::AutoUpgradeConfig
Configuration for automatic upgrades.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#effective_auto_upgrade_config ⇒ Google::Apis::GkehubV1alpha::AutoUpgradeConfig
Configuration for automatic upgrades.
-
#etag ⇒ String
Output only.
-
#ignored_clusters_selector ⇒ Google::Apis::GkehubV1alpha::ClusterSelector
Selector for clusters.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#stages ⇒ Array<Google::Apis::GkehubV1alpha::Stage>
Required.
-
#state ⇒ Google::Apis::GkehubV1alpha::RolloutSequenceState
State and reasons of the Rollout Sequence.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutSequence
constructor
A new instance of RolloutSequence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutSequence
Returns a new instance of RolloutSequence.
6383 6384 6385 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6383 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_upgrade_config ⇒ Google::Apis::GkehubV1alpha::AutoUpgradeConfig
Configuration for automatic upgrades.
Corresponds to the JSON property autoUpgradeConfig
6318 6319 6320 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6318 def auto_upgrade_config @auto_upgrade_config end |
#create_time ⇒ String
Output only. The timestamp at which the Rollout Sequence was created.
Corresponds to the JSON property createTime
6323 6324 6325 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6323 def create_time @create_time end |
#delete_time ⇒ String
Output only. The timestamp at the Rollout Sequence was deleted.
Corresponds to the JSON property deleteTime
6328 6329 6330 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6328 def delete_time @delete_time end |
#display_name ⇒ String
Optional. Human readable display name of the Rollout Sequence.
Corresponds to the JSON property displayName
6333 6334 6335 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6333 def display_name @display_name end |
#effective_auto_upgrade_config ⇒ Google::Apis::GkehubV1alpha::AutoUpgradeConfig
Configuration for automatic upgrades.
Corresponds to the JSON property effectiveAutoUpgradeConfig
6338 6339 6340 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6338 def effective_auto_upgrade_config @effective_auto_upgrade_config end |
#etag ⇒ String
Output only. etag of the Rollout Sequence Ex. abc1234
Corresponds to the JSON property etag
6343 6344 6345 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6343 def etag @etag end |
#ignored_clusters_selector ⇒ Google::Apis::GkehubV1alpha::ClusterSelector
Selector for clusters.
Corresponds to the JSON property ignoredClustersSelector
6348 6349 6350 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6348 def ignored_clusters_selector @ignored_clusters_selector end |
#labels ⇒ Hash<String,String>
Optional. Labels for this Rollout Sequence.
Corresponds to the JSON property labels
6353 6354 6355 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6353 def labels @labels end |
#name ⇒ String
Identifier. Name of the rollout sequence in the format of: projects/
PROJECT_ID/locations/global/rolloutSequences/NAME
Corresponds to the JSON property name
6359 6360 6361 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6359 def name @name end |
#stages ⇒ Array<Google::Apis::GkehubV1alpha::Stage>
Required. Ordered list of stages that constitutes this Rollout.
Corresponds to the JSON property stages
6364 6365 6366 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6364 def stages @stages end |
#state ⇒ Google::Apis::GkehubV1alpha::RolloutSequenceState
State and reasons of the Rollout Sequence.
Corresponds to the JSON property state
6369 6370 6371 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6369 def state @state end |
#uid ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all Rollout Sequence resources. If a Rollout Sequence resource is deleted and
another resource with the same name is created, it gets a different uid.
Corresponds to the JSON property uid
6376 6377 6378 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6376 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp at which the Rollout Sequence was last updated.
Corresponds to the JSON property updateTime
6381 6382 6383 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6381 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6388 def update!(**args) @auto_upgrade_config = args[:auto_upgrade_config] if args.key?(:auto_upgrade_config) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @effective_auto_upgrade_config = args[:effective_auto_upgrade_config] if args.key?(:effective_auto_upgrade_config) @etag = args[:etag] if args.key?(:etag) @ignored_clusters_selector = args[:ignored_clusters_selector] if args.key?(:ignored_clusters_selector) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @stages = args[:stages] if args.key?(:stages) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |