Class: Google::Apis::GkehubV1alpha::RolloutSequence
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::RolloutSequence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
RolloutSequence defines the desired order of upgrades.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#ignored_clusters_selector ⇒ Google::Apis::GkehubV1alpha::ClusterSelector
Selector for clusters.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#stages ⇒ Array<Google::Apis::GkehubV1alpha::Stage>
Required.
-
#state ⇒ Google::Apis::GkehubV1alpha::RolloutSequenceState
State and reasons of the Rollout Sequence.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutSequence
constructor
A new instance of RolloutSequence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutSequence
Returns a new instance of RolloutSequence.
6316 6317 6318 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6316 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp at which the Rollout Sequence was created.
Corresponds to the JSON property createTime
6261 6262 6263 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6261 def create_time @create_time end |
#delete_time ⇒ String
Output only. The timestamp at the Rollout Sequence was deleted.
Corresponds to the JSON property deleteTime
6266 6267 6268 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6266 def delete_time @delete_time end |
#display_name ⇒ String
Optional. Human readable display name of the Rollout Sequence.
Corresponds to the JSON property displayName
6271 6272 6273 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6271 def display_name @display_name end |
#etag ⇒ String
Output only. etag of the Rollout Sequence Ex. abc1234
Corresponds to the JSON property etag
6276 6277 6278 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6276 def etag @etag end |
#ignored_clusters_selector ⇒ Google::Apis::GkehubV1alpha::ClusterSelector
Selector for clusters.
Corresponds to the JSON property ignoredClustersSelector
6281 6282 6283 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6281 def ignored_clusters_selector @ignored_clusters_selector end |
#labels ⇒ Hash<String,String>
Optional. Labels for this Rollout Sequence.
Corresponds to the JSON property labels
6286 6287 6288 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6286 def labels @labels end |
#name ⇒ String
Identifier. Name of the rollout sequence in the format of: projects/
PROJECT_ID/locations/global/rolloutSequences/NAME
Corresponds to the JSON property name
6292 6293 6294 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6292 def name @name end |
#stages ⇒ Array<Google::Apis::GkehubV1alpha::Stage>
Required. Ordered list of stages that constitutes this Rollout.
Corresponds to the JSON property stages
6297 6298 6299 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6297 def stages @stages end |
#state ⇒ Google::Apis::GkehubV1alpha::RolloutSequenceState
State and reasons of the Rollout Sequence.
Corresponds to the JSON property state
6302 6303 6304 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6302 def state @state end |
#uid ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all Rollout Sequence resources. If a Rollout Sequence resource is deleted and
another resource with the same name is created, it gets a different uid.
Corresponds to the JSON property uid
6309 6310 6311 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6309 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp at which the Rollout Sequence was last updated.
Corresponds to the JSON property updateTime
6314 6315 6316 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6314 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6321 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @ignored_clusters_selector = args[:ignored_clusters_selector] if args.key?(:ignored_clusters_selector) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @stages = args[:stages] if args.key?(:stages) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |