Class: Google::Apis::GkehubV1alpha::RolloutSequence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

RolloutSequence defines the desired order of upgrades.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutSequence

Returns a new instance of RolloutSequence.



6341
6342
6343
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp at which the Rollout Sequence was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6296
6297
6298
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6296

def create_time
  @create_time
end

#delete_timeString

Output only. The timestamp at the Rollout Sequence was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


6301
6302
6303
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6301

def delete_time
  @delete_time
end

#display_nameString

Optional. Human readable display name of the Rollout Sequence. Corresponds to the JSON property displayName

Returns:

  • (String)


6306
6307
6308
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6306

def display_name
  @display_name
end

#etagString

Output only. etag of the Rollout Sequence Ex. abc1234 Corresponds to the JSON property etag

Returns:

  • (String)


6311
6312
6313
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6311

def etag
  @etag
end

#labelsHash<String,String>

Optional. Labels for this Rollout Sequence. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6316
6317
6318
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6316

def labels
  @labels
end

#nameString

Identifier. Name of the rollout sequence in the format of: projects/ PROJECT_ID/locations/global/rolloutSequences/NAME Corresponds to the JSON property name

Returns:

  • (String)


6322
6323
6324
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6322

def name
  @name
end

#stagesArray<Google::Apis::GkehubV1alpha::Stage>

Required. Ordered list of stages that constitutes this Rollout. Corresponds to the JSON property stages



6327
6328
6329
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6327

def stages
  @stages
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all Rollout Sequence resources. If a Rollout Sequence resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


6334
6335
6336
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6334

def uid
  @uid
end

#update_timeString

Output only. The timestamp at which the Rollout Sequence was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6339
6340
6341
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6339

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6346
6347
6348
6349
6350
6351
6352
6353
6354
6355
6356
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6346

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @stages = args[:stages] if args.key?(:stages)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end