Class: Google::Apis::GkehubV1alpha::RolloutSequenceState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::RolloutSequenceState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
State and reasons of the Rollout Sequence.
Instance Attribute Summary collapse
-
#last_state_change_time ⇒ String
Output only.
-
#lifecycle_state ⇒ String
Output only.
-
#state_reasons ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutSequenceState
constructor
A new instance of RolloutSequenceState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutSequenceState
Returns a new instance of RolloutSequenceState.
6356 6357 6358 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6356 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_state_change_time ⇒ String
Output only. The timestamp at which the LifecycleState was last changed. Used
to track how long it has been in the current state.
Corresponds to the JSON property lastStateChangeTime
6344 6345 6346 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6344 def last_state_change_time @last_state_change_time end |
#lifecycle_state ⇒ String
Output only. Lifecycle state of the Rollout Sequence.
Corresponds to the JSON property lifecycleState
6349 6350 6351 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6349 def lifecycle_state @lifecycle_state end |
#state_reasons ⇒ Array<String>
Output only. StateReason represents the reason for the Rollout Sequence state.
Corresponds to the JSON property stateReasons
6354 6355 6356 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6354 def state_reasons @state_reasons end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6361 6362 6363 6364 6365 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6361 def update!(**args) @last_state_change_time = args[:last_state_change_time] if args.key?(:last_state_change_time) @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state) @state_reasons = args[:state_reasons] if args.key?(:state_reasons) end |