Class: Google::Apis::GkehubV1alpha::RolloutStage
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::RolloutStage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Stage represents a single stage in the Rollout.
Instance Attribute Summary collapse
-
#cluster_selector ⇒ Google::Apis::GkehubV1alpha::ClusterSelector
Selector for clusters.
-
#end_time ⇒ String
Optional.
-
#fleet_projects ⇒ Array<String>
Output only.
-
#soak_duration ⇒ String
Optional.
-
#stage_number ⇒ Fixnum
Output only.
-
#start_time ⇒ String
Optional.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutStage
constructor
A new instance of RolloutStage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutStage
Returns a new instance of RolloutStage.
6588 6589 6590 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6588 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_selector ⇒ Google::Apis::GkehubV1alpha::ClusterSelector
Selector for clusters.
Corresponds to the JSON property clusterSelector
6555 6556 6557 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6555 def cluster_selector @cluster_selector end |
#end_time ⇒ String
Optional. Output only. The time at which the stage ended.
Corresponds to the JSON property endTime
6560 6561 6562 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6560 def end_time @end_time end |
#fleet_projects ⇒ Array<String>
Output only. The fleet projects from the sequence that was used to create this
stage. Expected format: projects/project_number
Corresponds to the JSON property fleetProjects
6566 6567 6568 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6566 def fleet_projects @fleet_projects end |
#soak_duration ⇒ String
Optional. Duration to soak after this stage before starting the next stage.
Corresponds to the JSON property soakDuration
6571 6572 6573 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6571 def soak_duration @soak_duration end |
#stage_number ⇒ Fixnum
Output only. The stage number to which this status applies.
Corresponds to the JSON property stageNumber
6576 6577 6578 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6576 def stage_number @stage_number end |
#start_time ⇒ String
Optional. Output only. The time at which the stage started.
Corresponds to the JSON property startTime
6581 6582 6583 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6581 def start_time @start_time end |
#state ⇒ String
Output only. The state of the stage.
Corresponds to the JSON property state
6586 6587 6588 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6586 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6593 6594 6595 6596 6597 6598 6599 6600 6601 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6593 def update!(**args) @cluster_selector = args[:cluster_selector] if args.key?(:cluster_selector) @end_time = args[:end_time] if args.key?(:end_time) @fleet_projects = args[:fleet_projects] if args.key?(:fleet_projects) @soak_duration = args[:soak_duration] if args.key?(:soak_duration) @stage_number = args[:stage_number] if args.key?(:stage_number) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |