Class: Google::Apis::GkehubV1alpha::Scope
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::Scope
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Scope represents a Scope in a Fleet.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
The resource name for the scope
projects/project/locations/location/ scopes/scope`Corresponds to the JSON propertyname`. -
#namespace_labels ⇒ Hash<String,String>
Optional.
-
#state ⇒ Google::Apis::GkehubV1alpha::ScopeLifecycleState
ScopeLifecycleState describes the state of a Scope resource.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Scope
constructor
A new instance of Scope.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Scope
Returns a new instance of Scope.
6580 6581 6582 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6580 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. When the scope was created.
Corresponds to the JSON property createTime
6536 6537 6538 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6536 def create_time @create_time end |
#delete_time ⇒ String
Output only. When the scope was deleted.
Corresponds to the JSON property deleteTime
6541 6542 6543 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6541 def delete_time @delete_time end |
#labels ⇒ Hash<String,String>
Optional. Labels for this Scope.
Corresponds to the JSON property labels
6546 6547 6548 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6546 def labels @labels end |
#name ⇒ String
The resource name for the scope projects/project/locations/location/
scopes/scope`
Corresponds to the JSON propertyname`
6552 6553 6554 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6552 def name @name end |
#namespace_labels ⇒ Hash<String,String>
Optional. Scope-level cluster namespace labels. For the member clusters bound
to the Scope, these labels are applied to each namespace under the Scope.
Scope-level labels take precedence over Namespace-level labels (
namespace_labels in the Fleet Namespace resource) if they share a key. Keys
and values must be Kubernetes-conformant.
Corresponds to the JSON property namespaceLabels
6561 6562 6563 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6561 def namespace_labels @namespace_labels end |
#state ⇒ Google::Apis::GkehubV1alpha::ScopeLifecycleState
ScopeLifecycleState describes the state of a Scope resource.
Corresponds to the JSON property state
6566 6567 6568 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6566 def state @state end |
#uid ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all scope resources. If a scope resource is deleted and another resource with
the same name is created, it gets a different uid.
Corresponds to the JSON property uid
6573 6574 6575 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6573 def uid @uid end |
#update_time ⇒ String
Output only. When the scope was last updated.
Corresponds to the JSON property updateTime
6578 6579 6580 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6578 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6585 6586 6587 6588 6589 6590 6591 6592 6593 6594 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6585 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @namespace_labels = args[:namespace_labels] if args.key?(:namespace_labels) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |