Class: Google::Apis::GkehubV1alpha::Scope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Scope represents a Scope in a Fleet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Scope

Returns a new instance of Scope.



6511
6512
6513
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6511

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. When the scope was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6467
6468
6469
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6467

def create_time
  @create_time
end

#delete_timeString

Output only. When the scope was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


6472
6473
6474
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6472

def delete_time
  @delete_time
end

#labelsHash<String,String>

Optional. Labels for this Scope. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6477
6478
6479
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6477

def labels
  @labels
end

#nameString

The resource name for the scope projects/project/locations/location/ scopes/scope` Corresponds to the JSON propertyname`

Returns:

  • (String)


6483
6484
6485
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6483

def name
  @name
end

#namespace_labelsHash<String,String>

Optional. Scope-level cluster namespace labels. For the member clusters bound to the Scope, these labels are applied to each namespace under the Scope. Scope-level labels take precedence over Namespace-level labels ( namespace_labels in the Fleet Namespace resource) if they share a key. Keys and values must be Kubernetes-conformant. Corresponds to the JSON property namespaceLabels

Returns:

  • (Hash<String,String>)


6492
6493
6494
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6492

def namespace_labels
  @namespace_labels
end

#stateGoogle::Apis::GkehubV1alpha::ScopeLifecycleState

ScopeLifecycleState describes the state of a Scope resource. Corresponds to the JSON property state



6497
6498
6499
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6497

def state
  @state
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all scope resources. If a scope resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


6504
6505
6506
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6504

def uid
  @uid
end

#update_timeString

Output only. When the scope was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6509
6510
6511
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6509

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6516
6517
6518
6519
6520
6521
6522
6523
6524
6525
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6516

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @namespace_labels = args[:namespace_labels] if args.key?(:namespace_labels)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end