Class: Google::Apis::GkehubV1alpha::ServiceMeshAnalysisMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

AnalysisMessage is a single message produced by an analyzer, and it used to communicate to the end user about the state of their Service Mesh configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceMeshAnalysisMessage

Returns a new instance of ServiceMeshAnalysisMessage.



6845
6846
6847
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6845

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsHash<String,Object>

A UI can combine these args with a template (based on message_base.type) to produce an internationalized message. Corresponds to the JSON property args

Returns:

  • (Hash<String,Object>)


6823
6824
6825
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6823

def args
  @args
end

#descriptionString

A human readable description of what the error means. It is suitable for non- internationalize display purposes. Corresponds to the JSON property description

Returns:

  • (String)


6829
6830
6831
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6829

def description
  @description
end

#message_baseGoogle::Apis::GkehubV1alpha::ServiceMeshAnalysisMessageBase

AnalysisMessageBase describes some common information that is needed for all messages. Corresponds to the JSON property messageBase



6835
6836
6837
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6835

def message_base
  @message_base
end

#resource_pathsArray<String>

A list of strings specifying the resource identifiers that were the cause of message generation. A "path" here may be: * MEMBERSHIP_ID if the cause is a specific member cluster * MEMBERSHIP_ID/(NAMESPACE\/)?RESOURCETYPE/NAME if the cause is a resource in a cluster Corresponds to the JSON property resourcePaths

Returns:

  • (Array<String>)


6843
6844
6845
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6843

def resource_paths
  @resource_paths
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6850
6851
6852
6853
6854
6855
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6850

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @description = args[:description] if args.key?(:description)
  @message_base = args[:message_base] if args.key?(:message_base)
  @resource_paths = args[:resource_paths] if args.key?(:resource_paths)
end