Class: Google::Apis::GkehubV1alpha::ServiceMeshAnalysisMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

AnalysisMessage is a single message produced by an analyzer, and it used to communicate to the end user about the state of their Service Mesh configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceMeshAnalysisMessage

Returns a new instance of ServiceMeshAnalysisMessage.



6721
6722
6723
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6721

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsHash<String,Object>

A UI can combine these args with a template (based on message_base.type) to produce an internationalized message. Corresponds to the JSON property args

Returns:

  • (Hash<String,Object>)


6699
6700
6701
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6699

def args
  @args
end

#descriptionString

A human readable description of what the error means. It is suitable for non- internationalize display purposes. Corresponds to the JSON property description

Returns:

  • (String)


6705
6706
6707
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6705

def description
  @description
end

#message_baseGoogle::Apis::GkehubV1alpha::ServiceMeshAnalysisMessageBase

AnalysisMessageBase describes some common information that is needed for all messages. Corresponds to the JSON property messageBase



6711
6712
6713
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6711

def message_base
  @message_base
end

#resource_pathsArray<String>

A list of strings specifying the resource identifiers that were the cause of message generation. A "path" here may be: * MEMBERSHIP_ID if the cause is a specific member cluster * MEMBERSHIP_ID/(NAMESPACE\/)?RESOURCETYPE/NAME if the cause is a resource in a cluster Corresponds to the JSON property resourcePaths

Returns:

  • (Array<String>)


6719
6720
6721
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6719

def resource_paths
  @resource_paths
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6726
6727
6728
6729
6730
6731
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6726

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @description = args[:description] if args.key?(:description)
  @message_base = args[:message_base] if args.key?(:message_base)
  @resource_paths = args[:resource_paths] if args.key?(:resource_paths)
end