Class: Google::Apis::GkehubV1alpha::ServiceMeshAnalysisMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

AnalysisMessage is a single message produced by an analyzer, and it used to communicate to the end user about the state of their Service Mesh configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceMeshAnalysisMessage

Returns a new instance of ServiceMeshAnalysisMessage.



6652
6653
6654
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsHash<String,Object>

A UI can combine these args with a template (based on message_base.type) to produce an internationalized message. Corresponds to the JSON property args

Returns:

  • (Hash<String,Object>)


6630
6631
6632
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6630

def args
  @args
end

#descriptionString

A human readable description of what the error means. It is suitable for non- internationalize display purposes. Corresponds to the JSON property description

Returns:

  • (String)


6636
6637
6638
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6636

def description
  @description
end

#message_baseGoogle::Apis::GkehubV1alpha::ServiceMeshAnalysisMessageBase

AnalysisMessageBase describes some common information that is needed for all messages. Corresponds to the JSON property messageBase



6642
6643
6644
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6642

def message_base
  @message_base
end

#resource_pathsArray<String>

A list of strings specifying the resource identifiers that were the cause of message generation. A "path" here may be: * MEMBERSHIP_ID if the cause is a specific member cluster * MEMBERSHIP_ID/(NAMESPACE\/)?RESOURCETYPE/NAME if the cause is a resource in a cluster Corresponds to the JSON property resourcePaths

Returns:

  • (Array<String>)


6650
6651
6652
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6650

def resource_paths
  @resource_paths
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6657
6658
6659
6660
6661
6662
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6657

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @description = args[:description] if args.key?(:description)
  @message_base = args[:message_base] if args.key?(:message_base)
  @resource_paths = args[:resource_paths] if args.key?(:resource_paths)
end