Class: Google::Apis::GkehubV1alpha::ServiceMeshAnalysisMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

AnalysisMessage is a single message produced by an analyzer, and it used to communicate to the end user about the state of their Service Mesh configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceMeshAnalysisMessage

Returns a new instance of ServiceMeshAnalysisMessage.



6633
6634
6635
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6633

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsHash<String,Object>

A UI can combine these args with a template (based on message_base.type) to produce an internationalized message. Corresponds to the JSON property args

Returns:

  • (Hash<String,Object>)


6611
6612
6613
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6611

def args
  @args
end

#descriptionString

A human readable description of what the error means. It is suitable for non- internationalize display purposes. Corresponds to the JSON property description

Returns:

  • (String)


6617
6618
6619
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6617

def description
  @description
end

#message_baseGoogle::Apis::GkehubV1alpha::ServiceMeshAnalysisMessageBase

AnalysisMessageBase describes some common information that is needed for all messages. Corresponds to the JSON property messageBase



6623
6624
6625
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6623

def message_base
  @message_base
end

#resource_pathsArray<String>

A list of strings specifying the resource identifiers that were the cause of message generation. A "path" here may be: * MEMBERSHIP_ID if the cause is a specific member cluster * MEMBERSHIP_ID/(NAMESPACE\/)?RESOURCETYPE/NAME if the cause is a resource in a cluster Corresponds to the JSON property resourcePaths

Returns:

  • (Array<String>)


6631
6632
6633
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6631

def resource_paths
  @resource_paths
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6638
6639
6640
6641
6642
6643
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6638

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @description = args[:description] if args.key?(:description)
  @message_base = args[:message_base] if args.key?(:message_base)
  @resource_paths = args[:resource_paths] if args.key?(:resource_paths)
end