Class: Google::Apis::GkehubV1alpha::ServiceMeshFeatureCondition
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ServiceMeshFeatureCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Condition being reported.
Instance Attribute Summary collapse
-
#code ⇒ String
Unique identifier of the condition which describes the condition recognizable to the user.
-
#details ⇒ String
A short summary about the issue.
-
#documentation_link ⇒ String
Links contains actionable information.
-
#severity ⇒ String
Severity level of the condition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceMeshFeatureCondition
constructor
A new instance of ServiceMeshFeatureCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceMeshFeatureCondition
Returns a new instance of ServiceMeshFeatureCondition.
6821 6822 6823 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6821 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Unique identifier of the condition which describes the condition recognizable
to the user.
Corresponds to the JSON property code
6804 6805 6806 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6804 def code @code end |
#details ⇒ String
A short summary about the issue.
Corresponds to the JSON property details
6809 6810 6811 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6809 def details @details end |
#documentation_link ⇒ String
Links contains actionable information.
Corresponds to the JSON property documentationLink
6814 6815 6816 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6814 def documentation_link @documentation_link end |
#severity ⇒ String
Severity level of the condition.
Corresponds to the JSON property severity
6819 6820 6821 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6819 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6826 6827 6828 6829 6830 6831 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6826 def update!(**args) @code = args[:code] if args.key?(:code) @details = args[:details] if args.key?(:details) @documentation_link = args[:documentation_link] if args.key?(:documentation_link) @severity = args[:severity] if args.key?(:severity) end |