Class: Google::Apis::GkehubV1alpha::ServiceMeshMembershipSpec
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::ServiceMeshMembershipSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Service Mesh: Spec for a single Membership for the servicemesh feature
Instance Attribute Summary collapse
-
#config_api ⇒ String
Optional.
-
#control_plane ⇒ String
Deprecated: use
managementinstead Enables automatic control plane management. -
#default_channel ⇒ String
Determines which release channel to use for default injection and service mesh APIs.
-
#management ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceMeshMembershipSpec
constructor
A new instance of ServiceMeshMembershipSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceMeshMembershipSpec
Returns a new instance of ServiceMeshMembershipSpec.
6868 6869 6870 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6868 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config_api ⇒ String
Optional. Specifies the API that will be used for configuring the mesh
workloads.
Corresponds to the JSON property configApi
6849 6850 6851 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6849 def config_api @config_api end |
#control_plane ⇒ String
Deprecated: use management instead Enables automatic control plane
management.
Corresponds to the JSON property controlPlane
6855 6856 6857 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6855 def control_plane @control_plane end |
#default_channel ⇒ String
Determines which release channel to use for default injection and service mesh
APIs.
Corresponds to the JSON property defaultChannel
6861 6862 6863 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6861 def default_channel @default_channel end |
#management ⇒ String
Optional. Enables automatic Service Mesh management.
Corresponds to the JSON property management
6866 6867 6868 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6866 def management @management end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6873 6874 6875 6876 6877 6878 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 6873 def update!(**args) @config_api = args[:config_api] if args.key?(:config_api) @control_plane = args[:control_plane] if args.key?(:control_plane) @default_channel = args[:default_channel] if args.key?(:default_channel) @management = args[:management] if args.key?(:management) end |