Class: Google::Apis::GkehubV1alpha::Stage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

Rollout stage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Stage

Returns a new instance of Stage.



7285
7286
7287
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7285

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_selectorGoogle::Apis::GkehubV1alpha::ClusterSelector

Selector for clusters. Corresponds to the JSON property clusterSelector



7272
7273
7274
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7272

def cluster_selector
  @cluster_selector
end

#fleet_projectsArray<String>

Required. List of Fleet projects to select the clusters from. Expected format: projects/project Corresponds to the JSON property fleetProjects

Returns:

  • (Array<String>)


7278
7279
7280
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7278

def fleet_projects
  @fleet_projects
end

#soak_durationString

Optional. Soak time after upgrading all the clusters in the stage. Corresponds to the JSON property soakDuration

Returns:

  • (String)


7283
7284
7285
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7283

def soak_duration
  @soak_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7290
7291
7292
7293
7294
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7290

def update!(**args)
  @cluster_selector = args[:cluster_selector] if args.key?(:cluster_selector)
  @fleet_projects = args[:fleet_projects] if args.key?(:fleet_projects)
  @soak_duration = args[:soak_duration] if args.key?(:soak_duration)
end