Class: Google::Apis::GkehubV1alpha::Stage
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::Stage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Rollout stage.
Instance Attribute Summary collapse
-
#cluster_selector ⇒ Google::Apis::GkehubV1alpha::ClusterSelector
Selector for clusters.
-
#fleet_projects ⇒ Array<String>
Required.
-
#soak_duration ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Stage
constructor
A new instance of Stage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Stage
Returns a new instance of Stage.
7145 7146 7147 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7145 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_selector ⇒ Google::Apis::GkehubV1alpha::ClusterSelector
Selector for clusters.
Corresponds to the JSON property clusterSelector
7132 7133 7134 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7132 def cluster_selector @cluster_selector end |
#fleet_projects ⇒ Array<String>
Required. List of Fleet projects to select the clusters from. Expected format:
projects/project
Corresponds to the JSON property fleetProjects
7138 7139 7140 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7138 def fleet_projects @fleet_projects end |
#soak_duration ⇒ String
Optional. Soak time after upgrading all the clusters in the stage.
Corresponds to the JSON property soakDuration
7143 7144 7145 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7143 def soak_duration @soak_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7150 7151 7152 7153 7154 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7150 def update!(**args) @cluster_selector = args[:cluster_selector] if args.key?(:cluster_selector) @fleet_projects = args[:fleet_projects] if args.key?(:fleet_projects) @soak_duration = args[:soak_duration] if args.key?(:soak_duration) end |