Class: Google::Apis::GkehubV1alpha::Stage
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::Stage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
Rollout stage.
Instance Attribute Summary collapse
-
#cluster_selector ⇒ Google::Apis::GkehubV1alpha::ClusterSelector
Selector for clusters.
-
#fleet_projects ⇒ Array<String>
Required.
-
#soak_duration ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Stage
constructor
A new instance of Stage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Stage
Returns a new instance of Stage.
7087 7088 7089 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7087 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_selector ⇒ Google::Apis::GkehubV1alpha::ClusterSelector
Selector for clusters.
Corresponds to the JSON property clusterSelector
7074 7075 7076 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7074 def cluster_selector @cluster_selector end |
#fleet_projects ⇒ Array<String>
Required. List of Fleet projects to select the clusters from. Expected format:
projects/project
Corresponds to the JSON property fleetProjects
7080 7081 7082 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7080 def fleet_projects @fleet_projects end |
#soak_duration ⇒ String
Optional. Soak time after upgrading all the clusters in the stage.
Corresponds to the JSON property soakDuration
7085 7086 7087 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7085 def soak_duration @soak_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7092 7093 7094 7095 7096 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7092 def update!(**args) @cluster_selector = args[:cluster_selector] if args.key?(:cluster_selector) @fleet_projects = args[:fleet_projects] if args.key?(:fleet_projects) @soak_duration = args[:soak_duration] if args.key?(:soak_duration) end |