Class: Google::Apis::GkehubV1alpha::ValidateExclusivityResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

The response of exclusivity artifacts validation result status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ValidateExclusivityResponse

Returns a new instance of ValidateExclusivityResponse.



7248
7249
7250
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7248

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#statusGoogle::Apis::GkehubV1alpha::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



7246
7247
7248
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7246

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7253
7254
7255
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7253

def update!(**args)
  @status = args[:status] if args.key?(:status)
end