Class: Google::Apis::GkehubV1alpha::WorkloadIdentityFeatureState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::WorkloadIdentityFeatureState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
WorkloadIdentity: Global feature state.
Instance Attribute Summary collapse
-
#namespace_state_details ⇒ Hash<String,Google::Apis::GkehubV1alpha::WorkloadIdentityNamespaceStateDetail>
The state of the IAM namespaces for the fleet.
-
#namespace_states ⇒ Hash<String,String>
Deprecated, this field will be erased after code is changed to use the new field.
-
#scope_tenancy_workload_identity_pool ⇒ String
The full name of the scope-tenancy pool for the fleet.
-
#workload_identity_pool ⇒ String
The full name of the svc.id.goog pool for the fleet.
-
#workload_identity_pool_state_details ⇒ Hash<String,Google::Apis::GkehubV1alpha::WorkloadIdentityWorkloadIdentityPoolStateDetail>
The state of the Workload Identity Pools for the fleet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityFeatureState
constructor
A new instance of WorkloadIdentityFeatureState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityFeatureState
Returns a new instance of WorkloadIdentityFeatureState.
7398 7399 7400 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7398 def initialize(**args) update!(**args) end |
Instance Attribute Details
#namespace_state_details ⇒ Hash<String,Google::Apis::GkehubV1alpha::WorkloadIdentityNamespaceStateDetail>
The state of the IAM namespaces for the fleet.
Corresponds to the JSON property namespaceStateDetails
7375 7376 7377 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7375 def namespace_state_details @namespace_state_details end |
#namespace_states ⇒ Hash<String,String>
Deprecated, this field will be erased after code is changed to use the new
field.
Corresponds to the JSON property namespaceStates
7381 7382 7383 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7381 def namespace_states @namespace_states end |
#scope_tenancy_workload_identity_pool ⇒ String
The full name of the scope-tenancy pool for the fleet.
Corresponds to the JSON property scopeTenancyWorkloadIdentityPool
7386 7387 7388 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7386 def scope_tenancy_workload_identity_pool @scope_tenancy_workload_identity_pool end |
#workload_identity_pool ⇒ String
The full name of the svc.id.goog pool for the fleet.
Corresponds to the JSON property workloadIdentityPool
7391 7392 7393 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7391 def workload_identity_pool @workload_identity_pool end |
#workload_identity_pool_state_details ⇒ Hash<String,Google::Apis::GkehubV1alpha::WorkloadIdentityWorkloadIdentityPoolStateDetail>
The state of the Workload Identity Pools for the fleet.
Corresponds to the JSON property workloadIdentityPoolStateDetails
7396 7397 7398 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7396 def workload_identity_pool_state_details @workload_identity_pool_state_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7403 7404 7405 7406 7407 7408 7409 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7403 def update!(**args) @namespace_state_details = args[:namespace_state_details] if args.key?(:namespace_state_details) @namespace_states = args[:namespace_states] if args.key?(:namespace_states) @scope_tenancy_workload_identity_pool = args[:scope_tenancy_workload_identity_pool] if args.key?(:scope_tenancy_workload_identity_pool) @workload_identity_pool = args[:workload_identity_pool] if args.key?(:workload_identity_pool) @workload_identity_pool_state_details = args[:workload_identity_pool_state_details] if args.key?(:workload_identity_pool_state_details) end |