Class: Google::Apis::GkehubV1alpha::WorkloadIdentityIdentityProviderStateDetail
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::WorkloadIdentityIdentityProviderStateDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
IdentityProviderStateDetail represents the state of an Identity Provider.
Instance Attribute Summary collapse
-
#code ⇒ String
The state of the Identity Provider.
-
#description ⇒ String
A human-readable description of the current state or returned error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityIdentityProviderStateDetail
constructor
A new instance of WorkloadIdentityIdentityProviderStateDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityIdentityProviderStateDetail
Returns a new instance of WorkloadIdentityIdentityProviderStateDetail.
7384 7385 7386 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7384 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The state of the Identity Provider.
Corresponds to the JSON property code
7377 7378 7379 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7377 def code @code end |
#description ⇒ String
A human-readable description of the current state or returned error.
Corresponds to the JSON property description
7382 7383 7384 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7382 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7389 7390 7391 7392 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7389 def update!(**args) @code = args[:code] if args.key?(:code) @description = args[:description] if args.key?(:description) end |