Class: Google::Apis::GkehubV1alpha::WorkloadIdentityIdentityProviderStateDetail
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::WorkloadIdentityIdentityProviderStateDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
IdentityProviderStateDetail represents the state of an Identity Provider.
Instance Attribute Summary collapse
-
#code ⇒ String
The state of the Identity Provider.
-
#description ⇒ String
A human-readable description of the current state or returned error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityIdentityProviderStateDetail
constructor
A new instance of WorkloadIdentityIdentityProviderStateDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityIdentityProviderStateDetail
Returns a new instance of WorkloadIdentityIdentityProviderStateDetail.
7365 7366 7367 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7365 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The state of the Identity Provider.
Corresponds to the JSON property code
7358 7359 7360 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7358 def code @code end |
#description ⇒ String
A human-readable description of the current state or returned error.
Corresponds to the JSON property description
7363 7364 7365 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7363 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7370 7371 7372 7373 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7370 def update!(**args) @code = args[:code] if args.key?(:code) @description = args[:description] if args.key?(:description) end |