Class: Google::Apis::GkehubV1alpha::WorkloadIdentityMembershipState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::WorkloadIdentityMembershipState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
WorkloadIdentity: The membership-specific state for WorkloadIdentity feature.
Instance Attribute Summary collapse
-
#description ⇒ String
Deprecated, this field will be erased after code is changed to use the new field.
-
#identity_provider_state_details ⇒ Hash<String,Google::Apis::GkehubV1alpha::WorkloadIdentityIdentityProviderStateDetail>
The state of the Identity Providers corresponding to the membership.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityMembershipState
constructor
A new instance of WorkloadIdentityMembershipState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityMembershipState
Returns a new instance of WorkloadIdentityMembershipState.
7672 7673 7674 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7672 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Deprecated, this field will be erased after code is changed to use the new
field.
Corresponds to the JSON property description
7665 7666 7667 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7665 def description @description end |
#identity_provider_state_details ⇒ Hash<String,Google::Apis::GkehubV1alpha::WorkloadIdentityIdentityProviderStateDetail>
The state of the Identity Providers corresponding to the membership.
Corresponds to the JSON property identityProviderStateDetails
7670 7671 7672 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7670 def identity_provider_state_details @identity_provider_state_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7677 7678 7679 7680 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7677 def update!(**args) @description = args[:description] if args.key?(:description) @identity_provider_state_details = args[:identity_provider_state_details] if args.key?(:identity_provider_state_details) end |