Class: Google::Apis::GkehubV1alpha::WorkloadIdentityMembershipState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::WorkloadIdentityMembershipState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
WorkloadIdentity: The membership-specific state for WorkloadIdentity feature.
Instance Attribute Summary collapse
-
#description ⇒ String
Deprecated, this field will be erased after code is changed to use the new field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityMembershipState
constructor
A new instance of WorkloadIdentityMembershipState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityMembershipState
Returns a new instance of WorkloadIdentityMembershipState.
7423 7424 7425 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7423 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Deprecated, this field will be erased after code is changed to use the new
field.
Corresponds to the JSON property description
7421 7422 7423 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7421 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7428 7429 7430 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7428 def update!(**args) @description = args[:description] if args.key?(:description) end |