Class: Google::Apis::GkehubV1alpha::WorkloadIdentityWorkloadIdentityPoolStateDetail
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1alpha::WorkloadIdentityWorkloadIdentityPoolStateDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb
Overview
WorkloadIdentityPoolStateDetail represents the state of the Workload Identity Pools for the fleet.
Instance Attribute Summary collapse
-
#code ⇒ String
The state of the Workload Identity Pool.
-
#description ⇒ String
A human-readable description of the current state or returned error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityWorkloadIdentityPoolStateDetail
constructor
A new instance of WorkloadIdentityWorkloadIdentityPoolStateDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityWorkloadIdentityPoolStateDetail
Returns a new instance of WorkloadIdentityWorkloadIdentityPoolStateDetail.
7531 7532 7533 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7531 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The state of the Workload Identity Pool.
Corresponds to the JSON property code
7524 7525 7526 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7524 def code @code end |
#description ⇒ String
A human-readable description of the current state or returned error.
Corresponds to the JSON property description
7529 7530 7531 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7529 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7536 7537 7538 7539 |
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7536 def update!(**args) @code = args[:code] if args.key?(:code) @description = args[:description] if args.key?(:description) end |