Class: Google::Apis::GkehubV1alpha::WorkloadIdentityWorkloadIdentityPoolStateDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

WorkloadIdentityPoolStateDetail represents the state of the Workload Identity Pools for the fleet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityWorkloadIdentityPoolStateDetail

Returns a new instance of WorkloadIdentityWorkloadIdentityPoolStateDetail.



7462
7463
7464
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

The state of the Workload Identity Pool. Corresponds to the JSON property code

Returns:

  • (String)


7455
7456
7457
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7455

def code
  @code
end

#descriptionString

A human-readable description of the current state or returned error. Corresponds to the JSON property description

Returns:

  • (String)


7460
7461
7462
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7460

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7467
7468
7469
7470
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7467

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @description = args[:description] if args.key?(:description)
end