Class: Google::Apis::GkehubV1alpha::WorkloadIdentityWorkloadIdentityPoolStateDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1alpha/classes.rb,
lib/google/apis/gkehub_v1alpha/representations.rb,
lib/google/apis/gkehub_v1alpha/representations.rb

Overview

WorkloadIdentityPoolStateDetail represents the state of the Workload Identity Pools for the fleet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityWorkloadIdentityPoolStateDetail

Returns a new instance of WorkloadIdentityWorkloadIdentityPoolStateDetail.



7473
7474
7475
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

The state of the Workload Identity Pool. Corresponds to the JSON property code

Returns:

  • (String)


7466
7467
7468
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7466

def code
  @code
end

#descriptionString

A human-readable description of the current state or returned error. Corresponds to the JSON property description

Returns:

  • (String)


7471
7472
7473
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7471

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7478
7479
7480
7481
# File 'lib/google/apis/gkehub_v1alpha/classes.rb', line 7478

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @description = args[:description] if args.key?(:description)
end